;;
;; REVISION HISTORY (most recent at bottom of comments):  
;;
;;
;; Mods:
;;   07/26/2004 GNC
;;     - GOB model to remove 190s from prefix
;;     - Orbit model to use May04 ops numbers
;;     - Orient range table increased to expected allowable numbers (still 
;; 		conservative at 90-100 deg)
;;
;;   08/17/2004 GNC
;;     - Orient range table update
;;
;;   11/08/2004 GNC
;;     - Increase FHST sun limit angles from 25.0 to 40.0
;;     - Decrease FHST warmup time from 3m to 1m
;;
;;   12/21/2004 GNC
;;     - Decrease fhst-sun-limit-angles from 40 --> 37.7
;;     - Modify GOB parameters for new GS Acq timing
;;
;;   01/17/2004 GNC
;;     - Modify GOB parameters for new GS Acq timing (+1s for FGSTERM at front)
;;       means GOB Dur 376-->377, GOB Excl Time 121-->122 & GOB Prefix 121-->122
;;
;;   01/18/2004 GNC
;;     - Modify OAD parameters.  +15s (0.25m) to the map (no-handoff) portion 
;;		of each OAD.
;;       Which means the overall OAD durations were also increased.
;;
;;   03/28/2005 GNC
;;     Post-F2G Test updates
;;     - Modify OAD parameters.  -15s (0.25m) to the map (no-handoff) portion 
;;		of EACH OAD.
;;       Which means the overall OAD durations were also decreased by 15s.
;;       OAD1 dur 10.25 --> 10.00,  OAD1 excl time 3.25 --> 3.00,
;;       OAD2 dur  8.25 -->  8.00 , OAD2 excl time 3.25 --> 3.00
;;     - Modify OAD2 correction/maneuver parameters. -170s from correction & 
;;		-30s from settling time (ie -200s from OAD2 duration).  
;;		Assuming the above -15s already done, then
;;       OAD2 dur  8.00 --> 4.666667
;;     - Decrease MAU from 2.0 degrees --> 0.1 degrees
;;
;;
;;   04/19/05 ASV for Merle changed oad1-duration from 10 to  9.50 (-30s 
;;	from settling time)
;;
;;   05/16/2005 GNC
;;     - Decreased MAP portion of each OAD by 15s:
;;       OAD1 dur  9.50     -->  9.25,     OAD1 excl time 3.00 --> 2.75
;;       OAD2 dur  4.666667 -->  4.416667, OAD2 excl time 3.00 --> 2.75
;;
;; 05/12/02 ijej:
;; Altered the following activity times pursuant to M. Reinhart's Nov. 23 
;;	10:10 email to LRPG:
;;
;; gob-handoff-exclusion-time:         from 4.25     to 2.75
;; gob-duration:                       from 6.283333 to 4.46667
;; oad1-duration:                      from 9.25     to 8.25
;; rate-task-duration:                 from 3.0      to 2.5
;; rate-task-handoff-exclustion-time:  from 3.0      to 2.5
;;
;; 06/02/09 ijej:  extended planning interval by 91 days.
;;                 changed gob handoff exclusion time from 2.75 to 2.4334.
;;
;; 06/02/09 ijej:  orbit model update.  Set for nominal solar prediction at 
;;		April 02, 2007.
;;
;; 06/02/21 ijej:  OAD1 update 8.25 --> 7.9167
;; 		   rate-task-duration 2.5 --> 1.6
;;		   rate-task-handoff-exclusion-time 2.5 --> 1.6
;;
;; 06/03/15 mdr: Expanded lau-attitude-error-angle to put in FHST moon, earth 
;;		dark and bright limb pads of 6.0 degreees
;;               oad2-duration 4.4167 --> 4.25
;;               gob-duration 4.46667 --> 4.45                   
;;               gob-handoff-exclusion-offset 2.03333 --> 1.86667
;;               gob-handoff-exclusion-time 2.43334 --> 2.58333
;;               gob-prefix 2.03333 --> 1.86667
;;               Note:  the gob numbers assume the PFFL GS Acq Logic Timings
;;               Added in fhst-activity-separations with current SPSS numbers, 
;;			but leave commented out for this delivery
;;
;; 06/06/12 mdr: Expanded orient-range-table to enable asymmetric roll
;;
;; 06-08-10/16 ij:	New orbit model aug06 optimized for April 2, 2008--
;;			correction to plane_projector projection 
;;			ascending node.  Update planning-start for earliest 
;;			linkset.
;; 07-16-07 mdr: Settings for Post-SM4 3-gyro mode up until about April 2009.
;;
;; 08-04-08 mdr: Complete rework of the orient-range-table due to OPR 58333
;;               Modified planning-end to be the end of the valid 
;;			orient-range-table data
;;               Removed :min/max-sun-angle per OPR 55253
;;               Update4d :sun-angle-restrictions per OPR 55253
;;
;; 08-04-18 ij:	copied for apt/casm17.2 release. Added in missing 2-gyro 
;;		parameters for heritage preservation.
;;		Contains dec07 orbit model.
;;

(DEFINE-CONSTRAINT-SET
  :planning-start                    "07.134"	;; Week start of the earliest 
						;; open linkset.
  :planning-end                      "10.186"   ;; An 6 month period beyond 
						;; cycle boundary.
  :model-fhst-in-saa                    nil	;; nil is the setting for 
						;; CASM/APT delivery.
  :filter-2gyro-with-3gyro-orb-viewing  t	;; t is the setting specified 
						;; for APT/CASM delivery.

  :2gyro-visibility-threshold           42	;; ;A minimum amount of
	;; 2-gyro visibility required for an  observation to be considered 
	;; suitable. In 3gyro mode it is used to calculate the estimated 
	;; 2-gyro suitability of a  visit.  In 2-gyro mode it is used to 
	;; collect roll ranges for the  :2GYRO-LOW-VIS roll-range-description, 
	;; cv-desc form for APT.


  ;;
  ;; SI/FGS/FHST LIMIT ANGLES:
  ;;
  ;;:si-bright-earth-limb-angle          20.0	;; ;SI bright earth limb 
				;; angle in degrees...now 
				;; comes from tic file

  :si-dark-earth-limb-angle             6    	;; SI dark earth limb 
				;; angle in degrees

  :fgs-bright-earth-limb-angle         13.5	;; FGS bright earth limb 
				;; angle in degrees

  :fgs-dark-earth-limb-angle            6	;; FGS dark earth limb 
				;; angle in degrees

  :fhst-sun-limit-angles         '(37.7 37.7 37.7)  ;; The Sun angle 
				;; limits (in degrees) for FHSTs 1,2,3 

  :fhst-moon-limit-angles        '(17.5 17.5 17.5)  ;; The Moon angle 
				;; limits (in degrees) for FHSTs 1,2,3

  :fhst-bright-earth-limb-angles '(32.375 32.375 32.375)
                                   ;; The bright Earth limb angle 
				;; limits (in degrees) for FHSTs 1,2,3

  :fhst-dark-earth-limb-angles   '(16.5 16.5 16.5)  ;; The dark Earth limb 
				;; angle limits (in degrees) for FHSTs 1,2,3

  :low-sky-si-bright-earth-angle     40		;; SI bright earth 
				;; limb angle in degrees for LOW SKY

  :off-nominal-calc                  T		;; Non nil - calc off-nominal 
				;; rolls in GS constraint
  ;;
  ;;
  ;;
  ;;  2-GYRO SPECIFIC PARAMETERS: 
  ;;  
  :lau-attitude-error-angle '(10.0  (:moon 4.0)         ;Large Attitude Uncertainty (degrees).
                                    (:dark-limb 4.0)    ;  The expected attitude error while under MMS Gyro control (T2G).
				    (:bright-limb 4.0)) ; See OPR 54890 for complete details on this parameter
  :MAU-attitude-error-angle              0.1        ;Medium Attitude Uncertainty (degrees). 
                                                    ;  The expected attitude error after the first OBAD.
  :SAU-attitude-error-angle              0.015280   ;Small Attitude Uncertainty (degrees).  
                                                    ;  The expected attitude error when under FHST (Tracker) 2 Gyro control.
  :rate-task-duration                    1.6        ;Duration of the rate task (minutes).
  :rate-task-handoff-exclusion-time      1.6        ;The portion of the rate task which cannot have an FHST handoff (minutes). 
                                                    ;  The zone starts at the start of the task.
  :oad1-duration                         7.9167     ;The duration of the first FHST attidude correction and map
  :oad1-handoff-exclusion-time           2.75       ;The portion of the oad1 task which cannot have an FHST handoff (minutes). 
                                                    ;  The zone starts at the start of the task.
  :oad2-duration                         4.25       ;The duration of the second FHST attidude correction and map (minutes).
  :oad2-handoff-exclusion-time           2.75       ;The portion of the oad2 task which cannot have an FHST handoff (minutes).
                                                    ;  The zone starts at the start of the task.
  :gob-duration                          4.45       ;The duration of fhst FGS overlap interval (minutes).
  :gob-handoff-exclusion-offset          1.86667    ;When the exclusion time starts relative to the start of the GOB task (minutes). 
  :gob-handoff-exclusion-time            2.58333    ;The duration of the gob task which cannot have an FHST handoff (minutes). 
  :gob-prefix                            1.86667    ;The portion of the gob task which can start before fgs visibility (in minutes)
  :fhst-warmup-time                      1.0        ;Minimum overlap time (minutes) between two FHST visibilities required to allow 
                                                    ;  for a handoff of FHST rate control
  :fhst-covers-occultation               t          ;If non-nil, code will model whether or not FHST visibility covers occultation
  :min-fhst-sample-step                  5          ;Smallest allowed roll sampling step for FHST vis (degrees)
  :max-fhst-sample-step                  10          ;Largest  allowed roll sampling step for FHST vis (degrees)
  :fhst-visibility-end-pad               5          ;Pad to compute conservative FHST windows (seconds)
  ;;:fhst-activity-separations '((:rate :oad1 96 780)     ;Start-to-Start min and max separations in seconds between 2 Gyro FHST activities
  ;;                             (:oad1 :oad2 475 4905)   ;See OPR 54891 for complete details on this parameter
  ;;                             (:oad2 :gob  255 1545)
  ;;                             (:rate :gob  826 7230))
  ;; 
  ;; END OF 2-GYRO SPECIFIC CONSTRAINT-SET PARAMETER SECTION 

  ;;
  ;;
  ;;
  ;;  HST ORBIT MODEL
  ;;
  :orbit-model                       "dec07"   ;; orbit model name -- does not 
	;; operate on anything--just text of when model updated.

  :st-information '(:inclination       28.470  ;; degrees
                    :time-asc-node  10952.5    ;; hjd--hubble julian date
                    :RA-asc-node       59.6    ;; degrees
                    :regression-rate   -6.4936 ;; degrees per day
                    :period            95.56   ;; minutes
                    :semimajor-axis  6924.0 )  ;; kilometers

  ;; SMA & period should both represent a floor over the planning interval.
  ;; time-asc-node, RA-asc-node, and regression rate, SMA & period are 
  ;; produced by /data/lrp/sw/scripts/plane_projector program.
  ;; The period is computed from (semimajor-axis/331.24915)^1.5 ... 
  ;; Larson & Wertz + Boden, eq. 6-11.
  ;; :time-of-asc-node is specified in the special 
  ;; hubble-julian-date format of JD - 2444000.0
  ;; RA-asc-node is given at :time-asc-node.
  ;;
  ;; Notes on orbit model apr08-phase2 (aka dec07):  The orbit model
  ;; created in december 2007 assumes a 15-km SM4 reboost with the 
  ;; nodal regression rate, and node optimized for middle-of-cycle 
  ;; circa 2009.121.  However, to preserve conservatism in the allowed
  ;; viewing geometry, the period and semimajor axis are chosen as
  ;; minimum out through 2010.190 assuming zero reboost during SM4.
  ;; A solar drag model equivalent to the previous sun cycle has
  ;; been assumed, replicated out with an 11.08 year periods.   Additionally,
  ;; as has been tradition, the semimajor axis values derived from 
  ;; the fit-cat table are used rather than those from SPSS FDF-derived
  ;; ephemeris information.  These fit-cat values are known to be low
  ;; in comparision to the actual orbit.
  ;;
  ;;
  ;;  END HST ORBIT MODEL
  ;;

  ;;
  ;; TDRS Parameters:
  ;;
  :tdrsw-information '(:longitude      -171.0
		       :period         86164.09054 ;nodal period in minutes
		       :semimajor-axis 42164.69)   ;semi-major axis in kms
  :tdrse-information '(:longitude      -41.0
		       :period         86164.09054 ;nodal period in minutes
		       :semimajor-axis 42164.69)   ;semi-major axis in kms
  ;;
  ;; END TDRS Parameters:
  ;;

  ;;
  ;;
  ;;
  ;;  LUNAR ANGLE LIMITS:
  ;;
  ;; moon avoidance angle
  :moon-angle-table                    '((0 9 0) (9 180 1))
  
  ;;
  ;;  SOLAR ANGLE LIMITS:
  ;;
  ;; sun-angle-restrictions is a table of allowed solar angles and of 
  ;; maximum allowed off nominal rolls.
  ;; 
  ;; 08-04-18, ij:  note that the format of the table below has been
  ;; modified to accommodate OPR 55253 wherein, it was adjudged,
  ;; that the old implementation either did not encompass the desired 
  ;; behavior, or that it was incorrect.
  ;;
  :sun-angle-restrictions             '(*MINUS-INFINITY* (50.0 180.0)
					"95.009" ( 90.0 120.0) 
					"95.054" (150.0 180.0) 
					"95.059" ( 90.0 120.0)
					"95.107" ( 50.0 180.0)
					"00.052" ( 50.3 180.0)
					"04.001" ( 60.3 180.0)	
						;; addition for 2-gyro
					"08.224" ( 50.3 180.0)	
						;; reset for post-sm4-testing 
						;; ijej 07-07-10.
					)  


  ;; The orient-range-table is composed of four time-based independent 
  ;; constraints that will get intersected together to arrive at the 
  ;; min/max orient allowed for a particular sun angle.  The 
  ;; interpretation of the numbers (ie, the direction/how the table is 
  ;; read) is the same as used by SPSS and PASS.  This is an explicit,
  ;; conscious change of the ordering convention from the previous
  ;; implementation of orient-range-table.  See OPR 58333 for the 
  ;; details of how to compute the number for each of the component 
  ;; tables.
  ;;
  :orient-range-table '((:solar-array-shadowing-restriction
  		         t
		         (*minus-infinity*
			  (( 50.0    -22.73    22.73)
			   ( 90.0    -22.73    22.73)
			   ( 93.0    -22.57    22.57)
			   ( 96.0    -22.69    22.69)
			   ( 99.0    -22.92    22.92)
			   (102.0    -23.32    23.32)
			   (105.0    -23.90    23.90)
			   (108.0    -24.60    24.60)
	  		   (111.0    -25.50    25.50)
			   (114.0    -24.76    24.76)
			   (117.0    -23.63    23.63)
			   (120.0    -22.65    22.65)
			   (123.0    -21.75    21.75)
			   (126.0    -20.97    20.97)
			   (129.0    -20.27    20.27)
			   (132.0    -19.64    19.64)
			   (135.0    -19.88    19.88)
			   (138.0    -20.07    20.07)
			   (141.0    -20.66    20.66)
			   (144.0    -21.56    21.56)
			   (147.0    -22.77    22.77)
			   (150.0    -24.45    24.45)
			   (153.0    -26.83    26.83)
			   (156.0    -30.19    30.19)
			   (159.0    -33.75    33.75)
			   (162.0    -39.53    39.53)
			   (165.0    -49.49    49.49)
			   (168.0    -70.03    70.03)
			   (171.0   -180.00   180.00))))
		        (:bay-five-restriction
		         t
		         (*minus-infinity*
			  (( 50.0   -180.00    180.0)
			   ( 90.0    -15.00    180.0)
			   ( 91.0    -15.00    180.0)
			   ( 92.0    -15.01    180.0)
			   ( 93.0    -15.02    180.0)
			   ( 94.0    -15.04    180.0)
			   ( 95.0    -15.06    180.0)
			   ( 96.0    -15.08    180.0)
			   ( 97.0    -15.12    180.0)
			   ( 98.0    -15.15    180.0)
			   ( 99.0    -15.20    180.0)
			   (100.0    -15.25    180.0)
			   (101.0    -15.30    180.0)
			   (102.0    -15.36    180.0)
			   (103.0    -15.43    180.0)
			   (104.0    -15.51    180.0)
			   (105.0    -15.59    180.0)
			   (106.0    -15.69    180.0)
			   (107.0    -15.79    180.0)
			   (108.0    -15.91    180.0)
			   (109.0    -16.03    180.0)
			   (110.0    -16.17    180.0)
			   (111.0    -16.33    180.0)
			   (112.0    -16.50    180.0)
			   (113.0    -16.69    180.0)
			   (114.0    -16.89    180.0)
			   (115.0    -17.12    180.0)
			   (116.0    -17.37    180.0)
			   (117.0    -17.65    180.0)
			   (118.0    -17.95    180.0)
			   (119.0    -18.29    180.0)
			   (120.0    -18.65    180.0)
			   (121.0    -19.05    180.0)
			   (122.0    -19.48    180.0)
			   (123.0    -19.95    180.0)
			   (124.0    -20.46    180.0)
			   (125.0    -21.02    180.0)
			   (126.0    -21.62    180.0)
			   (127.0    -22.26    180.0)
			   (128.0    -22.95    180.0)
			   (129.0    -23.69    180.0)
			   (130.0    -24.48    180.0)
			   (131.0    -25.33    180.0)
			   (132.0    -26.22    180.0)
			   (133.0    -27.17    180.0)
			   (134.0    -28.18    180.0)
			   (135.0    -29.24    180.0)
			   (136.0    -30.00    180.0)
			   (137.0   -180.00    180.0))))
		        (:hst-thermal-restriction
		         t
		         (*minus-infinity*
			  (( 50.0     -5.0     5.0)
			   ( 90.0    -30.0    30.0)
			   (178.0   -180.0   180.0))
			  "05.241"
			  (( 50.0     -5.0     5.0)
			   ( 90.0    -15.0    15.0)
			   (100.0    -30.0    30.0)
			   (179.0   -180.0   180.0))
			  "08.249"
			  (( 50.0     -5.0     5.0)
			   ( 90.0    -30.0    30.0)
			   (178.0   -180.0   180.0))))
		        (:solar-array-incidence-restriction
		         t
		         (*minus-infinity*
			  (( 50.0    -29.4    29.4)
			   ( 51.0    -29.0    29.0)
			   ( 52.0    -28.6    28.6)
			   ( 53.0    -28.2    28.2)
			   ( 54.0    -27.8    27.8)
			   ( 55.0    -27.5    27.5)
			   ( 56.0    -27.2    27.2)
			   ( 57.0    -26.8    26.8)
			   ( 58.0    -26.5    26.5)
			   ( 59.0    -26.3    26.3)
			   ( 60.0    -26.0    26.0)
			   ( 61.0    -25.7    25.7)
			   ( 62.0    -25.5    25.5)
			   ( 63.0    -25.2    25.2)
			   ( 64.0    -25.0    25.0)
			   ( 65.0    -24.8    24.8)
			   ( 66.0    -24.6    24.6)
			   ( 67.0    -24.4    24.4)
			   ( 68.0    -24.2    24.2)
			   ( 69.0    -24.1    24.1)
			   ( 70.0    -23.9    23.9)
			   ( 71.0    -23.8    23.8)
			   ( 72.0    -23.6    23.6)
			   ( 73.0    -23.5    23.5)
			   ( 74.0    -23.4    23.4)
			   ( 75.0    -23.3    23.3)
			   ( 76.0    -23.1    23.1)
			   ( 77.0    -23.0    23.0)
			   ( 78.0    -23.0    23.0)
			   ( 79.0    -22.9    22.9)
			   ( 80.0    -22.8    22.8)
			   ( 81.0    -22.7    22.7)
			   ( 82.0    -22.7    22.7)
			   ( 83.0    -22.6    22.6)
			   ( 84.0    -22.6    22.6)
			   ( 85.0    -22.5    22.5)
			   ( 86.0    -22.5    22.5)
			   ( 87.0    -22.5    22.5)
			   ( 88.0    -22.5    22.5)
			   ( 89.0    -22.5    22.5)
			   ( 90.0    -22.4    22.4)
			   ( 91.0    -22.5    22.5)
			   ( 92.0    -22.5    22.5)
			   ( 93.0    -22.5    22.5)
			   ( 94.0    -22.5    22.5)
			   ( 95.0    -22.5    22.5)
			   ( 96.0    -22.6    22.6)
			   ( 97.0    -22.6    22.6)
			   ( 98.0    -22.7    22.7)
			   ( 99.0    -22.7    22.7)
			   (100.0    -22.8    22.8)
			   (101.0    -22.9    22.9)
			   (102.0    -23.0    23.0)
			   (103.0    -23.0    23.0)
			   (104.0    -23.1    23.1)
			   (105.0    -23.3    23.3)
			   (106.0    -23.4    23.4)
			   (107.0    -23.5    23.5)
			   (108.0    -23.6    23.6)
			   (109.0    -23.8    23.8)
			   (110.0    -23.9    23.9)
			   (111.0    -24.1    24.1)
			   (112.0    -24.2    24.2)
			   (113.0    -24.4    24.4)
			   (114.0    -24.6    24.6)
			   (115.0    -24.8    24.8)
			   (116.0    -25.0    25.0)
			   (117.0    -25.2    25.2)
			   (118.0    -25.5    25.5)
			   (119.0    -25.7    25.7)
			   (120.0    -26.0    26.0)
			   (121.0    -26.3    26.3)
			   (122.0    -26.5    26.5)
			   (123.0    -26.8    26.8)
			   (124.0    -27.2    27.2)
			   (125.0    -27.5    27.5)
			   (126.0    -27.8    27.8)
			   (127.0    -28.2    28.2)
			   (128.0    -28.6    28.6)
			   (129.0    -29.0    29.0)
			   (130.0    -29.4    29.4)
			   (131.0    -29.9    29.9)
			   (132.0    -30.4    30.4)
			   (133.0    -30.9    30.9)
			   (134.0    -31.4    31.4)
			   (135.0    -32.0    32.0)
			   (136.0    -32.5    32.5)
			   (137.0    -33.2    33.2)
			   (138.0    -33.8    33.8)
			   (139.0    -34.5    34.5)
			   (140.0    -35.3    35.3)
			   (141.0    -36.0    36.0)
			   (142.0    -36.9    36.9)
			   (143.0    -37.7    37.7)
			   (144.0    -38.7    38.7)
			   (145.0    -39.7    39.7)
			   (146.0    -40.7    40.7)
			   (147.0    -41.9    41.9)
			   (148.0    -43.1    43.1)
			   (149.0    -44.4    44.4)
			   (150.0    -45.8    45.8)
			   (151.0    -47.3    47.3)
			   (152.0    -49.0    49.0)
			   (153.0    -50.8    50.8)
			   (154.0    -52.7    52.7)
			   (155.0    -54.9    54.9)
			   (156.0    -57.2    57.2)
			   (157.0    -59.8    59.8)
			   (158.0    -62.6    62.6)
			   (159.0    -65.8    65.8)
			   (160.0    -69.4    69.4)
			   (161.0    -73.4    73.4)
			   (162.0    -78.1    78.1)
			   (163.0    -83.5    83.5)
			   (164.0    -89.9    89.9)
			   (165.0    -97.5    97.5)
			   (166.0   -107.2   107.2)
			   (167.0   -119.8   119.8)
			   (168.0   -138.9   138.9)
			   (169.0   -180.0   180.0))
		         "09.117"
		          (( 50.0    -25.5    25.5)
			   ( 51.0    -25.2    25.2)
			   ( 52.0    -24.8    24.8)
			   ( 53.0    -24.5    24.5)
			   ( 54.0    -24.2    24.2)
			   ( 55.0    -23.9    23.9)
			   ( 56.0    -23.6    23.6)
			   ( 57.0    -23.3    23.3)
			   ( 58.0    -23.0    23.0)
			   ( 59.0    -22.8    22.8)
			   ( 60.0    -22.6    22.6)
			   ( 61.0    -22.3    22.3)
			   ( 62.0    -22.1    22.1)
			   ( 63.0    -21.9    21.9)
			   ( 64.0    -21.7    21.7)
			   ( 65.0    -21.5    21.5)
			   ( 66.0    -21.4    21.4)
			   ( 67.0    -21.2    21.2)
			   ( 68.0    -21.0    21.0)
			   ( 69.0    -20.9    20.9)
			   ( 70.0    -20.8    20.8)
			   ( 71.0    -20.6    20.6)
			   ( 72.0    -20.5    20.5)
			   ( 73.0    -20.4    20.4)
			   ( 74.0    -20.3    20.3)
			   ( 75.0    -20.2    20.2)
			   ( 76.0    -20.1    20.1)
			   ( 77.0    -20.0    20.0)
			   ( 78.0    -19.9    19.9)
			   ( 79.0    -19.9    19.9)
			   ( 80.0    -19.8    19.8)
			   ( 81.0    -19.7    19.7)
			   ( 82.0    -19.7    19.7)
			   ( 83.0    -19.6    19.6)
			   ( 84.0    -19.6    19.6)
			   ( 85.0    -19.6    19.6)
			   ( 86.0    -19.5    19.5)
			   ( 87.0    -19.5    19.5)
			   ( 88.0    -19.5    19.5)
			   ( 89.0    -19.5    19.5)
			   ( 90.0    -19.5    19.5)
			   ( 91.0    -19.5    19.5)
			   ( 92.0    -19.5    19.5)
			   ( 93.0    -19.5    19.5)
			   ( 94.0    -19.5    19.5)
			   ( 95.0    -19.6    19.6)
			   ( 96.0    -19.6    19.6)
			   ( 97.0    -19.6    19.6)
			   ( 98.0    -19.7    19.7)
			   ( 99.0    -19.7    19.7)
			   (100.0    -19.8    19.8)
			   (101.0    -19.9    19.9)
			   (102.0    -19.9    19.9)
			   (103.0    -20.0    20.0)
			   (104.0    -20.1    20.1)
			   (105.0    -20.2    20.2)
			   (106.0    -20.3    20.3)
			   (107.0    -20.4    20.4)
			   (108.0    -20.5    20.5)
			   (109.0    -20.6    20.6)
			   (110.0    -20.8    20.8)
			   (111.0    -20.9    20.9)
			   (112.0    -21.0    21.0)
			   (113.0    -21.2    21.2)
			   (114.0    -21.4    21.4)
			   (115.0    -21.5    21.5)
			   (116.0    -21.7    21.7)
			   (117.0    -21.9    21.9)
			   (118.0    -22.1    22.1)
			   (119.0    -22.3    22.3)
			   (120.0    -22.6    22.6)
			   (121.0    -22.8    22.8)
			   (122.0    -23.0    23.0)
			   (123.0    -23.3    23.3)
			   (124.0    -23.6    23.6)
			   (125.0    -23.9    23.9)
			   (126.0    -24.2    24.2)
			   (127.0    -24.5    24.5)
			   (128.0    -24.8    24.8)
			   (129.0    -25.2    25.2)
			   (130.0    -25.5    25.5)
			   (131.0    -25.9    25.9)
			   (132.0    -26.3    26.3)
			   (133.0    -26.8    26.8)
			   (134.0    -27.2    27.2)
			   (135.0    -27.7    27.7)
			   (136.0    -28.2    28.2)
			   (137.0    -28.8    28.8)
			   (138.0    -29.3    29.3)
			   (139.0    -29.9    29.9)
			   (140.0    -30.6    30.6)
			   (141.0    -31.2    31.2)
			   (142.0    -31.9    31.9)
			   (143.0    -32.7    32.7)
			   (144.0    -33.5    33.5)
			   (145.0    -34.3    34.3)
			   (146.0    -35.3    35.3)
			   (147.0    -36.2    36.2)
			   (148.0    -37.3    37.3)
			   (149.0    -38.4    38.4)
			   (150.0    -39.6    39.6)
			   (151.0    -40.9    40.9)
			   (152.0    -42.3    42.3)
			   (153.0    -43.8    43.8)
			   (154.0    -45.5    45.5)
			   (155.0    -47.2    47.2)
			   (156.0    -49.2    49.2)
			   (157.0    -51.4    51.4)
			   (158.0    -53.8    53.8)
			   (159.0    -56.4    56.4)
			   (160.0    -59.4    59.4)
			   (161.0    -62.7    62.7)
			   (162.0    -66.5    66.5)
			   (163.0    -70.8    70.8)
			   (164.0    -75.8    75.8)
			   (165.0    -81.7    81.7)
			   (166.0    -88.9    88.9)
			   (167.0    -97.7    97.7)
			   (168.0   -109.1   109.1)
			   (169.0   -125.1   125.1)
			   (170.0   -154.4   154.4)
			   (171.0   -180.0   180.0))
		         "09.166"
		          (( 50.0    -23.7    23.7)
			   ( 51.0    -23.4    23.4)
			   ( 52.0    -23.0    23.0)
			   ( 53.0    -22.7    22.7)
			   ( 54.0    -22.4    22.4)
			   ( 55.0    -22.1    22.1)
			   ( 56.0    -21.9    21.9)
			   ( 57.0    -21.6    21.6)
			   ( 58.0    -21.4    21.4)
			   ( 59.0    -21.1    21.1)
			   ( 60.0    -20.9    20.9)
			   ( 61.0    -20.7    20.7)
			   ( 62.0    -20.5    20.5)
			   ( 63.0    -20.3    20.3)
			   ( 64.0    -20.2    20.2)
			   ( 65.0    -20.0    20.0)
			   ( 66.0    -19.8    19.8)
			   ( 67.0    -19.7    19.7)
			   ( 68.0    -19.5    19.5)
			   ( 69.0    -19.4    19.4)
			   ( 70.0    -19.3    19.3)
			   ( 71.0    -19.2    19.2)
			   ( 72.0    -19.0    19.0)
			   ( 73.0    -18.9    18.9)
			   ( 74.0    -18.8    18.8)
			   ( 75.0    -18.7    18.7)
			   ( 76.0    -18.7    18.7)
			   ( 77.0    -18.6    18.6)
			   ( 78.0    -18.5    18.5)
			   ( 79.0    -18.4    18.4)
			   ( 80.0    -18.4    18.4)
			   ( 81.0    -18.3    18.3)
			   ( 82.0    -18.3    18.3)
			   ( 83.0    -18.2    18.2)
			   ( 84.0    -18.2    18.2)
			   ( 85.0    -18.2    18.2)
			   ( 86.0    -18.1    18.1)
			   ( 87.0    -18.1    18.1)
			   ( 88.0    -18.1    18.1)
			   ( 89.0    -18.1    18.1)
			   ( 90.0    -18.1    18.1)
			   ( 91.0    -18.1    18.1)
			   ( 92.0    -18.1    18.1)
			   ( 93.0    -18.1    18.1)
			   ( 94.0    -18.1    18.1)
			   ( 95.0    -18.2    18.2)
			   ( 96.0    -18.2    18.2)
			   ( 97.0    -18.2    18.2)
			   ( 98.0    -18.3    18.3)
			   ( 99.0    -18.3    18.3)
			   (100.0    -18.4    18.4)
			   (101.0    -18.4    18.4)
			   (102.0    -18.5    18.5)
			   (103.0    -18.6    18.6)
			   (104.0    -18.7    18.7)
			   (105.0    -18.7    18.7)
			   (106.0    -18.8    18.8)
			   (107.0    -18.9    18.9)
			   (108.0    -19.0    19.0)
			   (109.0    -19.2    19.2)
			   (110.0    -19.3    19.3)
			   (111.0    -19.4    19.4)
			   (112.0    -19.5    19.5)
			   (113.0    -19.7    19.7)
			   (114.0    -19.8    19.8)
			   (115.0    -20.0    20.0)
			   (116.0    -20.2    20.2)
			   (117.0    -20.3    20.3)
			   (118.0    -20.5    20.5)
			   (119.0    -20.7    20.7)
			   (120.0    -20.9    20.9)
			   (121.0    -21.1    21.1)
			   (122.0    -21.4    21.4)
			   (123.0    -21.6    21.6)
			   (124.0    -21.9    21.9)
			   (125.0    -22.1    22.1)
			   (126.0    -22.4    22.4)
			   (127.0    -22.7    22.7)
			   (128.0    -23.0    23.0)
			   (129.0    -23.4    23.4)
			   (130.0    -23.7    23.7)
			   (131.0    -24.1    24.1)
			   (132.0    -24.4    24.4)
			   (133.0    -24.8    24.8)
			   (134.0    -25.3    25.3)
			   (135.0    -25.7    25.7)
			   (136.0    -26.2    26.2)
			   (137.0    -26.7    26.7)
			   (138.0    -27.2    27.2)
			   (139.0    -27.7    27.7)
			   (140.0    -28.3    28.3)
			   (141.0    -28.9    28.9)
			   (142.0    -29.6    29.6)
			   (143.0    -30.3    30.3)
			   (144.0    -31.0    31.0)
			   (145.0    -31.8    31.8)
			   (146.0    -32.7    32.7)
			   (147.0    -33.6    33.6)
			   (148.0    -34.5    34.5)
			   (149.0    -35.6    35.6)
			   (150.0    -36.7    36.7)
			   (151.0    -37.9    37.9)
			   (152.0    -39.2    39.2)
			   (153.0    -40.5    40.5)
			   (154.0    -42.1    42.1)
			   (155.0    -43.7    43.7)
			   (156.0    -45.5    45.5)
			   (157.0    -47.5    47.5)
			   (158.0    -49.7    49.7)
			   (159.0    -52.1    52.1)
			   (160.0    -54.8    54.8)
			   (161.0    -57.8    57.8)
			   (162.0    -61.2    61.2)
			   (163.0    -65.1    65.1)
			   (164.0    -69.6    69.6)
			   (165.0    -74.9    74.9)
			   (166.0    -81.1    81.1)
			   (167.0    -88.7    88.7)
			   (168.0    -98.3    98.3)
			   (169.0   -111.0   111.0)
			   (170.0   -129.9   129.9)
			   (171.0   -180.0   180.0))
		         "09.201"
		          (( 50.0    -24.6    24.6)
			   ( 51.0    -24.3    24.3)
			   ( 52.0    -23.9    23.9)
			   ( 53.0    -23.6    23.6)
			   ( 54.0    -23.3    23.3)
			   ( 55.0    -23.0    23.0)
			   ( 56.0    -22.7    22.7)
			   ( 57.0    -22.5    22.5)
			   ( 58.0    -22.2    22.2)
			   ( 59.0    -22.0    22.0)
			   ( 60.0    -21.7    21.7)
			   ( 61.0    -21.5    21.5)
			   ( 62.0    -21.3    21.3)
			   ( 63.0    -21.1    21.1)
			   ( 64.0    -20.9    20.9)
			   ( 65.0    -20.8    20.8)
			   ( 66.0    -20.6    20.6)
			   ( 67.0    -20.4    20.4)
			   ( 68.0    -20.3    20.3)
			   ( 69.0    -20.2    20.2)
			   ( 70.0    -20.0    20.0)
			   ( 71.0    -19.9    19.9)
			   ( 72.0    -19.8    19.8)
			   ( 73.0    -19.7    19.7)
			   ( 74.0    -19.6    19.6)
			   ( 75.0    -19.5    19.5)
			   ( 76.0    -19.4    19.4)
			   ( 77.0    -19.3    19.3)
			   ( 78.0    -19.2    19.2)
			   ( 79.0    -19.2    19.2)
			   ( 80.0    -19.1    19.1)
			   ( 81.0    -19.0    19.0)
			   ( 82.0    -19.0    19.0)
			   ( 83.0    -18.9    18.9)
			   ( 84.0    -18.9    18.9)
			   ( 85.0    -18.9    18.9)
			   ( 86.0    -18.8    18.8)
			   ( 87.0    -18.8    18.8)
			   ( 88.0    -18.8    18.8)
			   ( 89.0    -18.8    18.8)
			   ( 90.0    -18.8    18.8)
			   ( 91.0    -18.8    18.8)
			   ( 92.0    -18.8    18.8)
			   ( 93.0    -18.8    18.8)
			   ( 94.0    -18.8    18.8)
			   ( 95.0    -18.9    18.9)
			   ( 96.0    -18.9    18.9)
			   ( 97.0    -18.9    18.9)
			   ( 98.0    -19.0    19.0)
			   ( 99.0    -19.0    19.0)
			   (100.0    -19.1    19.1)
			   (101.0    -19.2    19.2)
			   (102.0    -19.2    19.2)
			   (103.0    -19.3    19.3)
			   (104.0    -19.4    19.4)
			   (105.0    -19.5    19.5)
			   (106.0    -19.6    19.6)
			   (107.0    -19.7    19.7)
			   (108.0    -19.8    19.8)
			   (109.0    -19.9    19.9)
			   (110.0    -20.0    20.0)
			   (111.0    -20.2    20.2)
			   (112.0    -20.3    20.3)
			   (113.0    -20.4    20.4)
			   (114.0    -20.6    20.6)
			   (115.0    -20.8    20.8)
			   (116.0    -20.9    20.9)
			   (117.0    -21.1    21.1)
			   (118.0    -21.3    21.3)
			   (119.0    -21.5    21.5)
			   (120.0    -21.7    21.7)
			   (121.0    -22.0    22.0)
			   (122.0    -22.2    22.2)
			   (123.0    -22.5    22.5)
			   (124.0    -22.7    22.7)
			   (125.0    -23.0    23.0)
			   (126.0    -23.3    23.3)
			   (127.0    -23.6    23.6)
			   (128.0    -23.9    23.9)
			   (129.0    -24.3    24.3)
			   (130.0    -24.6    24.6)
			   (131.0    -25.0    25.0)
			   (132.0    -25.4    25.4)
			   (133.0    -25.8    25.8)
			   (134.0    -26.2    26.2)
			   (135.0    -26.7    26.7)
			   (136.0    -27.2    27.2)
			   (137.0    -27.7    27.7)
			   (138.0    -28.3    28.3)
			   (139.0    -28.8    28.8)
			   (140.0    -29.4    29.4)
			   (141.0    -30.1    30.1)
			   (142.0    -30.8    30.8)
			   (143.0    -31.5    31.5)
			   (144.0    -32.3    32.3)
			   (145.0    -33.1    33.1)
			   (146.0    -34.0    34.0)
			   (147.0    -34.9    34.9)
			   (148.0    -35.9    35.9)
			   (149.0    -37.0    37.0)
			   (150.0    -38.1    38.1)
			   (151.0    -39.4    39.4)
			   (152.0    -40.7    40.7)
			   (153.0    -42.2    42.2)
			   (154.0    -43.7    43.7)
			   (155.0    -45.5    45.5)
			   (156.0    -47.4    47.4)
			   (157.0    -49.4    49.4)
			   (158.0    -51.7    51.7)
			   (159.0    -54.2    54.2)
			   (160.0    -57.0    57.0)
			   (161.0    -60.2    60.2)
			   (162.0    -63.8    63.8)
			   (163.0    -67.9    67.9)
			   (164.0    -72.7    72.7)
			   (165.0    -78.3    78.3)
			   (166.0    -84.9    84.9)
			   (167.0    -93.1    93.1)
			   (168.0   -103.5   103.5)
			   (169.0   -117.7   117.7)
			   (170.0   -140.3   140.3)
			   (171.0   -180.0   180.0))
		         "09.250"
		          (( 50.0    -28.2    28.2)
			   ( 51.0    -27.8    27.8)
			   ( 52.0    -27.4    27.4)
			   ( 53.0    -27.0    27.0)
			   ( 54.0    -26.7    26.7)
			   ( 55.0    -26.3    26.3)
			   ( 56.0    -26.0    26.0)
			   ( 57.0    -25.7    25.7)
			   ( 58.0    -25.4    25.4)
			   ( 59.0    -25.1    25.1)
			   ( 60.0    -24.9    24.9)
			   ( 61.0    -24.6    24.6)
			   ( 62.0    -24.4    24.4)
			   ( 63.0    -24.2    24.2)
			   ( 64.0    -24.0    24.0)
			   ( 65.0    -23.8    23.8)
			   ( 66.0    -23.6    23.6)
			   ( 67.0    -23.4    23.4)
			   ( 68.0    -23.2    23.2)
			   ( 69.0    -23.0    23.0)
			   ( 70.0    -22.9    22.9)
			   ( 71.0    -22.8    22.8)
			   ( 72.0    -22.6    22.6)
			   ( 73.0    -22.5    22.5)
			   ( 74.0    -22.4    22.4)
			   ( 75.0    -22.3    22.3)
			   ( 76.0    -22.2    22.2)
			   ( 77.0    -22.1    22.1)
			   ( 78.0    -22.0    22.0)
			   ( 79.0    -21.9    21.9)
			   ( 80.0    -21.8    21.8)
			   ( 81.0    -21.8    21.8)
			   ( 82.0    -21.7    21.7)
			   ( 83.0    -21.7    21.7)
			   ( 84.0    -21.6    21.6)
			   ( 85.0    -21.6    21.6)
			   ( 86.0    -21.6    21.6)
			   ( 87.0    -21.5    21.5)
			   ( 88.0    -21.5    21.5)
			   ( 89.0    -21.5    21.5)
			   ( 90.0    -21.5    21.5)
			   ( 91.0    -21.5    21.5)
			   ( 92.0    -21.5    21.5)
			   ( 93.0    -21.5    21.5)
			   ( 94.0    -21.6    21.6)
			   ( 95.0    -21.6    21.6)
			   ( 96.0    -21.6    21.6)
			   ( 97.0    -21.7    21.7)
			   ( 98.0    -21.7    21.7)
			   ( 99.0    -21.8    21.8)
			   (100.0    -21.8    21.8)
			   (101.0    -21.9    21.9)
			   (102.0    -22.0    22.0)
			   (103.0    -22.1    22.1)
			   (104.0    -22.2    22.2)
			   (105.0    -22.3    22.3)
			   (106.0    -22.4    22.4)
			   (107.0    -22.5    22.5)
			   (108.0    -22.6    22.6)
			   (109.0    -22.8    22.8)
			   (110.0    -22.9    22.9)
			   (111.0    -23.0    23.0)
			   (112.0    -23.2    23.2)
			   (113.0    -23.4    23.4)
			   (114.0    -23.6    23.6)
			   (115.0    -23.8    23.8)
			   (116.0    -24.0    24.0)
			   (117.0    -24.2    24.2)
			   (118.0    -24.4    24.4)
			   (119.0    -24.6    24.6)
			   (120.0    -24.9    24.9)
			   (121.0    -25.1    25.1)
			   (122.0    -25.4    25.4)
			   (123.0    -25.7    25.7)
			   (124.0    -26.0    26.0)
			   (125.0    -26.3    26.3)
			   (126.0    -26.7    26.7)
			   (127.0    -27.0    27.0)
			   (128.0    -27.4    27.4)
			   (129.0    -27.8    27.8)
			   (130.0    -28.2    28.2)
			   (131.0    -28.6    28.6)
			   (132.0    -29.1    29.1)
			   (133.0    -29.6    29.6)
			   (134.0    -30.1    30.1)
			   (135.0    -30.6    30.6)
			   (136.0    -31.2    31.2)
			   (137.0    -31.7    31.7)
			   (138.0    -32.4    32.4)
			   (139.0    -33.0    33.0)
			   (140.0    -33.7    33.7)
			   (141.0    -34.5    34.5)
			   (142.0    -35.3    35.3)
			   (143.0    -36.1    36.1)
			   (144.0    -37.0    37.0)
			   (145.0    -38.0    38.0)
			   (146.0    -39.0    39.0)
			   (147.0    -40.1    40.1)
			   (148.0    -41.2    41.2)
			   (149.0    -42.5    42.5)
			   (150.0    -43.8    43.8)
			   (151.0    -45.3    45.3)
			   (152.0    -46.8    46.8)
			   (153.0    -48.5    48.5)
			   (154.0    -50.4    50.4)
			   (155.0    -52.4    52.4)
			   (156.0    -54.6    54.6)
			   (157.0    -57.0    57.0)
			   (158.0    -59.7    59.7)
			   (159.0    -62.7    62.7)
			   (160.0    -66.1    66.1)
			   (161.0    -69.9    69.9)
			   (162.0    -74.3    74.3)
			   (163.0    -79.3    79.3)
			   (164.0    -85.2    85.2)
			   (165.0    -92.2    92.2)
			   (166.0   -100.9   100.9)
			   (167.0   -112.0   112.0)
			   (168.0   -127.6   127.6)
			   (169.0   -155.7   155.7)
			   (170.0   -180.0   180.0))
		         "09.271"
		          (( 50.0    -29.5    29.5)
			   ( 51.0    -29.1    29.1)
			   ( 52.0    -28.7    28.7)
			   ( 53.0    -28.3    28.3)
			   ( 54.0    -27.9    27.9)
			   ( 55.0    -27.6    27.6)
			   ( 56.0    -27.2    27.2)
			   ( 57.0    -26.9    26.9)
			   ( 58.0    -26.6    26.6)
			   ( 59.0    -26.3    26.3)
			   ( 60.0    -26.0    26.0)
			   ( 61.0    -25.8    25.8)
			   ( 62.0    -25.5    25.5)
			   ( 63.0    -25.3    25.3)
			   ( 64.0    -25.1    25.1)
			   ( 65.0    -24.9    24.9)
			   ( 66.0    -24.7    24.7)
			   ( 67.0    -24.5    24.5)
			   ( 68.0    -24.3    24.3)
			   ( 69.0    -24.1    24.1)
			   ( 70.0    -24.0    24.0)
			   ( 71.0    -23.8    23.8)
			   ( 72.0    -23.7    23.7)
			   ( 73.0    -23.5    23.5)
			   ( 74.0    -23.4    23.4)
			   ( 75.0    -23.3    23.3)
			   ( 76.0    -23.2    23.2)
			   ( 77.0    -23.1    23.1)
			   ( 78.0    -23.0    23.0)
			   ( 79.0    -22.9    22.9)
			   ( 80.0    -22.9    22.9)
			   ( 81.0    -22.8    22.8)
			   ( 82.0    -22.7    22.7)
			   ( 83.0    -22.7    22.7)
			   ( 84.0    -22.6    22.6)
			   ( 85.0    -22.6    22.6)
			   ( 86.0    -22.6    22.6)
			   ( 87.0    -22.5    22.5)
			   ( 88.0    -22.5    22.5)
			   ( 89.0    -22.5    22.5)
			   ( 90.0    -22.5    22.5)
			   ( 91.0    -22.5    22.5)
			   ( 92.0    -22.5    22.5)
			   ( 93.0    -22.5    22.5)
			   ( 94.0    -22.6    22.6)
			   ( 95.0    -22.6    22.6)
			   ( 96.0    -22.6    22.6)
			   ( 97.0    -22.7    22.7)
			   ( 98.0    -22.7    22.7)
			   ( 99.0    -22.8    22.8)
			   (100.0    -22.9    22.9)
			   (101.0    -22.9    22.9)
			   (102.0    -23.0    23.0)
			   (103.0    -23.1    23.1)
			   (104.0    -23.2    23.2)
			   (105.0    -23.3    23.3)
			   (106.0    -23.4    23.4)
			   (107.0    -23.5    23.5)
			   (108.0    -23.7    23.7)
			   (109.0    -23.8    23.8)
			   (110.0    -24.0    24.0)
			   (111.0    -24.1    24.1)
			   (112.0    -24.3    24.3)
			   (113.0    -24.5    24.5)
			   (114.0    -24.7    24.7)
			   (115.0    -24.9    24.9)
			   (116.0    -25.1    25.1)
			   (117.0    -25.3    25.3)
			   (118.0    -25.5    25.5)
			   (119.0    -25.8    25.8)
			   (120.0    -26.0    26.0)
			   (121.0    -26.3    26.3)
			   (122.0    -26.6    26.6)
			   (123.0    -26.9    26.9)
			   (124.0    -27.2    27.2)
			   (125.0    -27.6    27.6)
			   (126.0    -27.9    27.9)
			   (127.0    -28.3    28.3)
			   (128.0    -28.7    28.7)
			   (129.0    -29.1    29.1)
			   (130.0    -29.5    29.5)
			   (131.0    -30.0    30.0)
			   (132.0    -30.4    30.4)
			   (133.0    -30.9    30.9)
			   (134.0    -31.5    31.5)
			   (135.0    -32.0    32.0)
			   (136.0    -32.6    32.6)
			   (137.0    -33.2    33.2)
			   (138.0    -33.9    33.9)
			   (139.0    -34.6    34.6)
			   (140.0    -35.3    35.3)
			   (141.0    -36.1    36.1)
			   (142.0    -36.9    36.9)
			   (143.0    -37.8    37.8)
			   (144.0    -38.8    38.8)
			   (145.0    -39.8    39.8)
			   (146.0    -40.8    40.8)
			   (147.0    -42.0    42.0)
			   (148.0    -43.2    43.2)
			   (149.0    -44.5    44.5)
			   (150.0    -45.9    45.9)
			   (151.0    -47.5    47.5)
			   (152.0    -49.1    49.1)
			   (153.0    -50.9    50.9)
			   (154.0    -52.9    52.9)
			   (155.0    -55.0    55.0)
			   (156.0    -57.3    57.3)
			   (157.0    -59.9    59.9)
			   (158.0    -62.8    62.8)
			   (159.0    -66.0    66.0)
			   (160.0    -69.6    69.6)
			   (161.0    -73.6    73.6)
			   (162.0    -78.3    78.3)
			   (163.0    -83.7    83.7)
			   (164.0    -90.1    90.1)
			   (165.0    -97.8    97.8)
			   (166.0   -107.5   107.5)
			   (167.0   -120.3   120.3)
			   (168.0   -139.5   139.5)
			   (169.0   -180.0   180.0))
		         "10.088"
		          (( 50.0    -26.5    26.5)
			   ( 51.0    -26.1    26.1)
			   ( 52.0    -25.7    25.7)
			   ( 53.0    -25.4    25.4)
			   ( 54.0    -25.0    25.0)
			   ( 55.0    -24.7    24.7)
			   ( 56.0    -24.4    24.4)
			   ( 57.0    -24.1    24.1)
			   ( 58.0    -23.9    23.9)
			   ( 59.0    -23.6    23.6)
			   ( 60.0    -23.4    23.4)
			   ( 61.0    -23.1    23.1)
			   ( 62.0    -22.9    22.9)
			   ( 63.0    -22.7    22.7)
			   ( 64.0    -22.5    22.5)
			   ( 65.0    -22.3    22.3)
			   ( 66.0    -22.1    22.1)
			   ( 67.0    -22.0    22.0)
			   ( 68.0    -21.8    21.8)
			   ( 69.0    -21.7    21.7)
			   ( 70.0    -21.5    21.5)
			   ( 71.0    -21.4    21.4)
			   ( 72.0    -21.3    21.3)
			   ( 73.0    -21.1    21.1)
			   ( 74.0    -21.0    21.0)
			   ( 75.0    -20.9    20.9)
			   ( 76.0    -20.8    20.8)
			   ( 77.0    -20.7    20.7)
			   ( 78.0    -20.7    20.7)
			   ( 79.0    -20.6    20.6)
			   ( 80.0    -20.5    20.5)
			   ( 81.0    -20.5    20.5)
			   ( 82.0    -20.4    20.4)
			   ( 83.0    -20.4    20.4)
			   ( 84.0    -20.3    20.3)
			   ( 85.0    -20.3    20.3)
			   ( 86.0    -20.2    20.2)
			   ( 87.0    -20.2    20.2)
			   ( 88.0    -20.2    20.2)
			   ( 89.0    -20.2    20.2)
			   ( 90.0    -20.2    20.2)
			   ( 91.0    -20.2    20.2)
			   ( 92.0    -20.2    20.2)
			   ( 93.0    -20.2    20.2)
			   ( 94.0    -20.2    20.2)
			   ( 95.0    -20.3    20.3)
			   ( 96.0    -20.3    20.3)
			   ( 97.0    -20.4    20.4)
			   ( 98.0    -20.4    20.4)
			   ( 99.0    -20.5    20.5)
			   (100.0    -20.5    20.5)
			   (101.0    -20.6    20.6)
			   (102.0    -20.7    20.7)
			   (103.0    -20.7    20.7)
			   (104.0    -20.8    20.8)
			   (105.0    -20.9    20.9)
			   (106.0    -21.0    21.0)
			   (107.0    -21.1    21.1)
			   (108.0    -21.3    21.3)
			   (109.0    -21.4    21.4)
			   (110.0    -21.5    21.5)
			   (111.0    -21.7    21.7)
			   (112.0    -21.8    21.8)
			   (113.0    -22.0    22.0)
			   (114.0    -22.1    22.1)
			   (115.0    -22.3    22.3)
			   (116.0    -22.5    22.5)
			   (117.0    -22.7    22.7)
			   (118.0    -22.9    22.9)
			   (119.0    -23.1    23.1)
			   (120.0    -23.4    23.4)
			   (121.0    -23.6    23.6)
			   (122.0    -23.9    23.9)
			   (123.0    -24.1    24.1)
			   (124.0    -24.4    24.4)
			   (125.0    -24.7    24.7)
			   (126.0    -25.0    25.0)
			   (127.0    -25.4    25.4)
			   (128.0    -25.7    25.7)
			   (129.0    -26.1    26.1)
			   (130.0    -26.5    26.5)
			   (131.0    -26.9    26.9)
			   (132.0    -27.3    27.3)
			   (133.0    -27.7    27.7)
			   (134.0    -28.2    28.2)
			   (135.0    -28.7    28.7)
			   (136.0    -29.2    29.2)
			   (137.0    -29.8    29.8)
			   (138.0    -30.4    30.4)
			   (139.0    -31.0    31.0)
			   (140.0    -31.7    31.7)
			   (141.0    -32.4    32.4)
			   (142.0    -33.1    33.1)
			   (143.0    -33.9    33.9)
			   (144.0    -34.7    34.7)
			   (145.0    -35.6    35.6)
			   (146.0    -36.6    36.6)
			   (147.0    -37.6    37.6)
			   (148.0    -38.7    38.7)
			   (149.0    -39.8    39.8)
			   (150.0    -41.1    41.1)
			   (151.0    -42.4    42.4)
			   (152.0    -43.9    43.9)
			   (153.0    -45.4    45.4)
			   (154.0    -47.2    47.2)
			   (155.0    -49.0    49.0)
			   (156.0    -51.1    51.1)
			   (157.0    -53.3    53.3)
			   (158.0    -55.8    55.8)
			   (159.0    -58.6    58.6)
			   (160.0    -61.7    61.7)
			   (161.0    -65.2    65.2)
			   (162.0    -69.2    69.2)
			   (163.0    -73.7    73.7)
			   (164.0    -79.0    79.0)
			   (165.0    -85.3    85.3)
			   (166.0    -92.9    92.9)
			   (167.0   -102.4   102.4)
			   (168.0   -115.0   115.0)
			   (169.0   -133.6   133.6)
			   (170.0   -180.0   180.0))
		         "10.137"
		          (( 50.0    -22.8    22.8)
			   ( 51.0    -22.4    22.4)
			   ( 52.0    -22.1    22.1)
			   ( 53.0    -21.8    21.8)
			   ( 54.0    -21.6    21.6)
			   ( 55.0    -21.3    21.3)
			   ( 56.0    -21.0    21.0)
			   ( 57.0    -20.8    20.8)
			   ( 58.0    -20.5    20.5)
			   ( 59.0    -20.3    20.3)
			   ( 60.0    -20.1    20.1)
			   ( 61.0    -19.9    19.9)
			   ( 62.0    -19.7    19.7)
			   ( 63.0    -19.5    19.5)
			   ( 64.0    -19.4    19.4)
			   ( 65.0    -19.2    19.2)
			   ( 66.0    -19.1    19.1)
			   ( 67.0    -18.9    18.9)
			   ( 68.0    -18.8    18.8)
			   ( 69.0    -18.6    18.6)
			   ( 70.0    -18.5    18.5)
			   ( 71.0    -18.4    18.4)
			   ( 72.0    -18.3    18.3)
			   ( 73.0    -18.2    18.2)
			   ( 74.0    -18.1    18.1)
			   ( 75.0    -18.0    18.0)
			   ( 76.0    -17.9    17.9)
			   ( 77.0    -17.9    17.9)
			   ( 78.0    -17.8    17.8)
			   ( 79.0    -17.7    17.7)
			   ( 80.0    -17.7    17.7)
			   ( 81.0    -17.6    17.6)
			   ( 82.0    -17.6    17.6)
			   ( 83.0    -17.5    17.5)
			   ( 84.0    -17.5    17.5)
			   ( 85.0    -17.5    17.5)
			   ( 86.0    -17.4    17.4)
			   ( 87.0    -17.4    17.4)
			   ( 88.0    -17.4    17.4)
			   ( 89.0    -17.4    17.4)
			   ( 90.0    -17.4    17.4)
			   ( 91.0    -17.4    17.4)
			   ( 92.0    -17.4    17.4)
			   ( 93.0    -17.4    17.4)
			   ( 94.0    -17.4    17.4)
			   ( 95.0    -17.5    17.5)
			   ( 96.0    -17.5    17.5)
			   ( 97.0    -17.5    17.5)
			   ( 98.0    -17.6    17.6)
			   ( 99.0    -17.6    17.6)
			   (100.0    -17.7    17.7)
			   (101.0    -17.7    17.7)
			   (102.0    -17.8    17.8)
			   (103.0    -17.9    17.9)
			   (104.0    -17.9    17.9)
			   (105.0    -18.0    18.0)
			   (106.0    -18.1    18.1)
			   (107.0    -18.2    18.2)
			   (108.0    -18.3    18.3)
			   (109.0    -18.4    18.4)
			   (110.0    -18.5    18.5)
			   (111.0    -18.6    18.6)
			   (112.0    -18.8    18.8)
			   (113.0    -18.9    18.9)
			   (114.0    -19.1    19.1)
			   (115.0    -19.2    19.2)
			   (116.0    -19.4    19.4)
			   (117.0    -19.5    19.5)
			   (118.0    -19.7    19.7)
			   (119.0    -19.9    19.9)
			   (120.0    -20.1    20.1)
			   (121.0    -20.3    20.3)
			   (122.0    -20.5    20.5)
			   (123.0    -20.8    20.8)
			   (124.0    -21.0    21.0)
			   (125.0    -21.3    21.3)
			   (126.0    -21.6    21.6)
			   (127.0    -21.8    21.8)
			   (128.0    -22.1    22.1)
			   (129.0    -22.4    22.4)
			   (130.0    -22.8    22.8)
			   (131.0    -23.1    23.1)
			   (132.0    -23.5    23.5)
			   (133.0    -23.9    23.9)
			   (134.0    -24.3    24.3)
			   (135.0    -24.7    24.7)
			   (136.0    -25.2    25.2)
			   (137.0    -25.6    25.6)
			   (138.0    -26.1    26.1)
			   (139.0    -26.7    26.7)
			   (140.0    -27.2    27.2)
			   (141.0    -27.8    27.8)
			   (142.0    -28.4    28.4)
			   (143.0    -29.1    29.1)
			   (144.0    -29.8    29.8)
			   (145.0    -30.6    30.6)
			   (146.0    -31.4    31.4)
			   (147.0    -32.2    32.2)
			   (148.0    -33.2    33.2)
			   (149.0    -34.2    34.2)
			   (150.0    -35.2    35.2)
			   (151.0    -36.4    36.4)
			   (152.0    -37.6    37.6)
			   (153.0    -38.9    38.9)
			   (154.0    -40.4    40.4)
			   (155.0    -41.9    41.9)
			   (156.0    -43.7    43.7)
			   (157.0    -45.6    45.6)
			   (158.0    -47.6    47.6)
			   (159.0    -49.9    49.9)
			   (160.0    -52.5    52.5)
			   (161.0    -55.4    55.4)
			   (162.0    -58.6    58.6)
			   (163.0    -62.3    62.3)
			   (164.0    -66.6    66.6)
			   (165.0    -71.5    71.5)
			   (166.0    -77.4    77.4)
			   (167.0    -84.5    84.5)
			   (168.0    -93.4    93.4)
			   (169.0   -104.9   104.9)
			   (170.0   -121.2   121.2)
		           (171.0   -150.4   150.4)	 
			   (172.0   -180.0   180.0))	 
		         "10.179"
		          (( 50.0    -21.9    21.9)
			   ( 51.0    -21.5    21.5)
			   ( 52.0    -21.2    21.2)
			   ( 53.0    -21.0    21.0)
			   ( 54.0    -20.7    20.7)
			   ( 55.0    -20.4    20.4)
			   ( 56.0    -20.2    20.2)
			   ( 57.0    -19.9    19.9)
			   ( 58.0    -19.7    19.7)
			   ( 59.0    -19.5    19.5)
			   ( 60.0    -19.3    19.3)
			   ( 61.0    -19.1    19.1)
			   ( 62.0    -18.9    18.9)
			   ( 63.0    -18.8    18.8)
			   ( 64.0    -18.6    18.6)
			   ( 65.0    -18.4    18.4)
			   ( 66.0    -18.3    18.3)
			   ( 67.0    -18.2    18.2)
			   ( 68.0    -18.0    18.0)
			   ( 69.0    -17.9    17.9)
			   ( 70.0    -17.8    17.8)
			   ( 71.0    -17.7    17.7)
			   ( 72.0    -17.6    17.6)
			   ( 73.0    -17.5    17.5)
			   ( 74.0    -17.4    17.4)
			   ( 75.0    -17.3    17.3)
			   ( 76.0    -17.2    17.2)
			   ( 77.0    -17.1    17.1)
			   ( 78.0    -17.1    17.1)
			   ( 79.0    -17.0    17.0)
			   ( 80.0    -17.0    17.0)
			   ( 81.0    -16.9    16.9)
			   ( 82.0    -16.9    16.9)
			   ( 83.0    -16.8    16.8)
			   ( 84.0    -16.8    16.8)
			   ( 85.0    -16.8    16.8)
			   ( 86.0    -16.7    16.7)
			   ( 87.0    -16.7    16.7)
			   ( 88.0    -16.7    16.7)
			   ( 89.0    -16.7    16.7)
			   ( 90.0    -16.7    16.7)
			   ( 91.0    -16.7    16.7)
			   ( 92.0    -16.7    16.7)
			   ( 93.0    -16.7    16.7)
			   ( 94.0    -16.7    16.7)
			   ( 95.0    -16.8    16.8)
			   ( 96.0    -16.8    16.8)
			   ( 97.0    -16.8    16.8)
			   ( 98.0    -16.9    16.9)
			   ( 99.0    -16.9    16.9)
			   (100.0    -17.0    17.0)
			   (101.0    -17.0    17.0)
			   (102.0    -17.1    17.1)
			   (103.0    -17.1    17.1)
			   (104.0    -17.2    17.2)
			   (105.0    -17.3    17.3)
			   (106.0    -17.4    17.4)
			   (107.0    -17.5    17.5)
			   (108.0    -17.6    17.6)
			   (109.0    -17.7    17.7)
			   (110.0    -17.8    17.8)
			   (111.0    -17.9    17.9)
			   (112.0    -18.0    18.0)
			   (113.0    -18.2    18.2)
			   (114.0    -18.3    18.3)
			   (115.0    -18.4    18.4)
			   (116.0    -18.6    18.6)
			   (117.0    -18.8    18.8)
			   (118.0    -18.9    18.9)
			   (119.0    -19.1    19.1)
			   (120.0    -19.3    19.3)
			   (121.0    -19.5    19.5)
			   (122.0    -19.7    19.7)
			   (123.0    -19.9    19.9)
			   (124.0    -20.2    20.2)
			   (125.0    -20.4    20.4)
			   (126.0    -20.7    20.7)
			   (127.0    -21.0    21.0)
			   (128.0    -21.2    21.2)
			   (129.0    -21.5    21.5)
			   (130.0    -21.9    21.9)
			   (131.0    -22.2    22.2)
			   (132.0    -22.5    22.5)
			   (133.0    -22.9    22.9)
			   (134.0    -23.3    23.3)
			   (135.0    -23.7    23.7)
			   (136.0    -24.1    24.1)
			   (137.0    -24.6    24.6)
			   (138.0    -25.1    25.1)
			   (139.0    -25.6    25.6)
			   (140.0    -26.1    26.1)
			   (141.0    -26.7    26.7)
			   (142.0    -27.3    27.3)
			   (143.0    -27.9    27.9)
			   (144.0    -28.6    28.6)
			   (145.0    -29.3    29.3)
			   (146.0    -30.1    30.1)
			   (147.0    -30.9    30.9)
			   (148.0    -31.8    31.8)
			   (149.0    -32.8    32.8)
			   (150.0    -33.8    33.8)
			   (151.0    -34.9    34.9)
			   (152.0    -36.0    36.0)
			   (153.0    -37.3    37.3)
			   (154.0    -38.7    38.7)
			   (155.0    -40.2    40.2)
			   (156.0    -41.8    41.8)
			   (157.0    -43.6    43.6)
			   (158.0    -45.6    45.6)
			   (159.0    -47.8    47.8)
			   (160.0    -50.2    50.2)
			   (161.0    -53.0    53.0)
			   (162.0    -56.1    56.1)
			   (163.0    -59.6    59.6)
			   (164.0    -63.6    63.6)
			   (165.0    -68.3    68.3)
			   (166.0    -73.8    73.8)
			   (167.0    -80.4    80.4)
			   (168.0    -88.6    88.6)
			   (169.0    -99.1    99.1)
			   (170.0   -113.5   113.5)
		           (171.0   -136.3   136.3)	 
			   (172.0   -180.0   180.0))	 
		         "10.221"
		          (( 50.0    -24.2    24.2)
			   ( 51.0    -23.9    23.9)
			   ( 52.0    -23.5    23.5)
			   ( 53.0    -23.2    23.2)
			   ( 54.0    -22.9    22.9)
			   ( 55.0    -22.6    22.6)
			   ( 56.0    -22.4    22.4)
			   ( 57.0    -22.1    22.1)
			   ( 58.0    -21.9    21.9)
			   ( 59.0    -21.6    21.6)
			   ( 60.0    -21.4    21.4)
			   ( 61.0    -21.2    21.2)
			   ( 62.0    -21.0    21.0)
			   ( 63.0    -20.8    20.8)
			   ( 64.0    -20.6    20.6)
			   ( 65.0    -20.4    20.4)
			   ( 66.0    -20.3    20.3)
			   ( 67.0    -20.1    20.1)
			   ( 68.0    -20.0    20.0)
			   ( 69.0    -19.8    19.8)
			   ( 70.0    -19.7    19.7)
			   ( 71.0    -19.6    19.6)
			   ( 72.0    -19.5    19.5)
			   ( 73.0    -19.4    19.4)
			   ( 74.0    -19.3    19.3)
			   ( 75.0    -19.2    19.2)
			   ( 76.0    -19.1    19.1)
			   ( 77.0    -19.0    19.0)
			   ( 78.0    -18.9    18.9)
			   ( 79.0    -18.8    18.8)
			   ( 80.0    -18.8    18.8)
			   ( 81.0    -18.7    18.7)
			   ( 82.0    -18.7    18.7)
			   ( 83.0    -18.6    18.6)
			   ( 84.0    -18.6    18.6)
			   ( 85.0    -18.6    18.6)
			   ( 86.0    -18.5    18.5)
			   ( 87.0    -18.5    18.5)
			   ( 88.0    -18.5    18.5)
			   ( 89.0    -18.5    18.5)
			   ( 90.0    -18.5    18.5)
			   ( 91.0    -18.5    18.5)
			   ( 92.0    -18.5    18.5)
			   ( 93.0    -18.5    18.5)
			   ( 94.0    -18.5    18.5)
			   ( 95.0    -18.6    18.6)
			   ( 96.0    -18.6    18.6)
			   ( 97.0    -18.6    18.6)
			   ( 98.0    -18.7    18.7)
			   ( 99.0    -18.7    18.7)
			   (100.0    -18.8    18.8)
			   (101.0    -18.8    18.8)
			   (102.0    -18.9    18.9)
			   (103.0    -19.0    19.0)
			   (104.0    -19.1    19.1)
			   (105.0    -19.2    19.2)
			   (106.0    -19.3    19.3)
			   (107.0    -19.4    19.4)
			   (108.0    -19.5    19.5)
			   (109.0    -19.6    19.6)
			   (110.0    -19.7    19.7)
			   (111.0    -19.8    19.8)
			   (112.0    -20.0    20.0)
			   (113.0    -20.1    20.1)
			   (114.0    -20.3    20.3)
			   (115.0    -20.4    20.4)
			   (116.0    -20.6    20.6)
			   (117.0    -20.8    20.8)
			   (118.0    -21.0    21.0)
			   (119.0    -21.2    21.2)
			   (120.0    -21.4    21.4)
			   (121.0    -21.6    21.6)
			   (122.0    -21.9    21.9)
			   (123.0    -22.1    22.1)
			   (124.0    -22.4    22.4)
			   (125.0    -22.6    22.6)
			   (126.0    -22.9    22.9)
			   (127.0    -23.2    23.2)
			   (128.0    -23.5    23.5)
			   (129.0    -23.9    23.9)
			   (130.0    -24.2    24.2)
			   (131.0    -24.6    24.6)
			   (132.0    -25.0    25.0)
			   (133.0    -25.4    25.4)
			   (134.0    -25.8    25.8)
			   (135.0    -26.3    26.3)
			   (136.0    -26.8    26.8)
			   (137.0    -27.3    27.3)
			   (138.0    -27.8    27.8)
			   (139.0    -28.4    28.4)
			   (140.0    -29.0    29.0)
			   (141.0    -29.6    29.6)
			   (142.0    -30.3    30.3)
			   (143.0    -31.0    31.0)
			   (144.0    -31.7    31.7)
			   (145.0    -32.5    32.5)
			   (146.0    -33.4    33.4)
			   (147.0    -34.3    34.3)
			   (148.0    -35.3    35.3)
			   (149.0    -36.4    36.4)
			   (150.0    -37.5    37.5)
			   (151.0    -38.7    38.7)
			   (152.0    -40.0    40.0)
			   (153.0    -41.5    41.5)
			   (154.0    -43.0    43.0)
			   (155.0    -44.7    44.7)
			   (156.0    -46.6    46.6)
			   (157.0    -48.6    48.6)
			   (158.0    -50.8    50.8)
			   (159.0    -53.3    53.3)
			   (160.0    -56.1    56.1)
			   (161.0    -59.2    59.2)
			   (162.0    -62.7    62.7)
			   (163.0    -66.7    66.7)
			   (164.0    -71.3    71.3)
			   (165.0    -76.8    76.8)
			   (166.0    -83.3    83.3)
			   (167.0    -91.2    91.2)
			   (168.0   -101.3   101.3)
			   (169.0   -114.8   114.8)
			   (170.0   -135.5   135.5)
		           (171.0   -180.0   180.0))	 
		         "10.270"
		          (( 50.0    -28.2    28.2)
			   ( 51.0    -27.8    27.8)
			   ( 52.0    -27.4    27.4)
			   ( 53.0    -27.0    27.0)
			   ( 54.0    -26.7    26.7)
			   ( 55.0    -26.3    26.3)
			   ( 56.0    -26.0    26.0)
			   ( 57.0    -25.7    25.7)
			   ( 58.0    -25.4    25.4)
			   ( 59.0    -25.1    25.1)
			   ( 60.0    -24.9    24.9)
			   ( 61.0    -24.6    24.6)
			   ( 62.0    -24.4    24.4)
			   ( 63.0    -24.2    24.2)
			   ( 64.0    -24.0    24.0)
			   ( 65.0    -23.8    23.8)
			   ( 66.0    -23.6    23.6)
			   ( 67.0    -23.4    23.4)
			   ( 68.0    -23.2    23.2)
			   ( 69.0    -23.0    23.0)
			   ( 70.0    -22.9    22.9)
			   ( 71.0    -22.8    22.8)
			   ( 72.0    -22.6    22.6)
			   ( 73.0    -22.5    22.5)
			   ( 74.0    -22.4    22.4)
			   ( 75.0    -22.3    22.3)
			   ( 76.0    -22.2    22.2)
			   ( 77.0    -22.1    22.1)
			   ( 78.0    -22.0    22.0)
			   ( 79.0    -21.9    21.9)
			   ( 80.0    -21.8    21.8)
			   ( 81.0    -21.8    21.8)
			   ( 82.0    -21.7    21.7)
			   ( 83.0    -21.7    21.7)
			   ( 84.0    -21.6    21.6)
			   ( 85.0    -21.6    21.6)
			   ( 86.0    -21.6    21.6)
			   ( 87.0    -21.5    21.5)
			   ( 88.0    -21.5    21.5)
			   ( 89.0    -21.5    21.5)
			   ( 90.0    -21.5    21.5)
			   ( 91.0    -21.5    21.5)
			   ( 92.0    -21.5    21.5)
			   ( 93.0    -21.5    21.5)
			   ( 94.0    -21.6    21.6)
			   ( 95.0    -21.6    21.6)
			   ( 96.0    -21.6    21.6)
			   ( 97.0    -21.7    21.7)
			   ( 98.0    -21.7    21.7)
			   ( 99.0    -21.8    21.8)
			   (100.0    -21.8    21.8)
			   (101.0    -21.9    21.9)
			   (102.0    -22.0    22.0)
			   (103.0    -22.1    22.1)
			   (104.0    -22.2    22.2)
			   (105.0    -22.3    22.3)
			   (106.0    -22.4    22.4)
			   (107.0    -22.5    22.5)
			   (108.0    -22.6    22.6)
			   (109.0    -22.8    22.8)
			   (110.0    -22.9    22.9)
			   (111.0    -23.0    23.0)
			   (112.0    -23.2    23.2)
			   (113.0    -23.4    23.4)
			   (114.0    -23.6    23.6)
			   (115.0    -23.8    23.8)
			   (116.0    -24.0    24.0)
			   (117.0    -24.2    24.2)
			   (118.0    -24.4    24.4)
			   (119.0    -24.6    24.6)
			   (120.0    -24.9    24.9)
			   (121.0    -25.1    25.1)
			   (122.0    -25.4    25.4)
			   (123.0    -25.7    25.7)
			   (124.0    -26.0    26.0)
			   (125.0    -26.3    26.3)
			   (126.0    -26.7    26.7)
			   (127.0    -27.0    27.0)
			   (128.0    -27.4    27.4)
			   (129.0    -27.8    27.8)
			   (130.0    -28.2    28.2)
			   (131.0    -28.6    28.6)
			   (132.0    -29.1    29.1)
			   (133.0    -29.6    29.6)
			   (134.0    -30.1    30.1)
			   (135.0    -30.6    30.6)
			   (136.0    -31.2    31.2)
			   (137.0    -31.7    31.7)
			   (138.0    -32.4    32.4)
			   (139.0    -33.0    33.0)
			   (140.0    -33.7    33.7)
			   (141.0    -34.5    34.5)
			   (142.0    -35.3    35.3)
			   (143.0    -36.1    36.1)
			   (144.0    -37.0    37.0)
			   (145.0    -38.0    38.0)
			   (146.0    -39.0    39.0)
			   (147.0    -40.1    40.1)
			   (148.0    -41.2    41.2)
			   (149.0    -42.5    42.5)
			   (150.0    -43.8    43.8)
			   (151.0    -45.3    45.3)
			   (152.0    -46.8    46.8)
			   (153.0    -48.5    48.5)
			   (154.0    -50.4    50.4)
			   (155.0    -52.4    52.4)
			   (156.0    -54.6    54.6)
			   (157.0    -57.0    57.0)
			   (158.0    -59.7    59.7)
			   (159.0    -62.7    62.7)
			   (160.0    -66.1    66.1)
			   (161.0    -69.9    69.9)
			   (162.0    -74.3    74.3)
			   (163.0    -79.3    79.3)
			   (164.0    -85.2    85.2)
			   (165.0    -92.2    92.2)
			   (166.0   -100.9   100.9)
			   (167.0   -112.0   112.0)
			   (168.0   -127.6   127.6)
			   (169.0   -155.7   155.7)
			   (170.0   -180.0   180.0))	 
		         "10.291"
		          (( 50.0    -29.5    29.5)
			   ( 51.0    -29.1    29.1)
			   ( 52.0    -28.7    28.7)
			   ( 53.0    -28.3    28.3)
			   ( 54.0    -27.9    27.9)
			   ( 55.0    -27.6    27.6)
			   ( 56.0    -27.2    27.2)
			   ( 57.0    -26.9    26.9)
			   ( 58.0    -26.6    26.6)
			   ( 59.0    -26.3    26.3)
			   ( 60.0    -26.0    26.0)
			   ( 61.0    -25.8    25.8)
			   ( 62.0    -25.5    25.5)
			   ( 63.0    -25.3    25.3)
			   ( 64.0    -25.1    25.1)
			   ( 65.0    -24.9    24.9)
			   ( 66.0    -24.7    24.7)
			   ( 67.0    -24.5    24.5)
			   ( 68.0    -24.3    24.3)
			   ( 69.0    -24.1    24.1)
			   ( 70.0    -24.0    24.0)
			   ( 71.0    -23.8    23.8)
			   ( 72.0    -23.7    23.7)
			   ( 73.0    -23.5    23.5)
			   ( 74.0    -23.4    23.4)
			   ( 75.0    -23.3    23.3)
			   ( 76.0    -23.2    23.2)
			   ( 77.0    -23.1    23.1)
			   ( 78.0    -23.0    23.0)
			   ( 79.0    -22.9    22.9)
			   ( 80.0    -22.9    22.9)
			   ( 81.0    -22.8    22.8)
			   ( 82.0    -22.7    22.7)
			   ( 83.0    -22.7    22.7)
			   ( 84.0    -22.6    22.6)
			   ( 85.0    -22.6    22.6)
			   ( 86.0    -22.6    22.6)
			   ( 87.0    -22.5    22.5)
			   ( 88.0    -22.5    22.5)
			   ( 89.0    -22.5    22.5)
			   ( 90.0    -22.5    22.5)
			   ( 91.0    -22.5    22.5)
			   ( 92.0    -22.5    22.5)
			   ( 93.0    -22.5    22.5)
			   ( 94.0    -22.6    22.6)
			   ( 95.0    -22.6    22.6)
			   ( 96.0    -22.6    22.6)
			   ( 97.0    -22.7    22.7)
			   ( 98.0    -22.7    22.7)
			   ( 99.0    -22.8    22.8)
			   (100.0    -22.9    22.9)
			   (101.0    -22.9    22.9)
			   (102.0    -23.0    23.0)
			   (103.0    -23.1    23.1)
			   (104.0    -23.2    23.2)
			   (105.0    -23.3    23.3)
			   (106.0    -23.4    23.4)
			   (107.0    -23.5    23.5)
			   (108.0    -23.7    23.7)
			   (109.0    -23.8    23.8)
			   (110.0    -24.0    24.0)
			   (111.0    -24.1    24.1)
			   (112.0    -24.3    24.3)
			   (113.0    -24.5    24.5)
			   (114.0    -24.7    24.7)
			   (115.0    -24.9    24.9)
			   (116.0    -25.1    25.1)
			   (117.0    -25.3    25.3)
			   (118.0    -25.5    25.5)
			   (119.0    -25.8    25.8)
			   (120.0    -26.0    26.0)
			   (121.0    -26.3    26.3)
			   (122.0    -26.6    26.6)
			   (123.0    -26.9    26.9)
			   (124.0    -27.2    27.2)
			   (125.0    -27.6    27.6)
			   (126.0    -27.9    27.9)
			   (127.0    -28.3    28.3)
			   (128.0    -28.7    28.7)
			   (129.0    -29.1    29.1)
			   (130.0    -29.5    29.5)
			   (131.0    -30.0    30.0)
			   (132.0    -30.4    30.4)
			   (133.0    -30.9    30.9)
			   (134.0    -31.5    31.5)
			   (135.0    -32.0    32.0)
			   (136.0    -32.6    32.6)
			   (137.0    -33.2    33.2)
			   (138.0    -33.9    33.9)
			   (139.0    -34.6    34.6)
			   (140.0    -35.3    35.3)
			   (141.0    -36.1    36.1)
			   (142.0    -36.9    36.9)
			   (143.0    -37.8    37.8)
			   (144.0    -38.8    38.8)
			   (145.0    -39.8    39.8)
			   (146.0    -40.8    40.8)
			   (147.0    -42.0    42.0)
			   (148.0    -43.2    43.2)
			   (149.0    -44.5    44.5)
			   (150.0    -45.9    45.9)
			   (151.0    -47.5    47.5)
			   (152.0    -49.1    49.1)
			   (153.0    -50.9    50.9)
			   (154.0    -52.9    52.9)
			   (155.0    -55.0    55.0)
			   (156.0    -57.3    57.3)
			   (157.0    -59.9    59.9)
			   (158.0    -62.8    62.8)
			   (159.0    -66.0    66.0)
			   (160.0    -69.6    69.6)
			   (161.0    -73.6    73.6)
			   (162.0    -78.3    78.3)
			   (163.0    -83.7    83.7)
			   (164.0    -90.1    90.1)
			   (165.0    -97.8    97.8)
			   (166.0   -107.5   107.5)
			   (167.0   -120.3   120.3)
			   (168.0   -139.5   139.5)
			   (169.0   -180.0   180.0))
			 )))	 
			
  ;; guide-star-table maps the number of guide star pairs available at a 
  ;; time to the guide star suitability
  ;;
  :guide-star-table '(:fine-lock-nominal       (*MINUS-INFINITY* 0.0 1 1.0)
		      :fine-lock-off-nominal   (*MINUS-INFINITY* 0.0 1 0.75)
		      :course-lock-nominal     (*MINUS-INFINITY* 0.0 1 1.0)
		      :course-lock-off-nominal (*MINUS-INFINITY* 0.0 1 0.75))

  :phase-period-cutoff 7.0	;; added ijej 01-05-01.  Restored to 
  				;; explicit default 01-05-03.
  )
