;;
;; REVISION HISTORY (most recent at bottom of comments):  
;;
;;
;; Mods:
;;
;;   05-11-04 IJEJ
;;     -- added the skygrid mode parameter per NF & opr 54512.
;;
;;   07/26/2004 GNC
;;     - GOB model to remove 190s from prefix
;;     - Orbit model to use May04 ops numbers
;;     - Orient range table increased to expected allowable numbers (still conservative at 90-100 deg)
;;
;;   08/17/2004 GNC
;;     - Orient range table update
;;
;;   11/08/2004 GNC
;;     - Increase FHST sun limit angles from 25.0 to 40.0
;;     - Decrease FHST warmup time from 3m to 1m
;;
;;   12/21/2004 GNC
;;     - Decrease fhst-sun-limit-angles from 40 --> 37.7
;;     - Modify GOB parameters for new GS Acq timing
;;
;;   01/17/2004 GNC
;;     - Modify GOB parameters for new GS Acq timing (+1s for FGSTERM at front)
;;       means GOB Dur 376-->377, GOB Excl Time 121-->122 & GOB Prefix 121-->122
;;
;;   01/18/2004 GNC
;;     - Modify OAD parameters.  +15s (0.25m) to the map (no-handoff) portion of each OAD.
;;       Which means the overall OAD durations were also increased.
;;
;;   03/28/2005 GNC
;;     Post-F2G Test updates
;;     - Modify OAD parameters.  -15s (0.25m) to the map (no-handoff) portion of EACH OAD.
;;       Which means the overall OAD durations were also decreased by 15s.
;;       OAD1 dur 10.25 --> 10.00,  OAD1 excl time 3.25 --> 3.00,
;;       OAD2 dur  8.25 -->  8.00 , OAD2 excl time 3.25 --> 3.00
;;     - Modify OAD2 correction/maneuver parameters. -170s from correction & -30s from 
;;       settling time (ie -200s from OAD2 duration).  Assuming the above -15s already done, then
;;       OAD2 dur  8.00 --> 4.666667
;;     - Decrease MAU from 2.0 degrees --> 0.1 degrees
;;
;;
;;   04/19/05 ASV for Merle changed oad1-duration from 10 to  9.50 (-30s from settling time)
;;
;;   05/16/2005 GNC
;;     - Decreased MAP portion of each OAD by 15s:
;;       OAD1 dur  9.50     -->  9.25,     OAD1 excl time 3.00 --> 2.75
;;       OAD2 dur  4.666667 -->  4.416667, OAD2 excl time 3.00 --> 2.75
;;
;; 05/12/02 ijej:
;; Altered the following activity times pursuant to M. Reinhart's Nov. 23 10:10 email to LRPG:
;;
;; gob-handoff-exclusion-time:         from 4.25     to 2.75
;; gob-duration:                       from 6.283333 to 4.46667
;; oad1-duration:                      from 9.25     to 8.25
;; rate-task-duration:                 from 3.0      to 2.5
;; rate-task-handoff-exclustion-time:  from 3.0      to 2.5
;;
;; 06/02/09 ijej:  extended planning interval by 91 days.
;;                 changed gob handoff exclusion time from 2.75 to 2.4334.
;;
;; 06/02/09 ijej:  orbit model update.  Set for nominal solar prediction at April 02, 2007.
;;
;; 06/02/21 ijej:  OAD1 update 8.25 --> 7.9167
;; 		   rate-task-duration 2.5 --> 1.6
;;		   rate-task-handoff-exclusion-time 2.5 --> 1.6
;;
;; 06/03/15 mdr: Expanded lau-attitude-error-angle to put in FHST moon, earth dark and bright limb pads of 6.0 degreees
;;               oad2-duration 4.4167 --> 4.25
;;               gob-duration 4.46667 --> 4.45                   
;;               gob-handoff-exclusion-offset 2.03333 --> 1.86667
;;               gob-handoff-exclusion-time 2.43334 --> 2.58333
;;               gob-prefix 2.03333 --> 1.86667
;;               Note:  the gob numbers assume the PFFL GS Acq Logic Timings
;;               Added in fhst-activity-separations with current SPSS numbers, but leave commented out for this delivery
;;
;; 07-03-07 ij: copied over this file from mar06;
;;              modified the planning-start and planning-end dates
;;              updated the orbit model to "aug06" [10466.5, 339.7, -6.5233] = (SJD, RAAN, rate).
;;              added the :fhst-detect-roll-edges-only  :skip-saa-schedulability-check parameters.
;;              updated the :orient-range-table for asymmetric roll as per other ops constraint sets (MDR 06-06-12)

(DEFINE-CONSTRAINT-SET
  :planning-start                    "07.183"       ; An 18 month period
  :planning-end                      "08.364"       ;

  ;; Speed of calculation/efficiency/fidelity parameters:
  :fhst-detect-roll-edges-only  T       ;; new parameter for speedup 07-03-07
  :skip-saa-schedulability-check T      ;; new parameter for speedup 07-03-07
  :model-fhst-in-saa                    nil
  :filter-2gyro-with-3gyro-orb-viewing  t

  :2gyro-visibility-threshold           42          ;A minimum amount of 2 gyro visibility required for an 
                                                    ;observation to be considered suitable. In 3gyro mode it is used
                                                    ;to calculate the estimated 2gyro suitability of a visit.  In
                                                    ;2gyro mode it is used to collect roll ranges for the
					            ;:2GYRO-LOW-VIS roll-range-description, cv-desc form for APT.


  ;;
  ;; SI/FGS/FHST LIMIT ANGLES:
  ;;
  ;;:si-bright-earth-limb-angle          20.0         ;SI bright earth limb angle in degrees...now comes from tic file
  :si-dark-earth-limb-angle             6           ;SI dark earth limb angle in degrees

  :fgs-bright-earth-limb-angle         13.5         ;FGS bright earth limb angle in degrees
  :fgs-dark-earth-limb-angle            6           ;FGS dark   earth limb angle in degrees

  :fhst-sun-limit-angles         '(37.7 37.7 37.7)  ;The Sun angle limits (in degrees) for FHSTs 1,2,3 
  :fhst-moon-limit-angles        '(17.5 17.5 17.5)  ;The Moon angle limits (in degrees) for FHSTs 1,2,3
  :fhst-bright-earth-limb-angles '(32.375 32.375 32.375)
                                                    ;The bright Earth limb angle limits (in degrees) for FHSTs 1,2,3
  :fhst-dark-earth-limb-angles   '(16.5 16.5 16.5)  ;The dark Earth limb angle limits (in degrees) for FHSTs 1,2,3

  :low-sky-si-bright-earth-angle     40	      	    ;SI bright earth limb angle in degrees for LOW SKY

  :min-sun-angle                     60.3           ;minimum solar angle.
  :max-sun-angle                     180            ;maximum solar angle.

  :off-nominal-calc                  T              ;Non nil - calc off-nominal rolls in GS constraint
  ;;
  ;;
  ;;
  ;;  2-GYRO SPECIFIC PARAMETERS: 
  ;;  
  :lau-attitude-error-angle '(10.0  (:moon 6.0)         ;Large Attitude Uncertainty (degrees).
                                    (:dark-limb 6.0)    ;  The expected attitude error while under MMS Gyro control (T2G).
				    (:bright-limb 6.0)) ; See OPR 54890 for complete details on this parameter
  :MAU-attitude-error-angle              0.1        ;Medium Attitude Uncertainty (degrees). 
                                                    ;  The expected attitude error after the first OBAD.
  :SAU-attitude-error-angle              0.015280   ;Small Attitude Uncertainty (degrees).  
                                                    ;  The expected attitude error when under FHST (Tracker) 2 Gyro control.
  :rate-task-duration                    1.6        ;Duration of the rate task (minutes).
  :rate-task-handoff-exclusion-time      1.6        ;The portion of the rate task which cannot have an FHST handoff (minutes). 
                                                    ;  The zone starts at the start of the task.
  :oad1-duration                         7.9167     ;The duration of the first FHST attidude correction and map
  :oad1-handoff-exclusion-time           2.75       ;The portion of the oad1 task which cannot have an FHST handoff (minutes). 
                                                    ;  The zone starts at the start of the task.
  :oad2-duration                         4.25       ;The duration of the second FHST attidude correction and map (minutes).
  :oad2-handoff-exclusion-time           2.75       ;The portion of the oad2 task which cannot have an FHST handoff (minutes).
                                                    ;  The zone starts at the start of the task.
  :gob-duration                          4.45       ;The duration of fhst FGS overlap interval (minutes).
  :gob-handoff-exclusion-offset          1.86667    ;When the exclusion time starts relative to the start of the GOB task (minutes). 
  :gob-handoff-exclusion-time            2.58333    ;The duration of the gob task which cannot have an FHST handoff (minutes). 
  :gob-prefix                            1.86667    ;The portion of the gob task which can start before fgs visibility (in minutes)
  :fhst-warmup-time                      1.0        ;Minimum overlap time (minutes) between two FHST visibilities required to allow 
                                                    ;  for a handoff of FHST rate control
  :fhst-covers-occultation               t          ;If non-nil, code will model whether or not FHST visibility covers occultation
  :min-fhst-sample-step                  5          ;Smallest allowed roll sampling step for FHST vis (degrees)
  :max-fhst-sample-step                  10         ;Largest  allowed roll sampling step for FHST vis (degrees)
  :fhst-visibility-end-pad               5          ;Pad to compute conservative FHST windows (seconds)
  ;;:fhst-activity-separations '((:rate :oad1 96 780)     ;Start-to-Start min and max separations in seconds between 2 Gyro FHST activities
  ;;                             (:oad1 :oad2 475 4905)   ;See OPR 54891 for complete details on this parameter
  ;;                             (:oad2 :gob  255 1545)
  ;;                             (:rate :gob  826 7230))
  ;;
  ;;
  ;;
  ;;  HST ORBIT MODEL
  ;;
  :orbit-model                       "aug06"  ;orbit model name
  :st-information '(:inclination     28.470   ;inclination in degrees
                    :time-asc-node  10466.5   ;time of asdending node in truncated Julian date ***           epoch 2008.001:00 
                    :RA-asc-node      339.7   ;right ascention of ascending node in degrees    ***              At 2008.001:00
                    :regression-rate -6.5233  ;nodal regression rate in degrees per day        ***  Predicted rate 2008.001:00
                    :period          95.91    ;nodal period in minutes (supposed to be a conservative floor) updated oct04
                    :semimajor-axis  6939.6 ) ;semi-major axis in kilometers (always keep in synch with the
                                              ;   :period)  semimajor-axis not in synch in this
                                              ;   constraint set.  Now represents a floor over the planning
                                              ;   interval. updated from 6943 for this constraint set oct03.
			;; time-asc-node, RA-asc-node, and regression rate are produced by the fit_hst_orbit.ftn 
			;; program.  semimajor-axis is also produced by this, but not flagged, similarly
			;; instead, it is identified by "Predictied semimajor axis (use in reg-rate calc.)"
			;; and represents the floor value over the planning interval.  The period is
			;; computed from (semimajor-axis/331.24915)^1.5 ... Larson & Wertz, eq. 6-11.

  ;;
  ;; TDRS Parameters:
  ;;
  :tdrsw-information '(:longitude      -171.0
		       :period         86164.09054 ;nodal period in minutes
		       :semimajor-axis 42164.69)   ;semi-major axis in kilometers
  :tdrse-information '(:longitude      -41.0
		       :period         86164.09054 ;nodal period in minutes
		       :semimajor-axis 42164.69)   ;semi-major axis in kilometers
  ;;
  ;;
  ;;
  ;;  LUNAR ANGLE LIMITS:
  ;;
  ;; moon avoidance angle
  :moon-angle-table                    '((0 9 0) (9 180 1))
  
  ;;
  ;;  SOLAR ANGLE LIMITS:
  ;;
  ;; sun-angle-restrictions is a table of allowed solar angles and of maximum allowed off nominal rolls.
  :sun-angle-restrictions             '(*MINUS-INFINITY* (50 180) 30 
					"95.009" (90 120) 30 
					"95.054" (150 180) 30 
					"95.059" (90 120) 30 
					"95.107" (50 180) 30
					"00.052" (50.3 180) 30
					"04.001" (60.3 180) 30)  ;addition for 2-gyro

  ;; orient-range-table maps the sun angle to the legal range of orientation from nominal. 
  ;; The first value in each pair is the upper limit. The next value is the legal range. 
  ;;
  ;; HOW TO UPDATE :orient-range-table 
  ;; ---------------------------------
  ;;
  ;; The complete set of roll limits is a combination of three unique constraints:
  ;;
  ;; 1. spacecraft thermal roll constraint
  ;;    This constraint is defined as:
  ;;
  ;;    Sun-V1 angle    valid off nominal roll range in degrees
  ;;       <=50.3          nil  (no valid roll angle in this Sun-V1 range)
  ;;       <=90            5  
  ;;       <=178           30
  ;;       <=180.1        180
  ;;
  ;; 2. Sun to solar array incidence angle constraint 
  ;;    This constraint is defined for each Sun-V1 angle by ?
  ;;
  ;; 3. solar array shadowing roll constraint
  ;;    This constraint is defined by a set of lookup tables in SPSSLIB:WONMRL.DAT. There is one shadow
  ;;    table for every 3 degrees of possible offset of the solar array from its nominal '0' slew position.
  ;;  
  ;;    In each of these tables, there is an implied pairwise association between the V1-sun angle and
  ;;    allowed roll.  The values are specified in 3 degree increments of sun angle (not to be confused with
  ;;    the 3 degree increments of solar array slew position). However, the association of the roll limit to
  ;;    the V1-sun angle is interpreted differently between the two systems as follows:
  ;;    SPSS:  the sun angle specified is the 'lower' limit for its associated roll limit. 
  ;;    SPIKE: the sun angle specified is the 'upper' limit for its associated roll limit.
  ;;    Therefore, when transferring values from SPSSLIB:WONMRL.DAT to this table, always assign the SPSS
  ;;    roll limit to the next higher V1-sun angle in the SPIKE table. We are not worried about the V1-sun
  ;;    boundaries since the discontinuities are relatively small compared to the uncertainty in the
  ;;    resulting orient window due to SPIKE's 12 hour time resolution.   
  ;;
  ;; e.g.- 
  ;;     V1-sun angle                129                   132                    135
  ;;     roll limit                          20.46                  20.58 
  ;;     association in SPSS         |-------------------->|--------------------->|
  ;;     association in SPIKE        |<--------------------|<---------------------|
  ;; 
  ;; 4. Bay #5 thermal constraint
  ;;    This constraint exists to prevent overheating of HST Bay #5 during its "hot-season" which begins
  ;;    in November. 
  ;;    The source is GSFC thermal engineering team: 
  ;;    Contacts as of 07/26/02: Christine Cottingham <ccottingham@hst.nasa.gov>
  ;;                             Dr. Art L. Whipple   <awhipple@hst.nasa.gov>
  ;;    Current values as of 07/26/02:
  ;;                Sun angle  Off-nominal roll limit             
  ;;                 90-110    15              
  ;;                110-118    17              
  ;;                118-122    19              
  ;;                122-126    21              
  ;;                127-130    23              
  ;;                130-132    25              
  ;;                132-134    27              
  ;;                134-135    29              
  ;;
  ;; Given these three constraints, the rules for setting values in the :orient-range-table are: 
  ;; 
  ;; 1. Using the shadow tables for solar array offset angle = -3, 0, and +3 
  ;;    Identify the roll limit due to shadow at each defined Sun-V1 angle using 
  ;;
  ;;    SPSS_shadowroll(x) = MIN(SPSS_shadowroll(x,shadow-table=-3), 
  ;;                             SPSS_shadowroll(x,shadow-table= 0), 
  ;;                             SPSS_shadowroll(x,shadow-table=+3)) 
  ;;
  ;;         (where x            = Sun-V1 angle 
  ;;            and shadow-table = the shadow table cooresponding to the specified solar array position
  ;;                               offset)
  ;;
  ;; 2. set SPIKE_roll_limit(x+3) = MIN(SPSS_shadowroll(x), IncidenceAnglelimit(x+3),
  ;;                                ThermalAngleLimit(x+3), Bay5AngleLimit(x+3))
  ;;      
  ;; Note: the incidence angle and Bay #5 constraints tend to dominate at Sun-V1 angles of 90 - 126, as does
  ;;       the thermal constraint below 90. In addition, these constraints tend not to change, so if you are
  ;;       updating this table to incorporate new shadow constraints, then it is usually safe to choose the
  ;;       smaller of the shadow value and any previous value already in the table for these Sun-V1 ranges. 
  ;;  
  ;;Using the above rules,  
  ;;data in SPSSLIB:WONMRL.DAT: 
  ;; SUN_V1_ARRAY=                                                                
  ;;                            90,         93,         96,         99,        102,        105,        108, 
  ;;                           111,        114,        117,        120,        123,        126,        129, 
  ;;                           132,        135,        138,        141,        144,        147,        150, 
  ;;                           153,        156,        159,        162,        165,        168,        171, 
  ;;                           174,        177,        180,          0,          0,          0,          0,   
  ;; 
  ;;
  ;; SHADOW_TABLE as of 07/26/02:
  ;;               SA offset
  ;;                    -3   22.73,   22.57,   22.69,   22.92,   23.32,   23.90,   24.60,    
  ;;                         25.50,   26.67,   25.82,   24.64,   23.55,   22.61,   21.75,    
  ;;                         21.28,   21.36,   21.52,   22.07,   22.89,   24.06,   25.66,    
  ;;                         27.96,   31.36,   34.88,   40.58,   50.58,   71.21,  180.00,    
  ;;                        180.00,  180.00,  180.00,       0,       0,       0,       0,    
  ;;                             0,       0,       0,       0,       0,       0,       0,    
  ;;                             0,       0,       0,       0,       0,       0,       0,    
  ;;                             0,                                                          
  ;;
  ;;                    0    22.73,   22.69,   22.89,   23.20,   23.67,   24.29,   25.07,    
  ;;                         26.13,   25.89,   24.68,   23.59,   22.61,   21.75,   20.97,    
  ;;                         20.46,   20.58,   20.78,   21.36,   22.22,   23.39,   25.07,    
  ;;                         27.42,   30.78,   34.33,   40.07,   50.03,   70.66,  180.00,    
  ;;                        180.00,  180.00,  180.00,       0,       0,       0,       0,    
  ;;                             0,       0,       0,       0,       0,       0,       0,    
  ;;                             0,       0,       0,       0,       0,       0,       0,    
  ;;                             0,                                                          
  ;;
  ;;                    +3   22.73,   22.81,   23.04,   23.43,   23.98,   24.68,   25.58,    
  ;;                         26.01,   24.76,   23.63,   22.65,   21.75,   20.97,   20.27,    
  ;;                         19.64,   19.88,   20.07,   20.66,   21.56,   22.77,   24.45,    
  ;;                         26.83,   30.19,   33.75,   39.53,   49.49,   70.03,  180.00,    
  ;;                        180.00,  180.00,  180.00,       0,       0,       0,       0,    
  ;;                             0,       0,       0,       0,       0,       0,       0,    
  ;;                             0,       0,       0,       0,       0,       0,       0,    
  ;;                             0,                                                          
  ;;
  ;;transfers to:
  ;; :orient-range-table '((50.3  nil) ( 90     5) 
  ;;                    ( 93 16.74) ( 96 16.76) ( 99 16.84) (102 16.96) (105 17.13) (108 17.35) (111 17.63)
  ;;                    (114 17.97) (117 18.38) (120 18.86) (123 19.43) (126 20.09) (129 20.86) (132 20.97) 
  ;;                    (135 20.46) (138 20.58) (141 20.78) (144 21.36) (147 22.22) (150 23.39) (153 25.07)
  ;;                    (156 27.42) (178    30) (180.1 180) )
  ;;
  ;; SPIKE orient-range-table update history:
  ;; 
  ;; 07/16/99 WMK - These are the new restrictions based upon 17 degrees solar incidence 
  ;;                with a 3-degree pad for uncertainty in solar array pointing combined 
  ;;                with the old restrictions which still apply, as they derive from the 
  ;;                shadow restrictions.
  ;;
  ;; 02/21/00 wmw - changed from 50 to 50.3 to be consistent with SPSS and PASS 
  ;;
  ;; 03/01/01 wmw - updated to incorporate new shadow restrictions due to the SA-3 to be installed 
  ;;                during SM3B in Nov 2001. Since the new values are more restrictive, we are doing 
  ;;                this now so that whenever SM3B occurs the resulting constraint changes will 
  ;;                already be taken into account in the LRP. 
  ;;
  ;; 03/02/01 wmw - updated comments to include descriptions and update procedures.
  ;;
  ;; 03/12/02 wmw - updated orbit model following SM3B boost
  ;;
  ;; 07/19/02 ijj - updated orbit model 
  ;;
  ;; 08/02/02 wmw - updated orient range table to incorporate new SUN-V3 offnominal roll limits in order
  ;;                to keep Bay 5 temperature in limits during the hot season beginning in November, and
  ;;                to incorporate new Sun-SA incidence restriction. 
  ;;
  ;;                Previous table values:
  ;;                :orient-range-table '(
  ;;                       (50.3  nil) 
  ;;                       ( 90     5) 
  ;;                       ( 93 16.74) 
  ;;                       ( 96 16.76) 
  ;;                       ( 99 16.84) 
  ;;                       (102 16.96) 
  ;;                       (105 17.13) 
  ;;                       (108 17.35) 
  ;;                       (111 17.63)
  ;;                       (114 17.97) 
  ;;                       (117 18.38) 
  ;;                       (120 18.86) 
  ;;                       (123 19.43) 
  ;;                       (126 20.09) 
  ;;                       (129 20.86) 
  ;;                       (132 20.97) 
  ;;                       (135 20.46) 
  ;;                       (138 20.58) 
  ;;                       (141 20.78) 
  ;;                       (144 21.36) 
  ;;                       (147 22.22) 
  ;;                       (150 23.39) 
  ;;                       (153 25.07)
  ;;                       (156 27.42) 
  ;;                       (178    30) 
  ;;                       (180.1 180) )
  ;;
  ;;........................................................................................................
  ;; Components of SPIKE orient-range-table as of (08/02/02):
  ;; 
  ;; off nominal roll limit due to: 
  ;;                       Sun-V1  shadow     Sun-SA      Bay #5  Sun-V1
  ;;                        angle   (WONMRL)  incidence   Thermal Thermal
  ;;                       ( 50.3  22.73)      24.83)     15.00)   nil)
  ;;                       ( 90    22.73)      24.83      15.00)   5.00)   
  ;;                       ( 93    22.73)      24.83)     15.00)  30.00)              
  ;;                       ( 96    22.69)      24.87)     15.00)  30.00) 
  ;;                       ( 99    22.69)      24.98)     15.00)  30.00)
  ;;                       (102    22.92)      25.16)     15.00   30.00)  
  ;;                       (105    23.32)      25.42)     15.00)  30.00)   
  ;;                       (108    23.90)      25.77)     15.00)  30.00)  
  ;;                       (110    24.60)      26.20)     15.00)  30.00) 
  ;;                       (111    24.60)      26.20)     17.00)  30.00) 
  ;;                       (114    25.50)      26.73)     17.00)  30.00)
  ;;                       (117    24.76)      27.37)     17.00)  30.00)
  ;;                       (118    23.65)      28.12)     17.00)  30.00)
  ;;                       (120    23.65)      28.12)     19.00)  30.00)
  ;;                       (122    22.65)      29.01)     19.00)  30.00)
  ;;                       (123    22.65)      29.01)     21.00)  30.00)           
  ;;                       (126    21.75)      30.05)     21.00)  30.00)
  ;;                       (129    20.97)      31.27)     23.00)  30.00)
  ;;                       (130    20.27)      32.71)     23.00)  30.00) 
  ;;                       (132    20.27)      32.71)     25.00)  30.00) 
  ;;                       (134    19.64)      34.41)     27.00)  30.00) 
  ;;                       (135    19.64)      34.41)     29.00)  30.00) 
  ;;                       (138    19.88)      36.43)    180.00)  30.00)
  ;;                       (141    20.07)      38.87)    180.00)  30.00)
  ;;                       (144    20.66)      41.86)    180.00)  30.00)
  ;;                       (147    21.56)      45.60)    180.00)  30.00)
  ;;                       (150    22.77)      50.45)    180.00)  30.00)
  ;;                       (153    24.45)      57.13)    180.00)  30.00)
  ;;                       (156    26.83)      67.67)    180.00)  30.00)
  ;;                       (159    30.19)     180.00)    180.00)  30.00)         
  ;;                       (162    33.75)     180.00)    180.00)  30.00)         
  ;;                       (165    39.53)     180.00)    180.00)  30.00)        
  ;;                       (168    49.49)     180.00)    180.00)  30.00)        
  ;;                       (171    70.03)     180.00)    180.00)  30.00)          
  ;;                       (178   180.00)     180.00)    180.00)  30.00)
  ;;                       (180.1 180.00)     180.00)    180.00) 180.00)         
  ;;
  ;;........................................................................................................
  ;;
  ;;   :orient-range-table '(  ( 60.3    nil) 
  ;;                           ( 90     5.00) 
  ;;                           (110    15.00) 
  ;;                           (118    17.00) 
  ;;                           (122    19.00) 
  ;;                           (126    21.00) 
  ;;                           (129    20.97) 
  ;;                           (132    20.27) 
  ;;                           (135    19.64) 
  ;;                           (138    19.88) 
  ;;                           (141    20.07) 
  ;;                           (144    20.66) 
  ;;                           (147    21.56) 
  ;;                           (150    22.77) 
  ;;                           (153    24.45)
  ;;                           (156    26.83) 
  ;;                           (179    30.00) 
  ;;                           (180.1 180.00))
  ;;
  ;;........................................................................................................
  ;; Components of SPIKE orient-range-table as of (06/12/06):
  ;; 
  ;; off nominal roll limit due to: 
  ;;                       Sun-V1  shadow     Sun-SA      Bay #5  Sun-V1
  ;;                        angle   (WONMRL)  incidence   Thermal Thermal
  ;;                       ( 60.3  22.73)      24.83)        nil)    nil)
  ;;                       ( 90    22.73)      24.83      -15.00)   5.00)
  ;;                       ( 91                           -15.00)  15.00)
  ;;                       ( 92                           -15.00)  15.00)   
  ;;                       ( 93    22.73)      24.83)     -15.01)  15.00)
  ;;                       ( 94                           -15.02)  15.00)
  ;;                       ( 95                           -15.04)  15.00)              
  ;;                       ( 96    22.69)      24.87)     -15.06)  15.00) 
  ;;                       ( 97                           -15.08)  15.00)
  ;;                       ( 98                           -15.12)  15.00)
  ;;                       ( 99    22.69)      24.98)     -15.15)  15.00)
  ;;                       (100                           -15.20   15.00)
  ;;                       (101                           -15.25)  30.00)
  ;;                       (102                           -15.30)  30.00)
  ;;                       (103    22.92)      25.16)     -15.36)  30.00)
  ;;                       (104                           -15.43)  30.00)
  ;;                       (105                           -15.51)  30.00)  
  ;;                       (106    23.32)      25.42)     -15.59)  30.00)
  ;;                       (107                           -15.69)  30.00)
  ;;                       (108                           -15.79)  30.00)   
  ;;                       (109    23.90)      25.77)     -15.91)  30.00)
  ;;                       (110                           -16.03)  30.00)  
  ;;                       (111    24.60)      26.20)     -16.17)  30.00) 
  ;;                       (112    24.60)      26.20)     -16.33)  30.00)
  ;;                       (113                           -16.50)  30.00)
  ;;                       (114                           -16.69)  30.00) 
  ;;                       (115    25.50)      26.73)     -16.89)  30.00)
  ;;                       (116                           -17.12)  30.00)
  ;;                       (117                           -17.37)  30.00)
  ;;                       (118    24.76)      27.37)     -17.65)  30.00)
  ;;                       (119    23.65)      28.12)     -17.95)  30.00)
  ;;                       (120                           -18.39)  30.00)
  ;;                       (121    23.65)      28.12)     -18.65)  30.00)
  ;;                       (122                           -19.05)  30.00)
  ;;                       (123    22.65)      29.01)     -19.48)  30.00)
  ;;                       (124    22.65)      29.01)     -19.95)  30.00)
  ;;                       (125                           -20.46)  30.00)
  ;;                       (126                           -21.02)  30.00)           
  ;;                       (127    21.75)      30.05)     -21.62)  30.00)
  ;;                       (128                           -22.26)  30.00)
  ;;                       (129                           -22.95)  30.00)
  ;;                       (130    20.97)      31.27)     -23.35)  30.00)
  ;;                       (131    20.27)      32.71)     -24.13)  30.00)
  ;;                       (132                           -25.33)  30.00)
  ;;                       (133    20.27)      32.71)     -26.22)  30.00)
  ;;                       (134                           -27.17)  30.00) 
  ;;                       (135    19.64)      34.41)     -28.18)  30.00) 
  ;;                       (136    19.64)      34.41)     -29.24)  30.00) 
  ;;                       (137                           -30.37)  30.00)
  ;;                       (138    19.88)      36.43)    -180.00)  30.00)
  ;;                       (141    20.07)      38.87)    -180.00)  30.00)
  ;;                       (144    20.66)      41.86)    -180.00)  30.00)
  ;;                       (147    21.56)      45.60)    -180.00)  30.00)
  ;;                       (150    22.77)      50.45)    -180.00)  30.00)
  ;;                       (153    24.45)      57.13)    -180.00)  30.00)
  ;;                       (156    26.83)      67.67)    -180.00)  30.00)
  ;;                       (159    30.19)     180.00)    -180.00)  30.00)         
  ;;                       (162    33.75)     180.00)    -180.00)  30.00)         
  ;;                       (165    39.53)     180.00)    -180.00)  30.00)        
  ;;                       (168    49.49)     180.00)    -180.00)  30.00)        
  ;;                       (171    70.03)     180.00)    -180.00)  30.00)          
  ;;                       (179   180.00)     180.00)    -180.00)  30.00)
  ;;                       (180.1 180.00)     180.00)    -180.00) 180.00)         
  ;;
  ;;........................................................................................................
  ;; Modification provided by M. Reinhart.
  ;;

   :orient-range-table '(  ( 60.3    nil    nil) 
                           ( 90    -5.00   5.00)
                           (100   -15.00  15.00)
                           (101   -15.25  22.92)
                           (102   -15.30  22.92)
                           (103   -15.36  22.92)
                           (104   -15.43  23.32)
                           (105   -15.51  23.32)
                           (106   -15.59  23.32)
                           (107   -15.69  23.32)
                           (108   -15.79  23.32)
                           (109   -15.91  23.32)
                           (110   -16.02  24.60)
                           (111   -16.17  24.60)
                           (112   -16.33  24.60)
                           (113   -16.50  25.50)
                           (114   -16.69  25.50)
                           (115   -16.89  25.50)
                           (116   -17.12  24.76)
                           (117   -17.37  24.76) 
                           (118   -17.65  24.76) 
                           (119   -17.95  23.65)
                           (120   -18.39  23.65)
                           (121   -18.65  23.65)
                           (122   -19.05  22.65)
                           (123   -19.48  22.65)
                           (124   -19.95  22.65)
                           (125   -20.46  21.75) 
                           (126   -21.02  21.75)
                           (127   -21.62  21.75)
                           (128   -20.97  20.97) 
                           (129   -20.97  20.97)
                           (130   -20.97  20.97)
                           (131   -20.27  20.27) 
                           (132   -20.27  20.27)
                           (133   -20.27  20.27)
                           (134   -19.64  19.64) 
                           (135   -19.64  19.64)
                           (136   -19.64  19.64)
                           (137   -19.88  19.88) 
                           (138   -19.88  19.88) 
                           (141   -20.07  20.07) 
                           (144   -20.66  20.66) 
                           (147   -21.56  21.56) 
                           (150   -22.77  22.77) 
                           (153   -24.45  24.45)
                           (156   -26.83  26.83) 
                           (179   -30.00  30.00) 
                           (180.1 -180.00 180.00))


  ;; guide-star-table maps the number of guide star pairs available at a time to the guide star suitability
  :guide-star-table '(:fine-lock-nominal       (*MINUS-INFINITY* 0.0 1 1.0)
		      :fine-lock-off-nominal   (*MINUS-INFINITY* 0.0 1 0.75)
		      :course-lock-nominal     (*MINUS-INFINITY* 0.0 1 1.0)
		      :course-lock-off-nominal (*MINUS-INFINITY* 0.0 1 0.75))
  :phase-period-cutoff 7.0	;; added ijej 01-05-01.  Restored to explicit default 01-05-03.
  )
