;; 	CONSTRAINT-SET FILE FOR USE WITH CASM/APT RELEASE.
;;
;; ============================== Start Modification History and Comment Block ==================================
;; REVISION HISTORY (most recent at bottom of comments):  
;;
;;
;; Mods:
;;   07/26/2004 GNC
;;     - GOB model to remove 190s from prefix
;;     - Orbit model to use May04 ops numbers
;;     - Orient range table increased to expected allowable numbers (still conservative at 90-100 deg)
;;
;;   08/17/2004 GNC
;;     - Orient range table update
;;
;;   11/08/2004 GNC
;;     - Increase FHST sun limit angles from 25.0 to 40.0
;;     - Decrease FHST warmup time from 3m to 1m
;;
;;   12/21/2004 GNC
;;     - Decrease fhst-sun-limit-angles from 40 --> 37.7
;;     - Modify GOB parameters for new GS Acq timing
;;
;;   01/17/2004 GNC
;;     - Modify GOB parameters for new GS Acq timing (+1s for FGSTERM at front)
;;       means GOB Dur 376-->377, GOB Excl Time 121-->122 & GOB Prefix 121-->122
;;
;;   01/18/2004 GNC
;;     - Modify OAD parameters.  +15s (0.25m) to the map (no-handoff) portion of each OAD.
;;       Which means the overall OAD durations were also increased.
;;
;;   03/28/2005 GNC
;;     Post-F2G Test updates
;;     - Modify OAD parameters.  -15s (0.25m) to the map (no-handoff) portion of EACH OAD.
;;       Which means the overall OAD durations were also decreased by 15s.
;;       OAD1 dur 10.25 --> 10.00,  OAD1 excl time 3.25 --> 3.00,
;;       OAD2 dur  8.25 -->  8.00 , OAD2 excl time 3.25 --> 3.00
;;     - Modify OAD2 correction/maneuver parameters. -170s from correction & -30s from 
;;       settling time (ie -200s from OAD2 duration).  Assuming the above -15s already done, then
;;       OAD2 dur  8.00 --> 4.666667
;;     - Decrease MAU from 2.0 degrees --> 0.1 degrees
;;
;;
;;   04/19/2005 ASV for Merle changed oad1-duration from 10 to  9.50 (-30s from settling time)
;;
;;   05/16/2005 GNC
;;     - Decreased MAP portion of each OAD by 15s:
;;       OAD1 dur  9.50     -->  9.25,     OAD1 excl time 3.00 --> 2.75
;;       OAD2 dur  4.666667 -->  4.416667, OAD2 excl time 3.00 --> 2.75
;;
;; 2005/12/02 ijej:
;; Altered the following activity times pursuant to M. Reinhart's Nov. 23 10:10 email to LRPG:
;;
;; gob-handoff-exclusion-time:         from 4.25     to 2.75
;; gob-duration:                       from 6.283333 to 4.46667
;; oad1-duration:                      from 9.25     to 8.25
;; rate-task-duration:                 from 3.0      to 2.5
;; rate-task-handoff-exclustion-time:  from 3.0      to 2.5
;;
;; 2006/02/09 ijej:  extended planning interval by 91 days.
;;                 changed gob handoff exclusion time from 2.75 to 2.4334.
;;
;; 2006/02/09 ijej:  orbit model update.  Set for nominal solar prediction at April 02, 2007.
;;
;; 2006/02/21 ijej:  OAD1 update 8.25 --> 7.9167
;; 		   rate-task-duration 2.5 --> 1.6
;;		   rate-task-handoff-exclusion-time 2.5 --> 1.6
;;
;; 2006/03/15 mdr: Expanded lau-attitude-error-angle to put in FHST moon, earth dark and bright limb pads of 6.0 degreees
;;               oad2-duration 4.4167 --> 4.25
;;               gob-duration 4.46667 --> 4.45                   
;;               gob-handoff-exclusion-offset 2.03333 --> 1.86667
;;               gob-handoff-exclusion-time 2.43334 --> 2.58333
;;               gob-prefix 2.03333 --> 1.86667
;;               Note:  the gob numbers assume the PFFL GS Acq Logic Timings
;;               Added in fhst-activity-separations with current SPSS numbers, but leave commented out for this delivery
;;
;; 2006/06/12 mdr: Expanded orient-range-table to enable asymmetric roll
;;
;; 2006-08-10/16 ij:	 New orbit model aug06 optimized for April 2, 2008--
;;				correction to plane_projector projection ascending node.  Update planning-start for earliest linkset.
;; 2007-16-07 mdr: Settings for Post-SM4 3-gyro mode up until about April 2009.
;;
;; 04-08-2008 mdr: Complete rework of the orient-range-table due to OPR 58333
;;               Modified planning-end to be the end of the valid orient-range-table data
;;               Removed :min/max-sun-angle per OPR 55253
;;               Update4d :sun-angle-restrictions per OPR 55253
;; 04-23-2008 mdr: Update :solar-array-incidence-restriction due to new SA output numbers
;;
;; 2009-07-29 ij:	copy of /data/lrp/constraint-sets/c17_2009april_v2_bay10_sa.lisp
;;			and modified to suit phase 1 Cycle 18 MCT.  This differs from nov07-phase1.lisp as follows:
;;				1. :planning-start & -end updated
;;				2. :filter-2gyro-with-3gyro-orb-viewing (not used this cycle)
;;				3. :2gyro-visibility parameter (not used this cycle)
;;				4. :min- and :max-sun-angle parameters removed from constraint set.
;;				5. HST orbit model parameters updated, optimized for June 1, 2011 & 
;;					200-day 'late' sun from previous solar magnetic Cycle.
;;				6. New format :orient-range-table (OPR 58333).
;;
;; 2009-11-25 ijej:	copy of /data/lrp/ops-deliverables/jul09/constraint-sets/jul09-phase1.lisp
;;				No other modifications as of yet.
;;	
;;	
;;	
;; ============================== End Modification History and Comment Block ==================================

(DEFINE-CONSTRAINT-SET
  ;; nominally, find-earliest-linksets shows we should use 06.114, however these are ACS.
  :planning-start                    "10.151"   ;; circa June 1, 2010, start of MCT Cycle 18 CfP
  :planning-end                      "12.365"   ;; 2 years plus 6 months.

  ;;
  ;; SI/FGS/FHST LIMIT ANGLES:
  ;;
  ;;:si-bright-earth-limb-angle          20.0         ;SI bright earth limb angle in degrees...now comes from tic file
  :si-dark-earth-limb-angle             6           ;SI dark earth limb angle in degrees

  :fgs-bright-earth-limb-angle         13.5         ;FGS bright earth limb angle in degrees
  :fgs-dark-earth-limb-angle            6           ;FGS dark   earth limb angle in degrees

  :fhst-sun-limit-angles         '(37.7 37.7 37.7)  ;The Sun angle limits (in degrees) for FHSTs 1,2,3 
  :fhst-moon-limit-angles        '(17.5 17.5 17.5)  ;The Moon angle limits (in degrees) for FHSTs 1,2,3
  :fhst-bright-earth-limb-angles '(32.375 32.375 32.375)
                                                    ;The bright Earth limb angle limits (in degrees) for FHSTs 1,2,3
  :fhst-dark-earth-limb-angles   '(16.5 16.5 16.5)  ;The dark Earth limb angle limits (in degrees) for FHSTs 1,2,3

  :low-sky-si-bright-earth-angle     40	      	    ;SI bright earth limb angle in degrees for LOW SKY

  :off-nominal-calc                  T              ;Non nil - calc off-nominal rolls in GS constraint


;;
;;
;;  :2gyro-visibility-threshold           42      ;; ;A minimum amount of
;;        ;; 2-gyro visibility required for an  observation to be considered 
;;        ;; suitable. In 3gyro mode it is used to calculate the estimated 
;;        ;; 2-gyro suitability of a  visit.  In 2-gyro mode it is used to 
;;        ;; collect roll ranges for the  :2GYRO-LOW-VIS roll-range-description, 
;;        ;; cv-desc form for APT.


  ;;
  ;;  2-GYRO SPECIFIC PARAMETERS: 
  ;;  


  :filter-2gyro-with-3gyro-orb-viewing  t       ;; t is the setting specified 
                                                ;; for APT/CASM delivery.

  :model-fhst-in-saa                    nil	;; nil is the setting for 
                                                ;; CASM/APT delivery.

  :lau-attitude-error-angle '(10.0  (:moon 4.0)         ;Large Attitude Uncertainty (degrees).
                                    (:dark-limb 4.0)    ;  The expected attitude error while under MMS Gyro control (T2G).
				    (:bright-limb 4.0)) ; See OPR 54890 for complete details on this parameter
  :MAU-attitude-error-angle              0.1        ;Medium Attitude Uncertainty (degrees). 
                                                    ;  The expected attitude error after the first OBAD.
  :SAU-attitude-error-angle              0.015280   ;Small Attitude Uncertainty (degrees).  
                                                    ;  The expected attitude error when under FHST (Tracker) 2 Gyro control.
  :rate-task-duration                    1.6        ;Duration of the rate task (minutes).
  :rate-task-handoff-exclusion-time      1.6        ;The portion of the rate task which cannot have an FHST handoff (minutes). 
                                                    ;  The zone starts at the start of the task.
  :oad1-duration                         7.9167     ;The duration of the first FHST attidude correction and map
  :oad1-handoff-exclusion-time           2.75       ;The portion of the oad1 task which cannot have an FHST handoff (minutes). 
                                                    ;  The zone starts at the start of the task.
  :oad2-duration                         4.25       ;The duration of the second FHST attidude correction and map (minutes).
  :oad2-handoff-exclusion-time           2.75       ;The portion of the oad2 task which cannot have an FHST handoff (minutes).
                                                    ;  The zone starts at the start of the task.
  :gob-duration                          4.45       ;The duration of fhst FGS overlap interval (minutes).
  :gob-handoff-exclusion-offset          1.86667    ;When the exclusion time starts relative to the start of the GOB task (minutes). 
  :gob-handoff-exclusion-time            2.58333    ;The duration of the gob task which cannot have an FHST handoff (minutes). 
  :gob-prefix                            1.86667    ;The portion of the gob task which can start before fgs visibility (in minutes)
  :fhst-warmup-time                      1.0        ;Minimum overlap time (minutes) between two FHST visibilities required to allow 
                                                    ;  for a handoff of FHST rate control
  :fhst-covers-occultation               t          ;If non-nil, code will model whether or not FHST visibility covers occultation
  :min-fhst-sample-step                  5          ;Smallest allowed roll sampling step for FHST vis (degrees) =1 operationally, 5 for apt
  :max-fhst-sample-step                 10          ;Largest  allowed roll sampling step for FHST vis (degrees) = 3 operationally, 10 for apt
  :fhst-visibility-end-pad               5          ;Pad to compute conservative FHST windows (seconds)
  ;;:fhst-activity-separations '((:rate :oad1 96 780)     ;Start-to-Start min and max separations in seconds between 2 Gyro FHST activities
  ;;                             (:oad1 :oad2 475 4905)   ;See OPR 54891 for complete details on this parameter
  ;;                             (:oad2 :gob  255 1545)
  ;;                             (:rate :gob  826 7230))
 
  ;;
  ;;
  ;;
  ;;  HST ORBIT MODEL
  ;;
  :orbit-model                       "jul09"    ;; orbit model name -- does not operate on anything--just text model update date. ***
  :st-information '(:inclination       28.470   ;; inclination in degrees
                    :time-asc-node  11713.5     ;; time of asdending node.	***
                    :RA-asc-node      118.50    ;; right ascention of ascending node in degrees    ***  
                    :regression-rate   -6.54620 ;; nodal regression rate in degrees per day        ***  
                    :period            95.60   ;; nodal period in minutes (supposed to be a conservative floor)      *** 
                    :semimajor-axis  6925.0 )   ;; semi-major axis in kilometers (always keep in synch with :period)  *** 
                                                ;; SMA & period should both represent a floor over the planning interval. ***
                                                ;;
                                               ;; time-asc-node, RA-asc-node, and regression rate, SMA & period are produced by 
                                               ;; /data/lrp/sw/scripts/plane_projector program.
                                               ;; The period is computed from (semimajor-axis/331.24915)^1.5 ... 
                                               ;; Larson & Wertz + Boden, eq. 6-11.

  ;;
  ;; TDRS Parameters:
  ;;
  :tdrsw-information '(:longitude      -171.0
		       :period         86164.09054 ;nodal period in minutes
		       :semimajor-axis 42164.69)   ;semi-major axis in kilometers
  :tdrse-information '(:longitude      -41.0
		       :period         86164.09054 ;nodal period in minutes
		       :semimajor-axis 42164.69)   ;semi-major axis in kilometers
  ;;
  ;;
  ;;
  ;;  LUNAR ANGLE LIMITS:
  ;;
  ;; moon avoidance angle
  :moon-angle-table                    '((0 9 0) (9 180 1))
  
  ;;
  ;;  SOLAR ANGLE LIMITS:
  ;;
  ;; sun-angle-restrictions is a table of allowed solar angles and of maximum allowed off nominal rolls.
  :sun-angle-restrictions             '(*MINUS-INFINITY* (50.0 180.0)
					"95.009" ( 90.0 120.0) 
					"95.054" (150.0 180.0) 
					"95.059" ( 90.0 120.0)
					"95.107" ( 50.0 180.0)
					"00.052" ( 50.3 180.0)
					"04.001" ( 60.3 180.0)	;addition for 2-gyro
					"08.224" ( 50.3 180.0)	;; reset for post-sm4-testing ijej 07-07-10.
					)  


  ;; The orient-range-table is composed of four time-based independent constraints that will
  ;; get intersected together to arrive at the min/max orient allowed for a particular sun angle.
  ;; The interpretation of the numbers (ie, the direction/how the table is read) is the same
  ;; as used by SPSS and PASS.
  ;; See OPR 58333 for the details of how to compute the number for each of the component tables
  ;;
  :orient-range-table '((:solar-array-shadowing-restriction
  		         t
		         (*minus-infinity*
			  (( 50.0    -22.73    22.73)
			   ( 90.0    -22.73    22.73)
			   ( 93.0    -22.57    22.57)
			   ( 96.0    -22.69    22.69)
			   ( 99.0    -22.92    22.92)
			   (102.0    -23.32    23.32)
			   (105.0    -23.90    23.90)
			   (108.0    -24.60    24.60)
	  		   (111.0    -25.50    25.50)
			   (114.0    -24.76    24.76)
			   (117.0    -23.63    23.63)
			   (120.0    -22.65    22.65)
			   (123.0    -21.75    21.75)
			   (126.0    -20.97    20.97)
			   (129.0    -20.27    20.27)
			   (132.0    -19.64    19.64)
			   (135.0    -19.88    19.88)
			   (138.0    -20.07    20.07)
			   (141.0    -20.66    20.66)
			   (144.0    -21.56    21.56)
			   (147.0    -22.77    22.77)
			   (150.0    -24.45    24.45)
			   (153.0    -26.83    26.83)
			   (156.0    -30.19    30.19)
			   (159.0    -33.75    33.75)
			   (162.0    -39.53    39.53)
			   (165.0    -49.49    49.49)
			   (168.0    -70.03    70.03)
			   (171.0   -180.00   180.00))))
;; modifying bay-five-restriction to accommodate bay 10 restrictions.
		        (:bay-five-restriction
		         t
		         (*minus-infinity*
			  (( 50.0   -180.00    180.0)
			   ( 90.0    -15.00    15)
			   ( 91.0    -15.00    15)
			   ( 92.0    -15.01    15.01)
			   ( 93.0    -15.02    15.02)
			   ( 94.0    -15.04    15.04)
			   ( 95.0    -15.06    15.06)
			   ( 96.0    -15.08    15.08)
			   ( 97.0    -15.12    15.12)
			   ( 98.0    -15.15    15.15)
			   ( 99.0    -15.20    15.2)
			   (100.0    -15.25    15.25)
			   (101.0    -15.30    15.3)
			   (102.0    -15.36    15.36)
			   (103.0    -15.43    15.43)
			   (104.0    -15.51    15.51)
			   (105.0    -15.59    15.59)
			   (106.0    -15.69    15.69)
			   (107.0    -15.79    15.79)
			   (108.0    -15.91    15.91)
			   (109.0    -16.03    16.03)
			   (110.0    -16.17    16.17)
			   (111.0    -16.33    16.33)
			   (112.0    -16.50    16.5)
			   (113.0    -16.69    16.69)
			   (114.0    -16.89    16.89)
			   (115.0    -17.12    17.12)
			   (116.0    -17.37    17.37)
			   (117.0    -17.65    17.65)
			   (118.0    -17.95    17.95)
			   (119.0    -18.29    18.29)
			   (120.0    -18.65    18.65)
			   (121.0    -19.05    19.05)
			   (122.0    -19.48    19.48)
			   (123.0    -19.95    19.95)
			   (124.0    -20.46    20.46)
			   (125.0    -21.02    21.02)
			   (126.0    -21.62    21.62)
			   (127.0    -22.26    22.26)
			   (128.0    -22.95    22.95)
			   (129.0    -23.69    23.69)
			   (130.0    -24.48    24.48)
			   (131.0    -25.33    25.33)
			   (132.0    -26.22    26.22)
			   (133.0    -27.17    27.17)
			   (134.0    -28.18    28.18)
			   (135.0    -29.24    29.24)
			   (136.0    -30.00    30)
			   (137.0   -180    180.0))))
;; End modifying bay-five-restriction.
		        (:hst-thermal-restriction
		         t
		         (*minus-infinity*
			  (( 50.0     -5.0     5.0)
			   ( 90.0    -30.0    30.0)
			   (178.0   -180.0   180.0))
			  "05.241"
			  (( 50.0     -5.0     5.0)
			   ( 90.0    -15.0    15.0)
			   (100.0    -30.0    30.0)
			   (179.0   -180.0   180.0))
			  "08.249"
			  (( 50.0     -5.0     5.0)
			   ( 90.0    -30.0    30.0)
			   (178.0   -180.0   180.0))))
		        (:solar-array-incidence-restriction
		         t
		         (*minus-infinity*
			  (( 50.0    -29.4    29.4)
			   ( 51.0    -29.0    29.0)
			   ( 52.0    -28.6    28.6)
			   ( 53.0    -28.2    28.2)
			   ( 54.0    -27.8    27.8)
			   ( 55.0    -27.5    27.5)
			   ( 56.0    -27.2    27.2)
			   ( 57.0    -26.8    26.8)
			   ( 58.0    -26.5    26.5)
			   ( 59.0    -26.3    26.3)
			   ( 60.0    -26.0    26.0)
			   ( 61.0    -25.7    25.7)
			   ( 62.0    -25.5    25.5)
			   ( 63.0    -25.2    25.2)
			   ( 64.0    -25.0    25.0)
			   ( 65.0    -24.8    24.8)
			   ( 66.0    -24.6    24.6)
			   ( 67.0    -24.4    24.4)
			   ( 68.0    -24.2    24.2)
			   ( 69.0    -24.1    24.1)
			   ( 70.0    -23.9    23.9)
			   ( 71.0    -23.8    23.8)
			   ( 72.0    -23.6    23.6)
			   ( 73.0    -23.5    23.5)
			   ( 74.0    -23.4    23.4)
			   ( 75.0    -23.3    23.3)
			   ( 76.0    -23.1    23.1)
			   ( 77.0    -23.0    23.0)
			   ( 78.0    -23.0    23.0)
			   ( 79.0    -22.9    22.9)
			   ( 80.0    -22.8    22.8)
			   ( 81.0    -22.7    22.7)
			   ( 82.0    -22.7    22.7)
			   ( 83.0    -22.6    22.6)
			   ( 84.0    -22.6    22.6)
			   ( 85.0    -22.5    22.5)
			   ( 86.0    -22.5    22.5)
			   ( 87.0    -22.5    22.5)
			   ( 88.0    -22.5    22.5)
			   ( 89.0    -22.5    22.5)
			   ( 90.0    -22.4    22.4)
			   ( 91.0    -22.5    22.5)
			   ( 92.0    -22.5    22.5)
			   ( 93.0    -22.5    22.5)
			   ( 94.0    -22.5    22.5)
			   ( 95.0    -22.5    22.5)
			   ( 96.0    -22.6    22.6)
			   ( 97.0    -22.6    22.6)
			   ( 98.0    -22.7    22.7)
			   ( 99.0    -22.7    22.7)
			   (100.0    -22.8    22.8)
			   (101.0    -22.9    22.9)
			   (102.0    -23.0    23.0)
			   (103.0    -23.0    23.0)
			   (104.0    -23.1    23.1)
			   (105.0    -23.3    23.3)
			   (106.0    -23.4    23.4)
			   (107.0    -23.5    23.5)
			   (108.0    -23.6    23.6)
			   (109.0    -23.8    23.8)
			   (110.0    -23.9    23.9)
			   (111.0    -24.1    24.1)
			   (112.0    -24.2    24.2)
			   (113.0    -24.4    24.4)
			   (114.0    -24.6    24.6)
			   (115.0    -24.8    24.8)
			   (116.0    -25.0    25.0)
			   (117.0    -25.2    25.2)
			   (118.0    -25.5    25.5)
			   (119.0    -25.7    25.7)
			   (120.0    -26.0    26.0)
			   (121.0    -26.3    26.3)
			   (122.0    -26.5    26.5)
			   (123.0    -26.8    26.8)
			   (124.0    -27.2    27.2)
			   (125.0    -27.5    27.5)
			   (126.0    -27.8    27.8)
			   (127.0    -28.2    28.2)
			   (128.0    -28.6    28.6)
			   (129.0    -29.0    29.0)
			   (130.0    -29.4    29.4)
			   (131.0    -29.9    29.9)
			   (132.0    -30.4    30.4)
			   (133.0    -30.9    30.9)
			   (134.0    -31.4    31.4)
			   (135.0    -32.0    32.0)
			   (136.0    -32.5    32.5)
			   (137.0    -33.2    33.2)
			   (138.0    -33.8    33.8)
			   (139.0    -34.5    34.5)
			   (140.0    -35.3    35.3)
			   (141.0    -36.0    36.0)
			   (142.0    -36.9    36.9)
			   (143.0    -37.7    37.7)
			   (144.0    -38.7    38.7)
			   (145.0    -39.7    39.7)
			   (146.0    -40.7    40.7)
			   (147.0    -41.9    41.9)
			   (148.0    -43.1    43.1)
			   (149.0    -44.4    44.4)
			   (150.0    -45.8    45.8)
			   (151.0    -47.3    47.3)
			   (152.0    -49.0    49.0)
			   (153.0    -50.8    50.8)
			   (154.0    -52.7    52.7)
			   (155.0    -54.9    54.9)
			   (156.0    -57.2    57.2)
			   (157.0    -59.8    59.8)
			   (158.0    -62.6    62.6)
			   (159.0    -65.8    65.8)
			   (160.0    -69.4    69.4)
			   (161.0    -73.4    73.4)
			   (162.0    -78.1    78.1)
			   (163.0    -83.5    83.5)
			   (164.0    -89.9    89.9)
			   (165.0    -97.5    97.5)
			   (166.0   -107.2   107.2)
			   (167.0   -119.8   119.8)
			   (168.0   -138.9   138.9)
			   (169.0   -180.0   180.0))
		         "09.117"
		          (( 50.0    -21.2    21.2)
			   ( 51.0    -20.9    20.9)
			   ( 52.0    -20.6    20.6)
			   ( 53.0    -20.3    20.3)
			   ( 54.0    -20.1    20.1)
			   ( 55.0    -19.8    19.8)
			   ( 56.0    -19.6    19.6)
			   ( 57.0    -19.3    19.3)
			   ( 58.0    -19.1    19.1)
			   ( 59.0    -18.9    18.9)
			   ( 60.0    -18.7    18.7)
			   ( 61.0    -18.5    18.5)
			   ( 62.0    -18.4    18.4)
			   ( 63.0    -18.2    18.2)
			   ( 64.0    -18.0    18.0)
			   ( 65.0    -17.9    17.9)
			   ( 66.0    -17.7    17.7)
			   ( 67.0    -17.6    17.6)
			   ( 68.0    -17.5    17.5)
			   ( 69.0    -17.4    17.4)
			   ( 70.0    -17.2    17.2)
			   ( 71.0    -17.1    17.1)
			   ( 72.0    -17.0    17.0)
			   ( 73.0    -16.9    16.9)
			   ( 74.0    -16.9    16.9)
			   ( 75.0    -16.8    16.8)
			   ( 76.0    -16.7    16.7)
			   ( 77.0    -16.6    16.6)
			   ( 78.0    -16.6    16.6)
			   ( 79.0    -16.5    16.5)
			   ( 80.0    -16.5    16.5)
			   ( 81.0    -16.4    16.4)
			   ( 82.0    -16.4    16.4)
			   ( 83.0    -16.3    16.3)
			   ( 84.0    -16.3    16.3)
			   ( 85.0    -16.3    16.3)
			   ( 86.0    -16.2    16.2)
			   ( 87.0    -16.2    16.2)
			   ( 88.0    -16.2    16.2)
			   ( 89.0    -16.2    16.2)
			   ( 90.0    -16.2    16.2)
			   ( 91.0    -16.2    16.2)
			   ( 92.0    -16.2    16.2)
			   ( 93.0    -16.2    16.2)
			   ( 94.0    -16.2    16.2)
			   ( 95.0    -16.3    16.3)
			   ( 96.0    -16.3    16.3)
			   ( 97.0    -16.3    16.3)
			   ( 98.0    -16.4    16.4)
			   ( 99.0    -16.4    16.4)
			   (100.0    -16.5    16.5)
			   (101.0    -16.5    16.5)
			   (102.0    -16.6    16.6)
			   (103.0    -16.6    16.6)
			   (104.0    -16.7    16.7)
			   (105.0    -16.8    16.8)
			   (106.0    -16.9    16.9)
			   (107.0    -16.9    16.9)
			   (108.0    -17.0    17.0)
			   (109.0    -17.1    17.1)
			   (110.0    -17.2    17.2)
			   (111.0    -17.4    17.4)
			   (112.0    -17.5    17.5)
			   (113.0    -17.6    17.6)
			   (114.0    -17.7    17.7)
			   (115.0    -17.9    17.9)
			   (116.0    -18.0    18.0)
			   (117.0    -18.2    18.2)
			   (118.0    -18.4    18.4)
			   (119.0    -18.5    18.5)
			   (120.0    -18.7    18.7)
			   (121.0    -18.9    18.9)
			   (122.0    -19.1    19.1)
			   (123.0    -19.3    19.3)
			   (124.0    -19.6    19.6)
			   (125.0    -19.8    19.8)
			   (126.0    -20.1    20.1)
			   (127.0    -20.3    20.3)
			   (128.0    -20.6    20.6)
			   (129.0    -20.9    20.9)
			   (130.0    -21.2    21.2)
			   (131.0    -21.5    21.5)
			   (132.0    -21.9    21.9)
			   (133.0    -22.2    22.2)
			   (134.0    -22.6    22.6)
			   (135.0    -23.0    23.0)
			   (136.0    -23.4    23.4)
			   (137.0    -23.8    23.8)
			   (138.0    -24.3    24.3)
			   (139.0    -24.8    24.8)
			   (140.0    -25.3    25.3)
			   (141.0    -25.9    25.9)
			   (142.0    -26.5    26.5)
			   (143.0    -27.1    27.1)
			   (144.0    -27.7    27.7)
			   (145.0    -28.4    28.4)
			   (146.0    -29.2    29.2)
			   (147.0    -30.0    30.0)
			   (148.0    -30.8    30.8)
			   (149.0    -31.8    31.8)
			   (150.0    -32.7    32.7)
			   (151.0    -33.8    33.8)
			   (152.0    -34.9    34.9)
			   (153.0    -36.2    36.2)
			   (154.0    -37.5    37.5)
			   (155.0    -39.0    39.0)
			   (156.0    -40.5    40.5)
			   (157.0    -42.3    42.3)
			   (158.0    -44.2    44.2)
			   (159.0    -46.3    46.3)
			   (160.0    -48.7    48.7)
			   (161.0    -51.3    51.3)
			   (162.0    -54.3    54.3)
			   (163.0    -57.6    57.6)
			   (164.0    -61.5    61.5)
			   (165.0    -66.0    66.0)
			   (166.0    -71.2    71.2)
			   (167.0    -77.6    77.6)
			   (168.0    -85.3    85.3)
			   (169.0    -95.2    95.2)
			   (170.0   -108.5   108.5)
			   (171.0   -128.5   128.5)
                           (172.0   -180.0   180.0))
		         "09.166"
		          (( 50.0    -18.8    18.8)
			   ( 51.0    -18.6    18.6)
			   ( 52.0    -18.3    18.3)
			   ( 53.0    -18.1    18.1)
			   ( 54.0    -17.8    17.8)
			   ( 55.0    -17.6    17.6)
			   ( 56.0    -17.4    17.4)
			   ( 57.0    -17.2    17.2)
			   ( 58.0    -17.0    17.0)
			   ( 59.0    -16.8    16.8)
			   ( 60.0    -16.6    16.6)
			   ( 61.0    -16.5    16.5)
			   ( 62.0    -16.3    16.3)
			   ( 63.0    -16.2    16.2)
			   ( 64.0    -16.0    16.0)
			   ( 65.0    -15.9    15.9)
			   ( 66.0    -15.8    15.8)
			   ( 67.0    -15.7    15.7)
			   ( 68.0    -15.5    15.5)
			   ( 69.0    -15.4    15.4)
			   ( 70.0    -15.3    15.3)
			   ( 71.0    -15.2    15.2)
			   ( 72.0    -15.1    15.1)
			   ( 73.0    -15.1    15.1)
			   ( 74.0    -15.0    15.0)
			   ( 75.0    -14.9    14.9)
			   ( 76.0    -14.8    14.8)
			   ( 77.0    -14.8    14.8)
			   ( 78.0    -14.7    14.7)
			   ( 79.0    -14.7    14.7)
			   ( 80.0    -14.6    14.6)
			   ( 81.0    -14.6    14.6)
			   ( 82.0    -14.5    14.5)
			   ( 83.0    -14.5    14.5)
			   ( 84.0    -14.5    14.5)
			   ( 85.0    -14.5    14.5)
			   ( 86.0    -14.4    14.4)
			   ( 87.0    -14.4    14.4)
			   ( 88.0    -14.4    14.4)
			   ( 89.0    -14.4    14.4)
			   ( 90.0    -14.4    14.4)
			   ( 91.0    -14.4    14.4)
			   ( 92.0    -14.4    14.4)
			   ( 93.0    -14.4    14.4)
			   ( 94.0    -14.4    14.4)
			   ( 95.0    -14.5    14.5)
			   ( 96.0    -14.5    14.5)
			   ( 97.0    -14.5    14.5)
			   ( 98.0    -14.5    14.5)
			   ( 99.0    -14.6    14.6)
			   (100.0    -14.6    14.6)
			   (101.0    -14.7    14.7)
			   (102.0    -14.7    14.7)
			   (103.0    -14.8    14.8)
			   (104.0    -14.8    14.8)
			   (105.0    -14.9    14.9)
			   (106.0    -15.0    15.0)
			   (107.0    -15.1    15.1)
			   (108.0    -15.1    15.1)
			   (109.0    -15.2    15.2)
			   (110.0    -15.3    15.3)
			   (111.0    -15.4    15.4)
			   (112.0    -15.5    15.5)
			   (113.0    -15.7    15.7)
			   (114.0    -15.8    15.8)
			   (115.0    -15.9    15.9)
			   (116.0    -16.0    16.0)
			   (117.0    -16.2    16.2)
			   (118.0    -16.3    16.3)
			   (119.0    -16.5    16.5)
			   (120.0    -16.6    16.6)
			   (121.0    -16.8    16.8)
			   (122.0    -17.0    17.0)
			   (123.0    -17.2    17.2)
			   (124.0    -17.4    17.4)
			   (125.0    -17.6    17.6)
			   (126.0    -17.8    17.8)
			   (127.0    -18.1    18.1)
			   (128.0    -18.3    18.3)
			   (129.0    -18.6    18.6)
			   (130.0    -18.8    18.8)
			   (131.0    -19.1    19.1)
			   (132.0    -19.4    19.4)
			   (133.0    -19.7    19.7)
			   (134.0    -20.1    20.1)
			   (135.0    -20.4    20.4)
			   (136.0    -20.8    20.8)
			   (137.0    -21.2    21.2)
			   (138.0    -21.6    21.6)
			   (139.0    -22.0    22.0)
			   (140.0    -22.5    22.5)
			   (141.0    -23.0    23.0)
			   (142.0    -23.5    23.5)
			   (143.0    -24.0    24.0)
			   (144.0    -24.6    24.6)
			   (145.0    -25.2    25.2)
			   (146.0    -25.9    25.9)
			   (147.0    -26.6    26.6)
			   (148.0    -27.4    27.4)
			   (149.0    -28.2    28.2)
			   (150.0    -29.0    29.0)
			   (151.0    -30.0    30.0)
			   (152.0    -31.0    31.0)
			   (153.0    -32.1    32.1)
			   (154.0    -33.2    33.2)
			   (155.0    -34.5    34.5)
			   (156.0    -35.9    35.9)
			   (157.0    -37.4    37.4)
			   (158.0    -39.1    39.1)
			   (159.0    -40.9    40.9)
			   (160.0    -43.0    43.0)
			   (161.0    -45.3    45.3)
			   (162.0    -47.9    47.9)
			   (163.0    -50.8    50.8)
			   (164.0    -54.1    54.1)
			   (165.0    -57.9    57.9)
			   (166.0    -62.4    62.4)
			   (167.0    -67.7    67.7)
			   (168.0    -74.1    74.1)
			   (169.0    -82.1    82.1)
			   (170.0    -92.4    92.4)
			   (171.0   -106.5   106.5)
                           (172.0   -128.5   128.5)
                           (173.0   -180.0   180.0))
		         "09.194"
		          (( 50.0    -20.0    20.0)
			   ( 51.0    -19.7    19.7)
			   ( 52.0    -19.5    19.5)
			   ( 53.0    -19.2    19.2)
			   ( 54.0    -18.9    18.9)
			   ( 55.0    -18.7    18.7)
			   ( 56.0    -18.5    18.5)
			   ( 57.0    -18.3    18.3)
			   ( 58.0    -18.1    18.1)
			   ( 59.0    -17.9    17.9)
			   ( 60.0    -17.7    17.7)
			   ( 61.0    -17.5    17.5)
			   ( 62.0    -17.3    17.3)
			   ( 63.0    -17.2    17.2)
			   ( 64.0    -17.0    17.0)
			   ( 65.0    -16.9    16.9)
			   ( 66.0    -16.8    16.8)
			   ( 67.0    -16.6    16.6)
			   ( 68.0    -16.5    16.5)
			   ( 69.0    -16.4    16.4)
			   ( 70.0    -16.3    16.3)
			   ( 71.0    -16.2    16.2)
			   ( 72.0    -16.1    16.1)
			   ( 73.0    -16.0    16.0)
			   ( 74.0    -15.9    15.9)
			   ( 75.0    -15.8    15.8)
			   ( 76.0    -15.8    15.8)
			   ( 77.0    -15.7    15.7)
			   ( 78.0    -15.6    15.6)
			   ( 79.0    -15.6    15.6)
			   ( 80.0    -15.5    15.5)
			   ( 81.0    -15.5    15.5)
			   ( 82.0    -15.5    15.5)
			   ( 83.0    -15.4    15.4)
			   ( 84.0    -15.4    15.4)
			   ( 85.0    -15.4    15.4)
			   ( 86.0    -15.3    15.3)
			   ( 87.0    -15.3    15.3)
			   ( 88.0    -15.3    15.3)
			   ( 89.0    -15.3    15.3)
			   ( 90.0    -15.3    15.3)
			   ( 91.0    -15.3    15.3)
			   ( 92.0    -15.3    15.3)
			   ( 93.0    -15.3    15.3)
			   ( 94.0    -15.3    15.3)
			   ( 95.0    -15.4    15.4)
			   ( 96.0    -15.4    15.4)
			   ( 97.0    -15.4    15.4)
			   ( 98.0    -15.5    15.5)
			   ( 99.0    -15.5    15.5)
			   (100.0    -15.5    15.5)
			   (101.0    -15.6    15.6)
			   (102.0    -15.6    15.6)
			   (103.0    -15.7    15.7)
			   (104.0    -15.8    15.8)
			   (105.0    -15.8    15.8)
			   (106.0    -15.9    15.9)
			   (107.0    -16.0    16.0)
			   (108.0    -16.1    16.1)
			   (109.0    -16.2    16.2)
			   (110.0    -16.3    16.3)
			   (111.0    -16.4    16.4)
			   (112.0    -16.5    16.5)
			   (113.0    -16.6    16.6)
			   (114.0    -16.8    16.8)
			   (115.0    -16.9    16.9)
			   (116.0    -17.0    17.0)
			   (117.0    -17.2    17.2)
			   (118.0    -17.3    17.3)
			   (119.0    -17.5    17.5)
			   (120.0    -17.7    17.7)
			   (121.0    -17.9    17.9)
			   (122.0    -18.1    18.1)
			   (123.0    -18.3    18.3)
			   (124.0    -18.5    18.5)
			   (125.0    -18.7    18.7)
			   (126.0    -18.9    18.9)
			   (127.0    -19.2    19.2)
			   (128.0    -19.5    19.5)
			   (129.0    -19.7    19.7)
			   (130.0    -20.0    20.0)
			   (131.0    -20.3    20.3)
			   (132.0    -20.6    20.6)
			   (133.0    -21.0    21.0)
			   (134.0    -21.3    21.3)
			   (135.0    -21.7    21.7)
			   (136.0    -22.1    22.1)
			   (137.0    -22.5    22.5)
			   (138.0    -23.0    23.0)
			   (139.0    -23.4    23.4)
			   (140.0    -23.9    23.9)
			   (141.0    -24.4    24.4)
			   (142.0    -25.0    25.0)
			   (143.0    -25.6    25.6)
			   (144.0    -26.2    26.2)
			   (145.0    -26.8    26.8)
			   (146.0    -27.5    27.5)
			   (147.0    -28.3    28.3)
			   (148.0    -29.1    29.1)
			   (149.0    -30.0    30.0)
			   (150.0    -30.9    30.9)
			   (151.0    -31.9    31.9)
			   (152.0    -32.9    32.9)
			   (153.0    -34.1    34.1)
			   (154.0    -35.4    35.4)
			   (155.0    -36.7    36.7)
			   (156.0    -38.2    38.2)
			   (157.0    -39.8    39.8)
			   (158.0    -41.6    41.6)
			   (159.0    -43.6    43.6)
			   (160.0    -45.8    45.8)
			   (161.0    -48.3    48.3)
			   (162.0    -51.0    51.0)
			   (163.0    -54.2    54.2)
			   (164.0    -57.8    57.8)
			   (165.0    -61.9    61.9)
			   (166.0    -66.8    66.8)
			   (167.0    -72.6    72.6)
			   (168.0    -79.6    79.6)
			   (169.0    -88.5    88.5)
			   (170.0   -100.1   100.1)
			   (171.0   -116.6   116.6)
                           (172.0   -146.1   146.1)
                           (173.0   -180.0   180.0))
		         "09.257"
		          (( 50.0    -24.0    24.0)
			   ( 51.0    -23.6    23.6)
			   ( 52.0    -23.3    23.3)
			   ( 53.0    -23.0    23.0)
			   ( 54.0    -22.7    22.7)
			   ( 55.0    -22.4    22.4)
			   ( 56.0    -22.1    22.1)
			   ( 57.0    -21.9    21.9)
			   ( 58.0    -21.6    21.6)
			   ( 59.0    -21.4    21.4)
			   ( 60.0    -21.2    21.2)
			   ( 61.0    -21.0    21.0)
			   ( 62.0    -20.8    20.8)
			   ( 63.0    -20.6    20.6)
			   ( 64.0    -20.4    20.4)
			   ( 65.0    -20.2    20.2)
			   ( 66.0    -20.0    20.0)
			   ( 67.0    -19.9    19.9)
			   ( 68.0    -19.8    19.8)
			   ( 69.0    -19.6    19.6)
			   ( 70.0    -19.5    19.5)
			   ( 71.0    -19.4    19.4)
			   ( 72.0    -19.3    19.3)
			   ( 73.0    -19.1    19.1)
			   ( 74.0    -19.0    19.0)
			   ( 75.0    -19.0    19.0)
			   ( 76.0    -18.9    18.9)
			   ( 77.0    -18.8    18.8)
			   ( 78.0    -18.7    18.7)
			   ( 79.0    -18.6    18.6)
			   ( 80.0    -18.6    18.6)
			   ( 81.0    -18.5    18.5)
			   ( 82.0    -18.5    18.5)
			   ( 83.0    -18.4    18.4)
			   ( 84.0    -18.4    18.4)
			   ( 85.0    -18.4    18.4)
			   ( 86.0    -18.3    18.3)
			   ( 87.0    -18.3    18.3)
			   ( 88.0    -18.3    18.3)
			   ( 89.0    -18.3    18.3)
			   ( 90.0    -18.3    18.3)
			   ( 91.0    -18.3    18.3)
			   ( 92.0    -18.3    18.3)
			   ( 93.0    -18.3    18.3)
			   ( 94.0    -18.3    18.3)
			   ( 95.0    -18.4    18.4)
			   ( 96.0    -18.4    18.4)
			   ( 97.0    -18.4    18.4)
			   ( 98.0    -18.5    18.5)
			   ( 99.0    -18.5    18.5)
			   (100.0    -18.6    18.6)
			   (101.0    -18.6    18.6)
			   (102.0    -18.7    18.7)
			   (103.0    -18.8    18.8)
			   (104.0    -18.9    18.9)
			   (105.0    -19.0    19.0)
			   (106.0    -19.0    19.0)
			   (107.0    -19.1    19.1)
			   (108.0    -19.3    19.3)
			   (109.0    -19.4    19.4)
			   (110.0    -19.5    19.5)
			   (111.0    -19.6    19.6)
			   (112.0    -19.8    19.8)
			   (113.0    -19.9    19.9)
			   (114.0    -20.0    20.0)
			   (115.0    -20.2    20.2)
			   (116.0    -20.4    20.4)
			   (117.0    -20.6    20.6)
			   (118.0    -20.8    20.8)
			   (119.0    -21.0    21.0)
			   (120.0    -21.2    21.2)
			   (121.0    -21.4    21.4)
			   (122.0    -21.6    21.6)
			   (123.0    -21.9    21.9)
			   (124.0    -22.1    22.1)
			   (125.0    -22.4    22.4)
			   (126.0    -22.7    22.7)
			   (127.0    -23.0    23.0)
			   (128.0    -23.3    23.3)
			   (129.0    -23.6    23.6)
			   (130.0    -24.0    24.0)
			   (131.0    -24.3    24.3)
			   (132.0    -24.7    24.7)
			   (133.0    -25.1    25.1)
			   (134.0    -25.5    25.5)
			   (135.0    -26.0    26.0)
			   (136.0    -26.5    26.5)
			   (137.0    -27.0    27.0)
			   (138.0    -27.5    27.5)
			   (139.0    -28.1    28.1)
			   (140.0    -28.6    28.6)
			   (141.0    -29.3    29.3)
			   (142.0    -29.9    29.9)
			   (143.0    -30.6    30.6)
			   (144.0    -31.4    31.4)
			   (145.0    -32.2    32.2)
			   (146.0    -33.0    33.0)
			   (147.0    -34.0    34.0)
			   (148.0    -34.9    34.9)
			   (149.0    -36.0    36.0)
			   (150.0    -37.1    37.1)
			   (151.0    -38.3    38.3)
			   (152.0    -39.6    39.6)
			   (153.0    -41.0    41.0)
			   (154.0    -42.5    42.5)
			   (155.0    -44.2    44.2)
			   (156.0    -46.0    46.0)
			   (157.0    -48.0    48.0)
			   (158.0    -50.2    50.2)
			   (159.0    -52.7    52.7)
			   (160.0    -55.4    55.4)
			   (161.0    -58.5    58.5)
			   (162.0    -61.9    61.9)
			   (163.0    -65.9    65.9)
			   (164.0    -70.5    70.5)
			   (165.0    -75.8    75.8)
			   (166.0    -82.2    82.2)
			   (167.0    -90.0    90.0)
			   (168.0    -99.8    99.8)
			   (169.0   -112.9   112.9)
			   (170.0   -132.6   132.6)
                           (171.0   -180.0   180.0))
		         "09.278"
		          (( 50.0    -26.7    26.7)
			   ( 51.0    -26.3    26.3)
			   ( 52.0    -26.0    26.0)
			   ( 53.0    -25.6    25.6)
			   ( 54.0    -25.3    25.3)
			   ( 55.0    -25.0    25.0)
			   ( 56.0    -24.7    24.7)
			   ( 57.0    -24.4    24.4)
			   ( 58.0    -24.1    24.1)
			   ( 59.0    -23.8    23.8)
			   ( 60.0    -23.6    23.6)
			   ( 61.0    -23.4    23.4)
			   ( 62.0    -23.1    23.1)
			   ( 63.0    -22.9    22.9)
			   ( 64.0    -22.7    22.7)
			   ( 65.0    -22.5    22.5)
			   ( 66.0    -22.4    22.4)
			   ( 67.0    -22.2    22.2)
			   ( 68.0    -22.0    22.0)
			   ( 69.0    -21.9    21.9)
			   ( 70.0    -21.7    21.7)
			   ( 71.0    -21.6    21.6)
			   ( 72.0    -21.5    21.5)
			   ( 73.0    -21.3    21.3)
			   ( 74.0    -21.2    21.2)
			   ( 75.0    -21.1    21.1)
			   ( 76.0    -21.0    21.0)
			   ( 77.0    -20.9    20.9)
			   ( 78.0    -20.9    20.9)
			   ( 79.0    -20.8    20.8)
			   ( 80.0    -20.7    20.7)
			   ( 81.0    -20.7    20.7)
			   ( 82.0    -20.6    20.6)
			   ( 83.0    -20.6    20.6)
			   ( 84.0    -20.5    20.5)
			   ( 85.0    -20.5    20.5)
			   ( 86.0    -20.5    20.5)
			   ( 87.0    -20.4    20.4)
			   ( 88.0    -20.4    20.4)
			   ( 89.0    -20.4    20.4)
			   ( 90.0    -20.4    20.4)
			   ( 91.0    -20.4    20.4)
			   ( 92.0    -20.4    20.4)
			   ( 93.0    -20.4    20.4)
			   ( 94.0    -20.5    20.5)
			   ( 95.0    -20.5    20.5)
			   ( 96.0    -20.5    20.5)
			   ( 97.0    -20.6    20.6)
			   ( 98.0    -20.6    20.6)
			   ( 99.0    -20.7    20.7)
			   (100.0    -20.7    20.7)
			   (101.0    -20.8    20.8)
			   (102.0    -20.9    20.9)
			   (103.0    -20.9    20.9)
			   (104.0    -21.0    21.0)
			   (105.0    -21.1    21.1)
			   (106.0    -21.2    21.2)
			   (107.0    -21.3    21.3)
			   (108.0    -21.5    21.5)
			   (109.0    -21.6    21.6)
			   (110.0    -21.7    21.7)
			   (111.0    -21.9    21.9)
			   (112.0    -22.0    22.0)
			   (113.0    -22.2    22.2)
			   (114.0    -22.4    22.4)
			   (115.0    -22.5    22.5)
			   (116.0    -22.7    22.7)
			   (117.0    -22.9    22.9)
			   (118.0    -23.1    23.1)
			   (119.0    -23.4    23.4)
			   (120.0    -23.6    23.6)
			   (121.0    -23.8    23.8)
			   (122.0    -24.1    24.1)
			   (123.0    -24.4    24.4)
			   (124.0    -24.7    24.7)
			   (125.0    -25.0    25.0)
			   (126.0    -25.3    25.3)
			   (127.0    -25.6    25.6)
			   (128.0    -26.0    26.0)
			   (129.0    -26.3    26.3)
			   (130.0    -26.7    26.7)
			   (131.0    -27.1    27.1)
			   (132.0    -27.6    27.6)
			   (133.0    -28.0    28.0)
			   (134.0    -28.5    28.5)
			   (135.0    -29.0    29.0)
			   (136.0    -29.5    29.5)
			   (137.0    -30.1    30.1)
			   (138.0    -30.7    30.7)
			   (139.0    -31.3    31.3)
			   (140.0    -32.0    32.0)
			   (141.0    -32.7    32.7)
			   (142.0    -33.4    33.4)
			   (143.0    -34.2    34.2)
			   (144.0    -35.1    35.1)
			   (145.0    -36.0    36.0)
			   (146.0    -36.9    36.9)
			   (147.0    -37.9    37.9)
			   (148.0    -39.0    39.0)
			   (149.0    -40.2    40.2)
			   (150.0    -41.5    41.5)
			   (151.0    -42.8    42.8)
			   (152.0    -44.3    44.3)
			   (153.0    -45.9    45.9)
			   (154.0    -47.7    47.7)
			   (155.0    -49.5    49.5)
			   (156.0    -51.6    51.6)
			   (157.0    -53.9    53.9)
			   (158.0    -56.4    56.4)
			   (159.0    -59.2    59.2)
			   (160.0    -62.4    62.4)
			   (161.0    -65.9    65.9)
			   (162.0    -69.9    69.9)
			   (163.0    -74.6    74.6)
			   (164.0    -80.0    80.0)
			   (165.0    -86.3    86.3)
			   (166.0    -94.1    94.1)
			   (167.0   -103.9   103.9)
			   (168.0   -116.8   116.8)
			   (169.0   -136.3   136.3)
                           (170.0   -180.0   180.0))
		         "09.320"
		          (( 50.0    -29.5    29.5)
			   ( 51.0    -29.1    29.1)
			   ( 52.0    -28.7    28.7)
			   ( 53.0    -28.3    28.3)
			   ( 54.0    -27.9    27.9)
			   ( 55.0    -27.6    27.6)
			   ( 56.0    -27.2    27.2)
			   ( 57.0    -26.9    26.9)
			   ( 58.0    -26.6    26.6)
			   ( 59.0    -26.3    26.3)
			   ( 60.0    -26.0    26.0)
			   ( 61.0    -25.8    25.8)
			   ( 62.0    -25.5    25.5)
			   ( 63.0    -25.3    25.3)
			   ( 64.0    -25.1    25.1)
			   ( 65.0    -24.9    24.9)
			   ( 66.0    -24.7    24.7)
			   ( 67.0    -24.5    24.5)
			   ( 68.0    -24.3    24.3)
			   ( 69.0    -24.1    24.1)
			   ( 70.0    -24.0    24.0)
			   ( 71.0    -23.8    23.8)
			   ( 72.0    -23.7    23.7)
			   ( 73.0    -23.5    23.5)
			   ( 74.0    -23.4    23.4)
			   ( 75.0    -23.3    23.3)
			   ( 76.0    -23.2    23.2)
			   ( 77.0    -23.1    23.1)
			   ( 78.0    -23.0    23.0)
			   ( 79.0    -22.9    22.9)
			   ( 80.0    -22.9    22.9)
			   ( 81.0    -22.8    22.8)
			   ( 82.0    -22.7    22.7)
			   ( 83.0    -22.7    22.7)
			   ( 84.0    -22.6    22.6)
			   ( 85.0    -22.6    22.6)
			   ( 86.0    -22.6    22.6)
			   ( 87.0    -22.5    22.5)
			   ( 88.0    -22.5    22.5)
			   ( 89.0    -22.5    22.5)
			   ( 90.0    -22.5    22.5)
			   ( 91.0    -22.5    22.5)
			   ( 92.0    -22.5    22.5)
			   ( 93.0    -22.5    22.5)
			   ( 94.0    -22.6    22.6)
			   ( 95.0    -22.6    22.6)
			   ( 96.0    -22.6    22.6)
			   ( 97.0    -22.7    22.7)
			   ( 98.0    -22.7    22.7)
			   ( 99.0    -22.8    22.8)
			   (100.0    -22.9    22.9)
			   (101.0    -22.9    22.9)
			   (102.0    -23.0    23.0)
			   (103.0    -23.1    23.1)
			   (104.0    -23.2    23.2)
			   (105.0    -23.3    23.3)
			   (106.0    -23.4    23.4)
			   (107.0    -23.5    23.5)
			   (108.0    -23.7    23.7)
			   (109.0    -23.8    23.8)
			   (110.0    -24.0    24.0)
			   (111.0    -24.1    24.1)
			   (112.0    -24.3    24.3)
			   (113.0    -24.5    24.5)
			   (114.0    -24.7    24.7)
			   (115.0    -24.9    24.9)
			   (116.0    -25.1    25.1)
			   (117.0    -25.3    25.3)
			   (118.0    -25.5    25.5)
			   (119.0    -25.8    25.8)
			   (120.0    -26.0    26.0)
			   (121.0    -26.3    26.3)
			   (122.0    -26.6    26.6)
			   (123.0    -26.9    26.9)
			   (124.0    -27.2    27.2)
			   (125.0    -27.6    27.6)
			   (126.0    -27.9    27.9)
			   (127.0    -28.3    28.3)
			   (128.0    -28.7    28.7)
			   (129.0    -29.1    29.1)
			   (130.0    -29.5    29.5)
			   (131.0    -30.0    30.0)
			   (132.0    -30.4    30.4)
			   (133.0    -30.9    30.9)
			   (134.0    -31.5    31.5)
			   (135.0    -32.0    32.0)
			   (136.0    -32.6    32.6)
			   (137.0    -33.2    33.2)
			   (138.0    -33.9    33.9)
			   (139.0    -34.6    34.6)
			   (140.0    -35.3    35.3)
			   (141.0    -36.1    36.1)
			   (142.0    -36.9    36.9)
			   (143.0    -37.8    37.8)
			   (144.0    -38.8    38.8)
			   (145.0    -39.8    39.8)
			   (146.0    -40.8    40.8)
			   (147.0    -42.0    42.0)
			   (148.0    -43.2    43.2)
			   (149.0    -44.5    44.5)
			   (150.0    -45.9    45.9)
			   (151.0    -47.5    47.5)
			   (152.0    -49.1    49.1)
			   (153.0    -50.9    50.9)
			   (154.0    -52.9    52.9)
			   (155.0    -55.0    55.0)
			   (156.0    -57.3    57.3)
			   (157.0    -59.9    59.9)
			   (158.0    -62.8    62.8)
			   (159.0    -66.0    66.0)
			   (160.0    -69.6    69.6)
			   (161.0    -73.6    73.6)
			   (162.0    -78.3    78.3)
			   (163.0    -83.7    83.7)
			   (164.0    -90.1    90.1)
			   (165.0    -97.8    97.8)
			   (166.0   -107.5   107.5)
			   (167.0   -120.3   120.3)
			   (168.0   -139.5   139.5)
			   (169.0   -180.0   180.0))
		         "10.039"
		          (( 50.0    -29.2    29.2)
			   ( 51.0    -28.8    28.8)
			   ( 52.0    -28.4    28.4)
			   ( 53.0    -28.0    28.0)
			   ( 54.0    -27.7    27.7)
			   ( 55.0    -27.3    27.3)
			   ( 56.0    -27.0    27.0)
			   ( 57.0    -26.7    26.7)
			   ( 58.0    -26.4    26.4)
			   ( 59.0    -26.1    26.1)
			   ( 60.0    -25.8    25.8)
			   ( 61.0    -25.5    25.5)
			   ( 62.0    -25.3    25.3)
			   ( 63.0    -25.1    25.1)
			   ( 64.0    -24.8    24.8)
			   ( 65.0    -24.6    24.6)
			   ( 66.0    -24.4    24.4)
			   ( 67.0    -24.3    24.3)
			   ( 68.0    -24.1    24.1)
			   ( 69.0    -23.9    23.9)
			   ( 70.0    -23.8    23.8)
			   ( 71.0    -23.6    23.6)
			   ( 72.0    -23.5    23.5)
			   ( 73.0    -23.3    23.3)
			   ( 74.0    -23.2    23.2)
			   ( 75.0    -23.1    23.1)
			   ( 76.0    -23.0    23.0)
			   ( 77.0    -22.9    22.9)
			   ( 78.0    -22.8    22.8)
			   ( 79.0    -22.7    22.7)
			   ( 80.0    -22.6    22.6)
			   ( 81.0    -22.6    22.6)
			   ( 82.0    -22.5    22.5)
			   ( 83.0    -22.5    22.5)
			   ( 84.0    -22.4    22.4)
			   ( 85.0    -22.4    22.4)
			   ( 86.0    -22.4    22.4)
			   ( 87.0    -22.3    22.3)
			   ( 88.0    -22.3    22.3)
			   ( 89.0    -22.3    22.3)
			   ( 90.0    -22.3    22.3)
			   ( 91.0    -22.3    22.3)
			   ( 92.0    -22.3    22.3)
			   ( 93.0    -22.3    22.3)
			   ( 94.0    -22.4    22.4)
			   ( 95.0    -22.4    22.4)
			   ( 96.0    -22.4    22.4)
			   ( 97.0    -22.5    22.5)
			   ( 98.0    -22.5    22.5)
			   ( 99.0    -22.6    22.6)
			   (100.0    -22.6    22.6)
			   (101.0    -22.7    22.7)
			   (102.0    -22.8    22.8)
			   (103.0    -22.9    22.9)
			   (104.0    -23.0    23.0)
			   (105.0    -23.1    23.1)
			   (106.0    -23.2    23.2)
			   (107.0    -23.3    23.3)
			   (108.0    -23.5    23.5)
			   (109.0    -23.6    23.6)
			   (110.0    -23.8    23.8)
			   (111.0    -23.9    23.9)
			   (112.0    -24.1    24.1)
			   (113.0    -24.3    24.3)
			   (114.0    -24.4    24.4)
			   (115.0    -24.6    24.6)
			   (116.0    -24.8    24.8)
			   (117.0    -25.1    25.1)
			   (118.0    -25.3    25.3)
			   (119.0    -25.5    25.5)
			   (120.0    -25.8    25.8)
			   (121.0    -26.1    26.1)
			   (122.0    -26.4    26.4)
			   (123.0    -26.7    26.7)
			   (124.0    -27.0    27.0)
			   (125.0    -27.3    27.3)
			   (126.0    -27.7    27.7)
			   (127.0    -28.0    28.0)
			   (128.0    -28.4    28.4)
			   (129.0    -28.8    28.8)
			   (130.0    -29.2    29.2)
			   (131.0    -29.7    29.7)
			   (132.0    -30.2    30.2)
			   (133.0    -30.7    30.7)
			   (134.0    -31.2    31.2)
			   (135.0    -31.7    31.7)
			   (136.0    -32.3    32.3)
			   (137.0    -32.9    32.9)
			   (138.0    -33.6    33.6)
			   (139.0    -34.3    34.3)
			   (140.0    -35.0    35.0)
			   (141.0    -35.8    35.8)
			   (142.0    -36.6    36.6)
			   (143.0    -37.5    37.5)
			   (144.0    -38.4    38.4)
			   (145.0    -39.4    39.4)
			   (146.0    -40.5    40.5)
			   (147.0    -41.6    41.6)
			   (148.0    -42.8    42.8)
			   (149.0    -44.1    44.1)
			   (150.0    -45.5    45.5)
			   (151.0    -47.0    47.0)
			   (152.0    -48.6    48.6)
			   (153.0    -50.4    50.4)
			   (154.0    -52.4    52.4)
			   (155.0    -54.5    54.5)
			   (156.0    -56.8    56.8)
			   (157.0    -59.3    59.3)
			   (158.0    -62.2    62.2)
			   (159.0    -65.3    65.3)
			   (160.0    -68.9    68.9)
			   (161.0    -72.9    72.9)
			   (162.0    -77.5    77.5)
			   (163.0    -82.8    82.8)
			   (164.0    -89.1    89.1)
			   (165.0    -96.7    96.7)
			   (166.0   -106.1   106.1)
			   (167.0   -118.6   118.6)
			   (168.0   -136.9   136.9)
			   (169.0   -180.0   180.0))
		         "10.060"
		          (( 50.0    -26.9    26.9)
			   ( 51.0    -26.5    26.5)
			   ( 52.0    -26.1    26.1)
			   ( 53.0    -25.7    25.7)
			   ( 54.0    -25.4    25.4)
			   ( 55.0    -25.1    25.1)
			   ( 56.0    -24.8    24.8)
			   ( 57.0    -24.5    24.5)
			   ( 58.0    -24.2    24.2)
			   ( 59.0    -24.0    24.0)
			   ( 60.0    -23.7    23.7)
			   ( 61.0    -23.5    23.5)
			   ( 62.0    -23.3    23.3)
			   ( 63.0    -23.0    23.0)
			   ( 64.0    -22.8    22.8)
			   ( 65.0    -22.6    22.6)
			   ( 66.0    -22.5    22.5)
			   ( 67.0    -22.3    22.3)
			   ( 68.0    -22.1    22.1)
			   ( 69.0    -22.0    22.0)
			   ( 70.0    -21.8    21.8)
			   ( 71.0    -21.7    21.7)
			   ( 72.0    -21.6    21.6)
			   ( 73.0    -21.4    21.4)
			   ( 74.0    -21.3    21.3)
			   ( 75.0    -21.2    21.2)
			   ( 76.0    -21.1    21.1)
			   ( 77.0    -21.0    21.0)
			   ( 78.0    -21.0    21.0)
			   ( 79.0    -20.9    20.9)
			   ( 80.0    -20.8    20.8)
			   ( 81.0    -20.8    20.8)
			   ( 82.0    -20.7    20.7)
			   ( 83.0    -20.7    20.7)
			   ( 84.0    -20.6    20.6)
			   ( 85.0    -20.6    20.6)
			   ( 86.0    -20.6    20.6)
			   ( 87.0    -20.5    20.5)
			   ( 88.0    -20.5    20.5)
			   ( 89.0    -20.5    20.5)
			   ( 90.0    -20.5    20.5)
			   ( 91.0    -20.5    20.5)
			   ( 92.0    -20.5    20.5)
			   ( 93.0    -20.5    20.5)
			   ( 94.0    -20.6    20.6)
			   ( 95.0    -20.6    20.6)
			   ( 96.0    -20.6    20.6)
			   ( 97.0    -20.7    20.7)
			   ( 98.0    -20.7    20.7)
			   ( 99.0    -20.8    20.8)
			   (100.0    -20.8    20.8)
			   (101.0    -20.9    20.9)
			   (102.0    -21.0    21.0)
			   (103.0    -21.0    21.0)
			   (104.0    -21.1    21.1)
			   (105.0    -21.2    21.2)
			   (106.0    -21.3    21.3)
			   (107.0    -21.4    21.4)
			   (108.0    -21.6    21.6)
			   (109.0    -21.7    21.7)
			   (110.0    -21.8    21.8)
			   (111.0    -22.0    22.0)
			   (112.0    -22.1    22.1)
			   (113.0    -22.3    22.3)
			   (114.0    -22.5    22.5)
			   (115.0    -22.6    22.6)
			   (116.0    -22.8    22.8)
			   (117.0    -23.0    23.0)
			   (118.0    -23.3    23.3)
			   (119.0    -23.5    23.5)
			   (120.0    -23.7    23.7)
			   (121.0    -24.0    24.0)
			   (122.0    -24.2    24.2)
			   (123.0    -24.5    24.5)
			   (124.0    -24.8    24.8)
			   (125.0    -25.1    25.1)
			   (126.0    -25.4    25.4)
			   (127.0    -25.7    25.7)
			   (128.0    -26.1    26.1)
			   (129.0    -26.5    26.5)
			   (130.0    -26.9    26.9)
			   (131.0    -27.3    27.3)
			   (132.0    -27.7    27.7)
			   (133.0    -28.2    28.2)
			   (134.0    -28.6    28.6)
			   (135.0    -29.2    29.2)
			   (136.0    -29.7    29.7)
			   (137.0    -30.2    30.2)
			   (138.0    -30.8    30.8)
			   (139.0    -31.5    31.5)
			   (140.0    -32.1    32.1)
			   (141.0    -32.8    32.8)
			   (142.0    -33.6    33.6)
			   (143.0    -34.4    34.4)
			   (144.0    -35.2    35.2)
			   (145.0    -36.1    36.1)
			   (146.0    -37.1    37.1)
			   (147.0    -38.1    38.1)
			   (148.0    -39.2    39.2)
			   (149.0    -40.4    40.4)
			   (150.0    -41.7    41.7)
			   (151.0    -43.1    43.1)
			   (152.0    -44.5    44.5)
			   (153.0    -46.2    46.2)
			   (154.0    -47.9    47.9)
			   (155.0    -49.8    49.8)
			   (156.0    -51.9    51.9)
			   (157.0    -54.2    54.2)
			   (158.0    -56.7    56.7)
			   (159.0    -59.5    59.5)
			   (160.0    -62.7    62.7)
			   (161.0    -66.3    66.3)
			   (162.0    -70.3    70.3)
			   (163.0    -75.0    75.0)
			   (164.0    -80.4    80.4)
			   (165.0    -86.9    86.9)
			   (166.0    -94.7    94.7)
			   (167.0   -104.6   104.6)
			   (168.0   -117.7   117.7)
			   (169.0   -137.7   137.7)
			   (170.0   -180.0   180.0))
		         "10.081"
		          (( 50.0    -21.7    21.7)
			   ( 51.0    -21.4    21.4)
			   ( 52.0    -21.1    21.1)
			   ( 53.0    -20.8    20.8)
			   ( 54.0    -20.6    20.6)
			   ( 55.0    -20.3    20.3)
			   ( 56.0    -20.1    20.1)
			   ( 57.0    -19.8    19.8)
			   ( 58.0    -19.6    19.6)
			   ( 59.0    -19.4    19.4)
			   ( 60.0    -19.2    19.2)
			   ( 61.0    -19.0    19.0)
			   ( 62.0    -18.8    18.8)
			   ( 63.0    -18.6    18.6)
			   ( 64.0    -18.5    18.5)
			   ( 65.0    -18.3    18.3)
			   ( 66.0    -18.2    18.2)
			   ( 67.0    -18.0    18.0)
			   ( 68.0    -17.9    17.9)
			   ( 69.0    -17.8    17.8)
			   ( 70.0    -17.7    17.7)
			   ( 71.0    -17.6    17.6)
			   ( 72.0    -17.5    17.5)
			   ( 73.0    -17.4    17.4)
			   ( 74.0    -17.3    17.3)
			   ( 75.0    -17.2    17.2)
			   ( 76.0    -17.1    17.1)
			   ( 77.0    -17.0    17.0)
			   ( 78.0    -17.0    17.0)
			   ( 79.0    -16.9    16.9)
			   ( 80.0    -16.9    16.9)
			   ( 81.0    -16.8    16.8)
			   ( 82.0    -16.8    16.8)
			   ( 83.0    -16.7    16.7)
			   ( 84.0    -16.7    16.7)
			   ( 85.0    -16.7    16.7)
			   ( 86.0    -16.6    16.6)
			   ( 87.0    -16.6    16.6)
			   ( 88.0    -16.6    16.6)
			   ( 89.0    -16.6    16.6)
			   ( 90.0    -16.6    16.6)
			   ( 91.0    -16.6    16.6)
			   ( 92.0    -16.6    16.6)
			   ( 93.0    -16.6    16.6)
			   ( 94.0    -16.6    16.6)
			   ( 95.0    -16.7    16.7)
			   ( 96.0    -16.7    16.7)
			   ( 97.0    -16.7    16.7)
			   ( 98.0    -16.8    16.8)
			   ( 99.0    -16.8    16.8)
			   (100.0    -16.9    16.9)
			   (101.0    -16.9    16.9)
			   (102.0    -17.0    17.0)
			   (103.0    -17.0    17.0)
			   (104.0    -17.1    17.1)
			   (105.0    -17.2    17.2)
			   (106.0    -17.3    17.3)
			   (107.0    -17.4    17.4)
			   (108.0    -17.5    17.5)
			   (109.0    -17.6    17.6)
			   (110.0    -17.7    17.7)
			   (111.0    -17.8    17.8)
			   (112.0    -17.9    17.9)
			   (113.0    -18.0    18.0)
			   (114.0    -18.2    18.2)
			   (115.0    -18.3    18.3)
			   (116.0    -18.5    18.5)
			   (117.0    -18.6    18.6)
			   (118.0    -18.8    18.8)
			   (119.0    -19.0    19.0)
			   (120.0    -19.2    19.2)
			   (121.0    -19.4    19.4)
			   (122.0    -19.6    19.6)
			   (123.0    -19.8    19.8)
			   (124.0    -20.1    20.1)
			   (125.0    -20.3    20.3)
			   (126.0    -20.6    20.6)
			   (127.0    -20.8    20.8)
			   (128.0    -21.1    21.1)
			   (129.0    -21.4    21.4)
			   (130.0    -21.7    21.7)
			   (131.0    -22.1    22.1)
			   (132.0    -22.4    22.4)
			   (133.0    -22.8    22.8)
			   (134.0    -23.2    23.2)
			   (135.0    -23.6    23.6)
			   (136.0    -24.0    24.0)
			   (137.0    -24.4    24.4)
			   (138.0    -24.9    24.9)
			   (139.0    -25.4    25.4)
			   (140.0    -26.0    26.0)
			   (141.0    -26.5    26.5)
			   (142.0    -27.1    27.1)
			   (143.0    -27.8    27.8)
			   (144.0    -28.4    28.4)
			   (145.0    -29.2    29.2)
			   (146.0    -29.9    29.9)
			   (147.0    -30.7    30.7)
			   (148.0    -31.6    31.6)
			   (149.0    -32.6    32.6)
			   (150.0    -33.6    33.6)
			   (151.0    -34.6    34.6)
			   (152.0    -35.8    35.8)
			   (153.0    -37.1    37.1)
			   (154.0    -38.5    38.5)
			   (155.0    -39.9    39.9)
			   (156.0    -41.6    41.6)
			   (157.0    -43.4    43.4)
			   (158.0    -45.3    45.3)
			   (159.0    -47.5    47.5)
			   (160.0    -49.9    49.9)
			   (161.0    -52.6    52.6)
			   (162.0    -55.7    55.7)
			   (163.0    -59.2    59.2)
			   (164.0    -63.2    63.2)
			   (165.0    -67.8    67.8)
			   (166.0    -73.3    73.3)
			   (167.0    -79.8    79.8)
			   (168.0    -87.9    87.9)
			   (169.0    -98.3    98.3)
			   (170.0   -112.5   112.5)
		           (171.0   -134.7   134.7)
                           (172.0   -180.0   180.0))
		         "10.130"
		          (( 50.0    -16.9    16.9)
			   ( 51.0    -16.6    16.6)
			   ( 52.0    -16.4    16.4)
			   ( 53.0    -16.2    16.2)
			   ( 54.0    -16.0    16.0)
			   ( 55.0    -15.8    15.8)
			   ( 56.0    -15.6    15.6)
			   ( 57.0    -15.4    15.4)
			   ( 58.0    -15.2    15.2)
			   ( 59.0    -15.1    15.1)
			   ( 60.0    -14.9    14.9)
			   ( 61.0    -14.8    14.8)
			   ( 62.0    -14.6    14.6)
			   ( 63.0    -14.5    14.5)
			   ( 64.0    -14.4    14.4)
			   ( 65.0    -14.2    14.2)
			   ( 66.0    -14.1    14.1)
			   ( 67.0    -14.0    14.0)
			   ( 68.0    -13.9    13.9)
			   ( 69.0    -13.8    13.8)
			   ( 70.0    -13.7    13.7)
			   ( 71.0    -13.6    13.6)
			   ( 72.0    -13.6    13.6)
			   ( 73.0    -13.5    13.5)
			   ( 74.0    -13.4    13.4)
			   ( 75.0    -13.4    13.4)
			   ( 76.0    -13.3    13.3)
			   ( 77.0    -13.2    13.2)
			   ( 78.0    -13.2    13.2)
			   ( 79.0    -13.1    13.1)
			   ( 80.0    -13.1    13.1)
			   ( 81.0    -13.1    13.1)
			   ( 82.0    -13.0    13.0)
			   ( 83.0    -13.0    13.0)
			   ( 84.0    -13.0    13.0)
			   ( 85.0    -12.9    12.9)
			   ( 86.0    -12.9    12.9)
			   ( 87.0    -12.9    12.9)
			   ( 88.0    -12.9    12.9)
			   ( 89.0    -12.9    12.9)
			   ( 90.0    -12.9    12.9)
			   ( 91.0    -12.9    12.9)
			   ( 92.0    -12.9    12.9)
			   ( 93.0    -12.9    12.9)
			   ( 94.0    -12.9    12.9)
			   ( 95.0    -12.9    12.9)
			   ( 96.0    -13.0    13.0)
			   ( 97.0    -13.0    13.0)
			   ( 98.0    -13.0    13.0)
			   ( 99.0    -13.1    13.1)
			   (100.0    -13.1    13.1)
			   (101.0    -13.1    13.1)
			   (102.0    -13.2    13.2)
			   (103.0    -13.2    13.2)
			   (104.0    -13.3    13.3)
			   (105.0    -13.4    13.4)
			   (106.0    -13.4    13.4)
			   (107.0    -13.5    13.5)
			   (108.0    -13.6    13.6)
			   (109.0    -13.6    13.6)
			   (110.0    -13.7    13.7)
			   (111.0    -13.8    13.8)
			   (112.0    -13.9    13.9)
			   (113.0    -14.0    14.0)
			   (114.0    -14.1    14.1)
			   (115.0    -14.2    14.2)
			   (116.0    -14.4    14.4)
			   (117.0    -14.5    14.5)
			   (118.0    -14.6    14.6)
			   (119.0    -14.8    14.8)
			   (120.0    -14.9    14.9)
			   (121.0    -15.1    15.1)
			   (122.0    -15.2    15.2)
			   (123.0    -15.4    15.4)
			   (124.0    -15.6    15.6)
			   (125.0    -15.8    15.8)
			   (126.0    -16.0    16.0)
			   (127.0    -16.2    16.2)
			   (128.0    -16.4    16.4)
			   (129.0    -16.6    16.6)
			   (130.0    -16.9    16.9)
			   (131.0    -17.1    17.1)
			   (132.0    -17.4    17.4)
			   (133.0    -17.7    17.7)
			   (134.0    -18.0    18.0)
			   (135.0    -18.3    18.3)
			   (136.0    -18.6    18.6)
			   (137.0    -19.0    19.0)
			   (138.0    -19.3    19.3)
			   (139.0    -19.7    19.7)
			   (140.0    -20.1    20.1)
			   (141.0    -20.6    20.6)
			   (142.0    -21.0    21.0)
			   (143.0    -21.5    21.5)
			   (144.0    -22.0    22.0)
			   (145.0    -22.6    22.6)
			   (146.0    -23.2    23.2)
			   (147.0    -23.8    23.8)
			   (148.0    -24.5    24.5)
			   (149.0    -25.2    25.2)
			   (150.0    -26.0    26.0)
			   (151.0    -26.8    26.8)
			   (152.0    -27.7    27.7)
			   (153.0    -28.7    28.7)
			   (154.0    -29.7    29.7)
			   (155.0    -30.8    30.8)
			   (156.0    -32.1    32.1)
			   (157.0    -33.4    33.4)
			   (158.0    -34.9    34.9)
			   (159.0    -36.5    36.5)
			   (160.0    -38.3    38.3)
			   (161.0    -40.4    40.4)
			   (162.0    -42.6    42.6)
			   (163.0    -45.2    45.2)
			   (164.0    -48.1    48.1)
			   (165.0    -51.4    51.4)
			   (166.0    -55.3    55.3)
			   (167.0    -59.9    59.9)
			   (168.0    -65.4    65.4)
			   (169.0    -72.1    72.1)
			   (170.0    -80.6    80.6)
                           (171.0    -91.8    91.8)
                           (172.0   -107.6   107.6)
                           (173.0   -134.4   134.4)
                           (174.0   -180.0   180.0))
		         "10.179"
		          (( 50.0    -15.7    15.7)
			   ( 51.0    -15.5    15.5)
			   ( 52.0    -15.2    15.2)
			   ( 53.0    -15.0    15.0)
			   ( 54.0    -14.8    14.8)
			   ( 55.0    -14.7    14.7)
			   ( 56.0    -14.5    14.5)
			   ( 57.0    -14.3    14.3)
			   ( 58.0    -14.2    14.2)
			   ( 59.0    -14.0    14.0)
			   ( 60.0    -13.9    13.9)
			   ( 61.0    -13.7    13.7)
			   ( 62.0    -13.6    13.6)
			   ( 63.0    -13.5    13.5)
			   ( 64.0    -13.4    13.4)
			   ( 65.0    -13.2    13.2)
			   ( 66.0    -13.1    13.1)
			   ( 67.0    -13.0    13.0)
			   ( 68.0    -12.9    12.9)
			   ( 69.0    -12.9    12.9)
			   ( 70.0    -12.8    12.8)
			   ( 71.0    -12.7    12.7)
			   ( 72.0    -12.6    12.6)
			   ( 73.0    -12.6    12.6)
			   ( 74.0    -12.5    12.5)
			   ( 75.0    -12.4    12.4)
			   ( 76.0    -12.4    12.4)
			   ( 77.0    -12.3    12.3)
			   ( 78.0    -12.3    12.3)
			   ( 79.0    -12.2    12.2)
			   ( 80.0    -12.2    12.2)
			   ( 81.0    -12.2    12.2)
			   ( 82.0    -12.1    12.1)
			   ( 83.0    -12.1    12.1)
			   ( 84.0    -12.1    12.1)
			   ( 85.0    -12.0    12.0)
			   ( 86.0    -12.0    12.0)
			   ( 87.0    -12.0    12.0)
			   ( 88.0    -12.0    12.0)
			   ( 89.0    -12.0    12.0)
			   ( 90.0    -12.0    12.0)
			   ( 91.0    -12.0    12.0)
			   ( 92.0    -12.0    12.0)
			   ( 93.0    -12.0    12.0)
			   ( 94.0    -12.0    12.0)
			   ( 95.0    -12.0    12.0)
			   ( 96.0    -12.1    12.1)
			   ( 97.0    -12.1    12.1)
			   ( 98.0    -12.1    12.1)
			   ( 99.0    -12.2    12.2)
			   (100.0    -12.2    12.2)
			   (101.0    -12.2    12.2)
			   (102.0    -12.3    12.3)
			   (103.0    -12.3    12.3)
			   (104.0    -12.4    12.4)
			   (105.0    -12.4    12.4)
			   (106.0    -12.5    12.5)
			   (107.0    -12.6    12.6)
			   (108.0    -12.6    12.6)
			   (109.0    -12.7    12.7)
			   (110.0    -12.8    12.8)
			   (111.0    -12.9    12.9)
			   (112.0    -12.9    12.9)
			   (113.0    -13.0    13.0)
			   (114.0    -13.1    13.1)
			   (115.0    -13.2    13.2)
			   (116.0    -13.4    13.4)
			   (117.0    -13.5    13.5)
			   (118.0    -13.6    13.6)
			   (119.0    -13.7    13.7)
			   (120.0    -13.9    13.9)
			   (121.0    -14.0    14.0)
			   (122.0    -14.2    14.2)
			   (123.0    -14.3    14.3)
			   (124.0    -14.5    14.5)
			   (125.0    -14.7    14.7)
			   (126.0    -14.8    14.8)
			   (127.0    -15.0    15.0)
			   (128.0    -15.2    15.2)
			   (129.0    -15.5    15.5)
			   (130.0    -15.7    15.7)
			   (131.0    -15.9    15.9)
			   (132.0    -16.2    16.2)
			   (133.0    -16.4    16.4)
			   (134.0    -16.7    16.7)
			   (135.0    -17.0    17.0)
			   (136.0    -17.3    17.3)
			   (137.0    -17.6    17.6)
			   (138.0    -18.0    18.0)
			   (139.0    -18.3    18.3)
			   (140.0    -18.7    18.7)
			   (141.0    -19.1    19.1)
			   (142.0    -19.6    19.6)
			   (143.0    -20.0    20.0)
			   (144.0    -20.5    20.5)
			   (145.0    -21.0    21.0)
			   (146.0    -21.5    21.5)
			   (147.0    -22.1    22.1)
			   (148.0    -22.8    22.8)
			   (149.0    -23.4    23.4)
			   (150.0    -24.1    24.1)
			   (151.0    -24.9    24.9)
			   (152.0    -25.7    25.7)
			   (153.0    -26.6    26.6)
			   (154.0    -27.6    27.6)
			   (155.0    -28.6    28.6)
			   (156.0    -29.8    29.8)
			   (157.0    -31.0    31.0)
			   (158.0    -32.4    32.4)
			   (159.0    -33.9    33.9)
			   (160.0    -35.6    35.6)
			   (161.0    -37.5    37.5)
			   (162.0    -39.5    39.5)
			   (163.0    -41.9    41.9)
			   (164.0    -44.6    44.6)
			   (165.0    -47.6    47.6)
			   (166.0    -51.2    51.2)
			   (167.0    -55.4    55.4)
			   (168.0    -60.4    60.4)
			   (169.0    -66.4    66.4)
                           (170.0    -74.0    74.0)
                           (171.0    -83.9    83.9)
                           (172.0    -97.4    97.4)
                           (173.0   -118.1   118.1)
                           (174.0   -180.0   180.0))
		         "10.221"
		          (( 50.0    -18.6    18.6)
			   ( 51.0    -18.3    18.3)
			   ( 52.0    -18.0    18.0)
			   ( 53.0    -17.8    17.8)
			   ( 54.0    -17.6    17.6)
			   ( 55.0    -17.4    17.4)
			   ( 56.0    -17.1    17.1)
			   ( 57.0    -17.0    17.0)
			   ( 58.0    -16.8    16.8)
			   ( 59.0    -16.6    16.6)
			   ( 60.0    -16.4    16.4)
			   ( 61.0    -16.2    16.2)
			   ( 62.0    -16.1    16.1)
			   ( 63.0    -15.9    15.9)
			   ( 64.0    -15.8    15.8)
			   ( 65.0    -15.7    15.7)
			   ( 66.0    -15.6    15.6)
			   ( 67.0    -15.4    15.4)
			   ( 68.0    -15.3    15.3)
			   ( 69.0    -15.2    15.2)
			   ( 70.0    -15.1    15.1)
			   ( 71.0    -15.0    15.0)
			   ( 72.0    -14.9    14.9)
			   ( 73.0    -14.9    14.9)
			   ( 74.0    -14.8    14.8)
			   ( 75.0    -14.7    14.7)
			   ( 76.0    -14.6    14.6)
			   ( 77.0    -14.6    14.6)
			   ( 78.0    -14.5    14.5)
			   ( 79.0    -14.5    14.5)
			   ( 80.0    -14.4    14.4)
			   ( 81.0    -14.4    14.4)
			   ( 82.0    -14.3    14.3)
			   ( 83.0    -14.3    14.3)
			   ( 84.0    -14.3    14.3)
			   ( 85.0    -14.3    14.3)
			   ( 86.0    -14.2    14.2)
			   ( 87.0    -14.2    14.2)
			   ( 88.0    -14.2    14.2)
			   ( 89.0    -14.2    14.2)
			   ( 90.0    -14.2    14.2)
			   ( 91.0    -14.2    14.2)
			   ( 92.0    -14.2    14.2)
			   ( 93.0    -14.2    14.2)
			   ( 94.0    -14.2    14.2)
			   ( 95.0    -14.3    14.3)
			   ( 96.0    -14.3    14.3)
			   ( 97.0    -14.3    14.3)
			   ( 98.0    -14.3    14.3)
			   ( 99.0    -14.4    14.4)
			   (100.0    -14.4    14.4)
			   (101.0    -14.5    14.5)
			   (102.0    -14.5    14.5)
			   (103.0    -14.6    14.6)
			   (104.0    -14.6    14.6)
			   (105.0    -14.7    14.7)
			   (106.0    -14.8    14.8)
			   (107.0    -14.9    14.9)
			   (108.0    -14.9    14.9)
			   (109.0    -15.0    15.0)
			   (110.0    -15.1    15.1)
			   (111.0    -15.2    15.2)
			   (112.0    -15.3    15.3)
			   (113.0    -15.4    15.4)
			   (114.0    -15.6    15.6)
			   (115.0    -15.7    15.7)
			   (116.0    -15.8    15.8)
			   (117.0    -15.9    15.9)
			   (118.0    -16.1    16.1)
			   (119.0    -16.2    16.2)
			   (120.0    -16.4    16.4)
			   (121.0    -16.6    16.6)
			   (122.0    -16.8    16.8)
			   (123.0    -17.0    17.0)
			   (124.0    -17.1    17.1)
			   (125.0    -17.4    17.4)
			   (126.0    -17.6    17.6)
			   (127.0    -17.8    17.8)
			   (128.0    -18.0    18.0)
			   (129.0    -18.3    18.3)
			   (130.0    -18.6    18.6)
			   (131.0    -18.9    18.9)
			   (132.0    -19.1    19.1)
			   (133.0    -19.5    19.5)
			   (134.0    -19.8    19.8)
			   (135.0    -20.1    20.1)
			   (136.0    -20.5    20.5)
			   (137.0    -20.9    20.9)
			   (138.0    -21.3    21.3)
			   (139.0    -21.7    21.7)
			   (140.0    -22.2    22.2)
			   (141.0    -22.7    22.7)
			   (142.0    -23.2    23.2)
			   (143.0    -23.7    23.7)
			   (144.0    -24.3    24.3)
			   (145.0    -24.9    24.9)
			   (146.0    -25.5    25.5)
			   (147.0    -26.2    26.2)
			   (148.0    -27.0    27.0)
			   (149.0    -27.8    27.8)
			   (150.0    -28.6    28.6)
			   (151.0    -29.5    29.5)
			   (152.0    -30.5    30.5)
			   (153.0    -31.6    31.6)
			   (154.0    -32.8    32.8)
			   (155.0    -34.0    34.0)
			   (156.0    -35.4    35.4)
			   (157.0    -36.9    36.9)
			   (158.0    -38.5    38.5)
			   (159.0    -40.4    40.4)
			   (160.0    -42.4    42.4)
			   (161.0    -44.6    44.6)
			   (162.0    -47.2    47.2)
			   (163.0    -50.0    50.0)
			   (164.0    -53.3    53.3)
			   (165.0    -57.1    57.1)
			   (166.0    -61.4    61.4)
			   (167.0    -66.7    66.7)
			   (168.0    -73.0    73.0)
			   (169.0    -80.7    80.7)
                           (170.0    -90.8    90.8)
                           (171.0   -104.4   104.4)
                           (172.0   -125.3   125.3)
                           (173.0   -180.0   180.0))
		         "10.291"
		          (( 50.0    -26.3    26.3)
			   ( 51.0    -26.0    26.0)
			   ( 52.0    -25.6    25.6)
			   ( 53.0    -25.2    25.2)
			   ( 54.0    -24.9    24.9)
			   ( 55.0    -24.6    24.6)
			   ( 56.0    -24.3    24.3)
			   ( 57.0    -24.0    24.0)
			   ( 58.0    -23.7    23.7)
			   ( 59.0    -23.5    23.5)
			   ( 60.0    -23.2    23.2)
			   ( 61.0    -23.0    23.0)
			   ( 62.0    -22.8    22.8)
			   ( 63.0    -22.6    22.6)
			   ( 64.0    -22.4    22.4)
			   ( 65.0    -22.2    22.2)
			   ( 66.0    -22.0    22.0)
			   ( 67.0    -21.9    21.9)
			   ( 68.0    -21.7    21.7)
			   ( 69.0    -21.5    21.5)
			   ( 70.0    -21.4    21.4)
			   ( 71.0    -21.3    21.3)
			   ( 72.0    -21.1    21.1)
			   ( 73.0    -21.0    21.0)
			   ( 74.0    -20.9    20.9)
			   ( 75.0    -20.8    20.8)
			   ( 76.0    -20.7    20.7)
			   ( 77.0    -20.6    20.6)
			   ( 78.0    -20.6    20.6)
			   ( 79.0    -20.5    20.5)
			   ( 80.0    -20.4    20.4)
			   ( 81.0    -20.4    20.4)
			   ( 82.0    -20.3    20.3)
			   ( 83.0    -20.3    20.3)
			   ( 84.0    -20.2    20.2)
			   ( 85.0    -20.2    20.2)
			   ( 86.0    -20.1    20.1)
			   ( 87.0    -20.1    20.1)
			   ( 88.0    -20.1    20.1)
			   ( 89.0    -20.1    20.1)
			   ( 90.0    -20.1    20.1)
			   ( 91.0    -20.1    20.1)
			   ( 92.0    -20.1    20.1)
			   ( 93.0    -20.1    20.1)
			   ( 94.0    -20.1    20.1)
			   ( 95.0    -20.2    20.2)
			   ( 96.0    -20.2    20.2)
			   ( 97.0    -20.3    20.3)
			   ( 98.0    -20.3    20.3)
			   ( 99.0    -20.4    20.4)
			   (100.0    -20.4    20.4)
			   (101.0    -20.5    20.5)
			   (102.0    -20.6    20.6)
			   (103.0    -20.6    20.6)
			   (104.0    -20.7    20.7)
			   (105.0    -20.8    20.8)
			   (106.0    -20.9    20.9)
			   (107.0    -21.0    21.0)
			   (108.0    -21.1    21.1)
			   (109.0    -21.3    21.3)
			   (110.0    -21.4    21.4)
			   (111.0    -21.5    21.5)
			   (112.0    -21.7    21.7)
			   (113.0    -21.9    21.9)
			   (114.0    -22.0    22.0)
			   (115.0    -22.2    22.2)
			   (116.0    -22.4    22.4)
			   (117.0    -22.6    22.6)
			   (118.0    -22.8    22.8)
			   (119.0    -23.0    23.0)
			   (120.0    -23.2    23.2)
			   (121.0    -23.5    23.5)
			   (122.0    -23.7    23.7)
			   (123.0    -24.0    24.0)
			   (124.0    -24.3    24.3)
			   (125.0    -24.6    24.6)
			   (126.0    -24.9    24.9)
			   (127.0    -25.2    25.2)
			   (128.0    -25.6    25.6)
			   (129.0    -26.0    26.0)
			   (130.0    -26.3    26.3)
			   (131.0    -26.7    26.7)
			   (132.0    -27.2    27.2)
			   (133.0    -27.6    27.6)
			   (134.0    -28.1    28.1)
			   (135.0    -28.6    28.6)
			   (136.0    -29.1    29.1)
			   (137.0    -29.7    29.7)
			   (138.0    -30.2    30.2)
			   (139.0    -30.9    30.9)
			   (140.0    -31.5    31.5)
			   (141.0    -32.2    32.2)
			   (142.0    -32.9    32.9)
			   (143.0    -33.7    33.7)
			   (144.0    -34.5    34.5)
			   (145.0    -35.4    35.4)
			   (146.0    -36.4    36.4)
			   (147.0    -37.4    37.4)
			   (148.0    -38.5    38.5)
			   (149.0    -39.6    39.6)
			   (150.0    -40.9    40.9)
			   (151.0    -42.2    42.2)
			   (152.0    -43.6    43.6)
			   (153.0    -45.2    45.2)
			   (154.0    -46.9    46.9)
			   (155.0    -48.8    48.8)
			   (156.0    -50.8    50.8)
			   (157.0    -53.1    53.1)
			   (158.0    -55.5    55.5)
			   (159.0    -58.3    58.3)
			   (160.0    -61.4    61.4)
			   (161.0    -64.8    64.8)
			   (162.0    -68.8    68.8)
			   (163.0    -73.3    73.3)
			   (164.0    -78.6    78.6)
			   (165.0    -84.8    84.8)
			   (166.0    -92.3    92.3)
			   (167.0   -101.7   101.7)
			   (168.0   -114.1   114.1)
			   (169.0   -132.3   132.3)
                           (170.0   -180.0   180.0)
                           (171.0    -83.9    83.9)
                           (172.0    -97.4    97.4)
                           (173.0   -118.1   118.1)
                           (174.0   -180.0   180.0))
		         "10.333"
		          (( 50.0    -29.5    29.5)
			   ( 51.0    -29.1    29.1)
			   ( 52.0    -28.7    28.7)
			   ( 53.0    -28.3    28.3)
			   ( 54.0    -27.9    27.9)
			   ( 55.0    -27.6    27.6)
			   ( 56.0    -27.2    27.2)
			   ( 57.0    -26.9    26.9)
			   ( 58.0    -26.6    26.6)
			   ( 59.0    -26.3    26.3)
			   ( 60.0    -26.0    26.0)
			   ( 61.0    -25.8    25.8)
			   ( 62.0    -25.5    25.5)
			   ( 63.0    -25.3    25.3)
			   ( 64.0    -25.1    25.1)
			   ( 65.0    -24.9    24.9)
			   ( 66.0    -24.7    24.7)
			   ( 67.0    -24.5    24.5)
			   ( 68.0    -24.3    24.3)
			   ( 69.0    -24.1    24.1)
			   ( 70.0    -24.0    24.0)
			   ( 71.0    -23.8    23.8)
			   ( 72.0    -23.7    23.7)
			   ( 73.0    -23.5    23.5)
			   ( 74.0    -23.4    23.4)
			   ( 75.0    -23.3    23.3)
			   ( 76.0    -23.2    23.2)
			   ( 77.0    -23.1    23.1)
			   ( 78.0    -23.0    23.0)
			   ( 79.0    -22.9    22.9)
			   ( 80.0    -22.9    22.9)
			   ( 81.0    -22.8    22.8)
			   ( 82.0    -22.7    22.7)
			   ( 83.0    -22.7    22.7)
			   ( 84.0    -22.6    22.6)
			   ( 85.0    -22.6    22.6)
			   ( 86.0    -22.6    22.6)
			   ( 87.0    -22.5    22.5)
			   ( 88.0    -22.5    22.5)
			   ( 89.0    -22.5    22.5)
			   ( 90.0    -22.5    22.5)
			   ( 91.0    -22.5    22.5)
			   ( 92.0    -22.5    22.5)
			   ( 93.0    -22.5    22.5)
			   ( 94.0    -22.6    22.6)
			   ( 95.0    -22.6    22.6)
			   ( 96.0    -22.6    22.6)
			   ( 97.0    -22.7    22.7)
			   ( 98.0    -22.7    22.7)
			   ( 99.0    -22.8    22.8)
			   (100.0    -22.9    22.9)
			   (101.0    -22.9    22.9)
			   (102.0    -23.0    23.0)
			   (103.0    -23.1    23.1)
			   (104.0    -23.2    23.2)
			   (105.0    -23.3    23.3)
			   (106.0    -23.4    23.4)
			   (107.0    -23.5    23.5)
			   (108.0    -23.7    23.7)
			   (109.0    -23.8    23.8)
			   (110.0    -24.0    24.0)
			   (111.0    -24.1    24.1)
			   (112.0    -24.3    24.3)
			   (113.0    -24.5    24.5)
			   (114.0    -24.7    24.7)
			   (115.0    -24.9    24.9)
			   (116.0    -25.1    25.1)
			   (117.0    -25.3    25.3)
			   (118.0    -25.5    25.5)
			   (119.0    -25.8    25.8)
			   (120.0    -26.0    26.0)
			   (121.0    -26.3    26.3)
			   (122.0    -26.6    26.6)
			   (123.0    -26.9    26.9)
			   (124.0    -27.2    27.2)
			   (125.0    -27.6    27.6)
			   (126.0    -27.9    27.9)
			   (127.0    -28.3    28.3)
			   (128.0    -28.7    28.7)
			   (129.0    -29.1    29.1)
			   (130.0    -29.5    29.5)
			   (131.0    -30.0    30.0)
			   (132.0    -30.4    30.4)
			   (133.0    -30.9    30.9)
			   (134.0    -31.5    31.5)
			   (135.0    -32.0    32.0)
			   (136.0    -32.6    32.6)
			   (137.0    -33.2    33.2)
			   (138.0    -33.9    33.9)
			   (139.0    -34.6    34.6)
			   (140.0    -35.3    35.3)
			   (141.0    -36.1    36.1)
			   (142.0    -36.9    36.9)
			   (143.0    -37.8    37.8)
			   (144.0    -38.8    38.8)
			   (145.0    -39.8    39.8)
			   (146.0    -40.8    40.8)
			   (147.0    -42.0    42.0)
			   (148.0    -43.2    43.2)
			   (149.0    -44.5    44.5)
			   (150.0    -45.9    45.9)
			   (151.0    -47.5    47.5)
			   (152.0    -49.1    49.1)
			   (153.0    -50.9    50.9)
			   (154.0    -52.9    52.9)
			   (155.0    -55.0    55.0)
			   (156.0    -57.3    57.3)
			   (157.0    -59.9    59.9)
			   (158.0    -62.8    62.8)
			   (159.0    -66.0    66.0)
			   (160.0    -69.6    69.6)
			   (161.0    -73.6    73.6)
			   (162.0    -78.3    78.3)
			   (163.0    -83.7    83.7)
			   (164.0    -90.1    90.1)
			   (165.0    -97.8    97.8)
			   (166.0   -107.5   107.5)
			   (167.0   -120.3   120.3)
			   (168.0   -139.5   139.5)
			   (169.0   -180.0   180.0))
		         "10.354"
		          (( 50.0    -28.6    28.6)
			   ( 51.0    -28.2    28.2)
			   ( 52.0    -27.8    27.8)
			   ( 53.0    -27.4    27.4)
			   ( 54.0    -27.0    27.0)
			   ( 55.0    -26.7    26.7)
			   ( 56.0    -26.4    26.4)
			   ( 57.0    -26.1    26.1)
			   ( 58.0    -25.8    25.8)
			   ( 59.0    -25.5    25.5)
			   ( 60.0    -25.2    25.2)
			   ( 61.0    -25.0    25.0)
			   ( 62.0    -24.7    24.7)
			   ( 63.0    -24.5    24.5)
			   ( 64.0    -24.3    24.3)
			   ( 65.0    -24.1    24.1)
			   ( 66.0    -23.9    23.9)
			   ( 67.0    -23.7    23.7)
			   ( 68.0    -23.5    23.5)
			   ( 69.0    -23.4    23.4)
			   ( 70.0    -23.2    23.2)
			   ( 71.0    -23.1    23.1)
			   ( 72.0    -22.9    22.9)
			   ( 73.0    -22.8    22.8)
			   ( 74.0    -22.7    22.7)
			   ( 75.0    -22.6    22.6)
			   ( 76.0    -22.5    22.5)
			   ( 77.0    -22.4    22.4)
			   ( 78.0    -22.3    22.3)
			   ( 79.0    -22.2    22.2)
			   ( 80.0    -22.1    22.1)
			   ( 81.0    -22.1    22.1)
			   ( 82.0    -22.0    22.0)
			   ( 83.0    -22.0    22.0)
			   ( 84.0    -21.9    21.9)
			   ( 85.0    -21.9    21.9)
			   ( 86.0    -21.9    21.9)
			   ( 87.0    -21.8    21.8)
			   ( 88.0    -21.8    21.8)
			   ( 89.0    -21.8    21.8)
			   ( 90.0    -21.8    21.8)
			   ( 91.0    -21.8    21.8)
			   ( 92.0    -21.8    21.8)
			   ( 93.0    -21.8    21.8)
			   ( 94.0    -21.9    21.9)
			   ( 95.0    -21.9    21.9)
			   ( 96.0    -21.9    21.9)
			   ( 97.0    -22.0    22.0)
			   ( 98.0    -22.0    22.0)
			   ( 99.0    -22.1    22.1)
			   (100.0    -22.1    22.1)
			   (101.0    -22.2    22.2)
			   (102.0    -22.3    22.3)
			   (103.0    -22.4    22.4)
			   (104.0    -22.5    22.5)
			   (105.0    -22.6    22.6)
			   (106.0    -22.7    22.7)
			   (107.0    -22.8    22.8)
			   (108.0    -22.9    22.9)
			   (109.0    -23.1    23.1)
			   (110.0    -23.2    23.2)
			   (111.0    -23.4    23.4)
			   (112.0    -23.5    23.5)
			   (113.0    -23.7    23.7)
			   (114.0    -23.9    23.9)
			   (115.0    -24.1    24.1)
			   (116.0    -24.3    24.3)
			   (117.0    -24.5    24.5)
			   (118.0    -24.7    24.7)
			   (119.0    -25.0    25.0)
			   (120.0    -25.2    25.2)
			   (121.0    -25.5    25.5)
			   (122.0    -25.8    25.8)
			   (123.0    -26.1    26.1)
			   (124.0    -26.4    26.4)
			   (125.0    -26.7    26.7)
			   (126.0    -27.0    27.0)
			   (127.0    -27.4    27.4)
			   (128.0    -27.8    27.8)
			   (129.0    -28.2    28.2)
			   (130.0    -28.6    28.6)
			   (131.0    -29.0    29.0)
			   (132.0    -29.5    29.5)
			   (133.0    -30.0    30.0)
			   (134.0    -30.5    30.5)
			   (135.0    -31.0    31.0)
			   (136.0    -31.6    31.6)
			   (137.0    -32.2    32.2)
			   (138.0    -32.8    32.8)
			   (139.0    -33.5    33.5)
			   (140.0    -34.2    34.2)
			   (141.0    -35.0    35.0)
			   (142.0    -35.8    35.8)
			   (143.0    -36.6    36.6)
			   (144.0    -37.5    37.5)
			   (145.0    -38.5    38.5)
			   (146.0    -39.5    39.5)
			   (147.0    -40.6    40.6)
			   (148.0    -41.8    41.8)
			   (149.0    -43.1    43.1)
			   (150.0    -44.4    44.4)
			   (151.0    -45.9    45.9)
			   (152.0    -47.5    47.5)
			   (153.0    -49.2    49.2)
			   (154.0    -51.1    51.1)
			   (155.0    -53.2    53.2)
			   (156.0    -55.4    55.4)
			   (157.0    -57.9    57.9)
			   (158.0    -60.6    60.6)
			   (159.0    -63.7    63.7)
			   (160.0    -67.1    67.1)
			   (161.0    -71.0    71.0)
			   (162.0    -75.5    75.5)
			   (163.0    -80.6    80.6)
			   (164.0    -86.6    86.6)
			   (165.0    -93.9    93.9)
			   (166.0   -102.8   102.8)
			   (167.0   -114.4   114.4)
			   (168.0   -130.9   130.9)
			   (169.0   -164.6   164.6)
                           (170.0   -180.0   180.0))
		         "11.017"
		          (( 50.0    -29.5    29.5)
			   ( 51.0    -29.1    29.1)
			   ( 52.0    -28.7    28.7)
			   ( 53.0    -28.3    28.3)
			   ( 54.0    -27.9    27.9)
			   ( 55.0    -27.6    27.6)
			   ( 56.0    -27.2    27.2)
			   ( 57.0    -26.9    26.9)
			   ( 58.0    -26.6    26.6)
			   ( 59.0    -26.3    26.3)
			   ( 60.0    -26.0    26.0)
			   ( 61.0    -25.8    25.8)
			   ( 62.0    -25.5    25.5)
			   ( 63.0    -25.3    25.3)
			   ( 64.0    -25.1    25.1)
			   ( 65.0    -24.9    24.9)
			   ( 66.0    -24.7    24.7)
			   ( 67.0    -24.5    24.5)
			   ( 68.0    -24.3    24.3)
			   ( 69.0    -24.1    24.1)
			   ( 70.0    -24.0    24.0)
			   ( 71.0    -23.8    23.8)
			   ( 72.0    -23.7    23.7)
			   ( 73.0    -23.5    23.5)
			   ( 74.0    -23.4    23.4)
			   ( 75.0    -23.3    23.3)
			   ( 76.0    -23.2    23.2)
			   ( 77.0    -23.1    23.1)
			   ( 78.0    -23.0    23.0)
			   ( 79.0    -22.9    22.9)
			   ( 80.0    -22.9    22.9)
			   ( 81.0    -22.8    22.8)
			   ( 82.0    -22.7    22.7)
			   ( 83.0    -22.7    22.7)
			   ( 84.0    -22.6    22.6)
			   ( 85.0    -22.6    22.6)
			   ( 86.0    -22.6    22.6)
			   ( 87.0    -22.5    22.5)
			   ( 88.0    -22.5    22.5)
			   ( 89.0    -22.5    22.5)
			   ( 90.0    -22.5    22.5)
			   ( 91.0    -22.5    22.5)
			   ( 92.0    -22.5    22.5)
			   ( 93.0    -22.5    22.5)
			   ( 94.0    -22.6    22.6)
			   ( 95.0    -22.6    22.6)
			   ( 96.0    -22.6    22.6)
			   ( 97.0    -22.7    22.7)
			   ( 98.0    -22.7    22.7)
			   ( 99.0    -22.8    22.8)
			   (100.0    -22.9    22.9)
			   (101.0    -22.9    22.9)
			   (102.0    -23.0    23.0)
			   (103.0    -23.1    23.1)
			   (104.0    -23.2    23.2)
			   (105.0    -23.3    23.3)
			   (106.0    -23.4    23.4)
			   (107.0    -23.5    23.5)
			   (108.0    -23.7    23.7)
			   (109.0    -23.8    23.8)
			   (110.0    -24.0    24.0)
			   (111.0    -24.1    24.1)
			   (112.0    -24.3    24.3)
			   (113.0    -24.5    24.5)
			   (114.0    -24.7    24.7)
			   (115.0    -24.9    24.9)
			   (116.0    -25.1    25.1)
			   (117.0    -25.3    25.3)
			   (118.0    -25.5    25.5)
			   (119.0    -25.8    25.8)
			   (120.0    -26.0    26.0)
			   (121.0    -26.3    26.3)
			   (122.0    -26.6    26.6)
			   (123.0    -26.9    26.9)
			   (124.0    -27.2    27.2)
			   (125.0    -27.6    27.6)
			   (126.0    -27.9    27.9)
			   (127.0    -28.3    28.3)
			   (128.0    -28.7    28.7)
			   (129.0    -29.1    29.1)
			   (130.0    -29.5    29.5)
			   (131.0    -30.0    30.0)
			   (132.0    -30.4    30.4)
			   (133.0    -30.9    30.9)
			   (134.0    -31.5    31.5)
			   (135.0    -32.0    32.0)
			   (136.0    -32.6    32.6)
			   (137.0    -33.2    33.2)
			   (138.0    -33.9    33.9)
			   (139.0    -34.6    34.6)
			   (140.0    -35.3    35.3)
			   (141.0    -36.1    36.1)
			   (142.0    -36.9    36.9)
			   (143.0    -37.8    37.8)
			   (144.0    -38.8    38.8)
			   (145.0    -39.8    39.8)
			   (146.0    -40.8    40.8)
			   (147.0    -42.0    42.0)
			   (148.0    -43.2    43.2)
			   (149.0    -44.5    44.5)
			   (150.0    -45.9    45.9)
			   (151.0    -47.5    47.5)
			   (152.0    -49.1    49.1)
			   (153.0    -50.9    50.9)
			   (154.0    -52.9    52.9)
			   (155.0    -55.0    55.0)
			   (156.0    -57.3    57.3)
			   (157.0    -59.9    59.9)
			   (158.0    -62.8    62.8)
			   (159.0    -66.0    66.0)
			   (160.0    -69.6    69.6)
			   (161.0    -73.6    73.6)
			   (162.0    -78.3    78.3)
			   (163.0    -83.7    83.7)
			   (164.0    -90.1    90.1)
			   (165.0    -97.8    97.8)
			   (166.0   -107.5   107.5)
			   (167.0   -120.3   120.3)
			   (168.0   -139.5   139.5)
			   (169.0   -180.0   180.0))
		         "11.038"
		          (( 50.0    -25.5    25.5)
			   ( 51.0    -25.2    25.2)
			   ( 52.0    -24.8    24.8)
			   ( 53.0    -24.5    24.5)
			   ( 54.0    -24.2    24.2)
			   ( 55.0    -23.9    23.9)
			   ( 56.0    -23.6    23.6)
			   ( 57.0    -23.3    23.3)
			   ( 58.0    -23.0    23.0)
			   ( 59.0    -22.8    22.8)
			   ( 60.0    -22.6    22.6)
			   ( 61.0    -22.3    22.3)
			   ( 62.0    -22.1    22.1)
			   ( 63.0    -21.9    21.9)
			   ( 64.0    -21.7    21.7)
			   ( 65.0    -21.5    21.5)
			   ( 66.0    -21.4    21.4)
			   ( 67.0    -21.2    21.2)
			   ( 68.0    -21.0    21.0)
			   ( 69.0    -20.9    20.9)
			   ( 70.0    -20.8    20.8)
			   ( 71.0    -20.6    20.6)
			   ( 72.0    -20.5    20.5)
			   ( 73.0    -20.4    20.4)
			   ( 74.0    -20.3    20.3)
			   ( 75.0    -20.2    20.2)
			   ( 76.0    -20.1    20.1)
			   ( 77.0    -20.0    20.0)
			   ( 78.0    -19.9    19.9)
			   ( 79.0    -19.9    19.9)
			   ( 80.0    -19.8    19.8)
			   ( 81.0    -19.7    19.7)
			   ( 82.0    -19.7    19.7)
			   ( 83.0    -19.6    19.6)
			   ( 84.0    -19.6    19.6)
			   ( 85.0    -19.6    19.6)
			   ( 86.0    -19.5    19.5)
			   ( 87.0    -19.5    19.5)
			   ( 88.0    -19.5    19.5)
			   ( 89.0    -19.5    19.5)
			   ( 90.0    -19.5    19.5)
			   ( 91.0    -19.5    19.5)
			   ( 92.0    -19.5    19.5)
			   ( 93.0    -19.5    19.5)
			   ( 94.0    -19.5    19.5)
			   ( 95.0    -19.6    19.6)
			   ( 96.0    -19.6    19.6)
			   ( 97.0    -19.6    19.6)
			   ( 98.0    -19.7    19.7)
			   ( 99.0    -19.7    19.7)
			   (100.0    -19.8    19.8)
			   (101.0    -19.9    19.9)
			   (102.0    -19.9    19.9)
			   (103.0    -20.0    20.0)
			   (104.0    -20.1    20.1)
			   (105.0    -20.2    20.2)
			   (106.0    -20.3    20.3)
			   (107.0    -20.4    20.4)
			   (108.0    -20.5    20.5)
			   (109.0    -20.6    20.6)
			   (110.0    -20.8    20.8)
			   (111.0    -20.9    20.9)
			   (112.0    -21.0    21.0)
			   (113.0    -21.2    21.2)
			   (114.0    -21.4    21.4)
			   (115.0    -21.5    21.5)
			   (116.0    -21.7    21.7)
			   (117.0    -21.9    21.9)
			   (118.0    -22.1    22.1)
			   (119.0    -22.3    22.3)
			   (120.0    -22.6    22.6)
			   (121.0    -22.8    22.8)
			   (122.0    -23.0    23.0)
			   (123.0    -23.3    23.3)
			   (124.0    -23.6    23.6)
			   (125.0    -23.9    23.9)
			   (126.0    -24.2    24.2)
			   (127.0    -24.5    24.5)
			   (128.0    -24.8    24.8)
			   (129.0    -25.2    25.2)
			   (130.0    -25.5    25.5)
			   (131.0    -25.9    25.9)
			   (132.0    -26.3    26.3)
			   (133.0    -26.8    26.8)
			   (134.0    -27.2    27.2)
			   (135.0    -27.7    27.7)
			   (136.0    -28.2    28.2)
			   (137.0    -28.8    28.8)
			   (138.0    -29.3    29.3)
			   (139.0    -29.9    29.9)
			   (140.0    -30.6    30.6)
			   (141.0    -31.2    31.2)
			   (142.0    -31.9    31.9)
			   (143.0    -32.7    32.7)
			   (144.0    -33.5    33.5)
			   (145.0    -34.3    34.3)
			   (146.0    -35.3    35.3)
			   (147.0    -36.2    36.2)
			   (148.0    -37.3    37.3)
			   (149.0    -38.4    38.4)
			   (150.0    -39.6    39.6)
			   (151.0    -40.9    40.9)
			   (152.0    -42.3    42.3)
			   (153.0    -43.8    43.8)
			   (154.0    -45.5    45.5)
			   (155.0    -47.2    47.2)
			   (156.0    -49.2    49.2)
			   (157.0    -51.4    51.4)
			   (158.0    -53.8    53.8)
			   (159.0    -56.4    56.4)
			   (160.0    -59.4    59.4)
			   (161.0    -62.7    62.7)
			   (162.0    -66.5    66.5)
			   (163.0    -70.8    70.8)
			   (164.0    -75.8    75.8)
			   (165.0    -81.7    81.7)
			   (166.0    -88.9    88.9)
			   (167.0    -97.7    97.7)
			   (168.0   -109.1   109.1)
			   (169.0   -125.1   125.1)
                           (170.0   -154.4   154.4)
                           (171.0   -180.0   180.0))
		         "11.073"
		          (( 50.0    -22.6    22.6)
			   ( 51.0    -22.3    22.3)
			   ( 52.0    -22.0    22.0)
			   ( 53.0    -21.7    21.7)
			   ( 54.0    -21.4    21.4)
			   ( 55.0    -21.2    21.2)
			   ( 56.0    -20.9    20.9)
			   ( 57.0    -20.7    20.7)
			   ( 58.0    -20.4    20.4)
			   ( 59.0    -20.2    20.2)
			   ( 60.0    -20.0    20.0)
			   ( 61.0    -19.8    19.8)
			   ( 62.0    -19.6    19.6)
			   ( 63.0    -19.4    19.4)
			   ( 64.0    -19.3    19.3)
			   ( 65.0    -19.1    19.1)
			   ( 66.0    -19.0    19.0)
			   ( 67.0    -18.8    18.8)
			   ( 68.0    -18.7    18.7)
			   ( 69.0    -18.5    18.5)
			   ( 70.0    -18.4    18.4)
			   ( 71.0    -18.3    18.3)
			   ( 72.0    -18.2    18.2)
			   ( 73.0    -18.1    18.1)
			   ( 74.0    -18.0    18.0)
			   ( 75.0    -17.9    17.9)
			   ( 76.0    -17.8    17.8)
			   ( 77.0    -17.8    17.8)
			   ( 78.0    -17.7    17.7)
			   ( 79.0    -17.6    17.6)
			   ( 80.0    -17.6    17.6)
			   ( 81.0    -17.5    17.5)
			   ( 82.0    -17.5    17.5)
			   ( 83.0    -17.4    17.4)
			   ( 84.0    -17.4    17.4)
			   ( 85.0    -17.4    17.4)
			   ( 86.0    -17.3    17.3)
			   ( 87.0    -17.3    17.3)
			   ( 88.0    -17.3    17.3)
			   ( 89.0    -17.3    17.3)
			   ( 90.0    -17.3    17.3)
			   ( 91.0    -17.3    17.3)
			   ( 92.0    -17.3    17.3)
			   ( 93.0    -17.3    17.3)
			   ( 94.0    -17.3    17.3)
			   ( 95.0    -17.4    17.4)
			   ( 96.0    -17.4    17.4)
			   ( 97.0    -17.4    17.4)
			   ( 98.0    -17.5    17.5)
			   ( 99.0    -17.5    17.5)
			   (100.0    -17.6    17.6)
			   (101.0    -17.6    17.6)
			   (102.0    -17.7    17.7)
			   (103.0    -17.8    17.8)
			   (104.0    -17.8    17.8)
			   (105.0    -17.9    17.9)
			   (106.0    -18.0    18.0)
			   (107.0    -18.1    18.1)
			   (108.0    -18.2    18.2)
			   (109.0    -18.3    18.3)
			   (110.0    -18.4    18.4)
			   (111.0    -18.5    18.5)
			   (112.0    -18.7    18.7)
			   (113.0    -18.8    18.8)
			   (114.0    -19.0    19.0)
			   (115.0    -19.1    19.1)
			   (116.0    -19.3    19.3)
			   (117.0    -19.4    19.4)
			   (118.0    -19.6    19.6)
			   (119.0    -19.8    19.8)
			   (120.0    -20.0    20.0)
			   (121.0    -20.2    20.2)
			   (122.0    -20.4    20.4)
			   (123.0    -20.7    20.7)
			   (124.0    -20.9    20.9)
			   (125.0    -21.2    21.2)
			   (126.0    -21.4    21.4)
			   (127.0    -21.7    21.7)
			   (128.0    -22.0    22.0)
			   (129.0    -22.3    22.3)
			   (130.0    -22.6    22.6)
			   (131.0    -23.0    23.0)
			   (132.0    -23.4    23.4)
			   (133.0    -23.7    23.7)
			   (134.0    -24.1    24.1)
			   (135.0    -24.6    24.6)
			   (136.0    -25.0    25.0)
			   (137.0    -25.5    25.5)
			   (138.0    -26.0    26.0)
			   (139.0    -26.5    26.5)
			   (140.0    -27.1    27.1)
			   (141.0    -27.7    27.7)
			   (142.0    -28.3    28.3)
			   (143.0    -28.9    28.9)
			   (144.0    -29.7    29.7)
			   (145.0    -30.4    30.4)
			   (146.0    -31.2    31.2)
			   (147.0    -32.1    32.1)
			   (148.0    -33.0    33.0)
			   (149.0    -34.0    34.0)
			   (150.0    -35.0    35.0)
			   (151.0    -36.1    36.1)
			   (152.0    -37.4    37.4)
			   (153.0    -38.7    38.7)
			   (154.0    -40.1    40.1)
			   (155.0    -41.7    41.7)
			   (156.0    -43.4    43.4)
			   (157.0    -45.3    45.3)
			   (158.0    -47.3    47.3)
			   (159.0    -49.6    49.6)
			   (160.0    -52.2    52.2)
			   (161.0    -55.0    55.0)
			   (162.0    -58.2    58.2)
			   (163.0    -61.9    61.9)
			   (164.0    -66.1    66.1)
			   (165.0    -71.1    71.1)
			   (166.0    -76.9    76.9)
			   (167.0    -83.9    83.9)
			   (168.0    -92.7    92.7)
			   (169.0   -104.0   104.0)
                           (170.0   -120.0   120.0)
                           (171.0   -148.1   148.1)
                           (172.0   -180.0   180.0))
		         "11.101"
		          (( 50.0    -16.7    16.7)
			   ( 51.0    -16.5    16.5)
			   ( 52.0    -16.3    16.3)
			   ( 53.0    -16.0    16.0)
			   ( 54.0    -15.8    15.8)
			   ( 55.0    -15.6    15.6)
			   ( 56.0    -15.5    15.5)
			   ( 57.0    -15.3    15.3)
			   ( 58.0    -15.1    15.1)
			   ( 59.0    -14.9    14.9)
			   ( 60.0    -14.8    14.8)
			   ( 61.0    -14.6    14.6)
			   ( 62.0    -14.5    14.5)
			   ( 63.0    -14.4    14.4)
			   ( 64.0    -14.2    14.2)
			   ( 65.0    -14.1    14.1)
			   ( 66.0    -14.0    14.0)
			   ( 67.0    -13.9    13.9)
			   ( 68.0    -13.8    13.8)
			   ( 69.0    -13.7    13.7)
			   ( 70.0    -13.6    13.6)
			   ( 71.0    -13.5    13.5)
			   ( 72.0    -13.5    13.5)
			   ( 73.0    -13.4    13.4)
			   ( 74.0    -13.3    13.3)
			   ( 75.0    -13.3    13.3)
			   ( 76.0    -13.2    13.2)
			   ( 77.0    -13.1    13.1)
			   ( 78.0    -13.1    13.1)
			   ( 79.0    -13.0    13.0)
			   ( 80.0    -13.0    13.0)
			   ( 81.0    -13.0    13.0)
			   ( 82.0    -12.9    12.9)
			   ( 83.0    -12.9    12.9)
			   ( 84.0    -12.9    12.9)
			   ( 85.0    -12.8    12.8)
			   ( 86.0    -12.8    12.8)
			   ( 87.0    -12.8    12.8)
			   ( 88.0    -12.8    12.8)
			   ( 89.0    -12.8    12.8)
			   ( 90.0    -12.8    12.8)
			   ( 91.0    -12.8    12.8)
			   ( 92.0    -12.8    12.8)
			   ( 93.0    -12.8    12.8)
			   ( 94.0    -12.8    12.8)
			   ( 95.0    -12.8    12.8)
			   ( 96.0    -12.9    12.9)
			   ( 97.0    -12.9    12.9)
			   ( 98.0    -12.9    12.9)
			   ( 99.0    -13.0    13.0)
			   (100.0    -13.0    13.0)
			   (101.0    -13.0    13.0)
			   (102.0    -13.1    13.1)
			   (103.0    -13.1    13.1)
			   (104.0    -13.2    13.2)
			   (105.0    -13.3    13.3)
			   (106.0    -13.3    13.3)
			   (107.0    -13.4    13.4)
			   (108.0    -13.5    13.5)
			   (109.0    -13.5    13.5)
			   (110.0    -13.6    13.6)
			   (111.0    -13.7    13.7)
			   (112.0    -13.8    13.8)
			   (113.0    -13.9    13.9)
			   (114.0    -14.0    14.0)
			   (115.0    -14.1    14.1)
			   (116.0    -14.2    14.2)
			   (117.0    -14.4    14.4)
			   (118.0    -14.5    14.5)
			   (119.0    -14.6    14.6)
			   (120.0    -14.8    14.8)
			   (121.0    -14.9    14.9)
			   (122.0    -15.1    15.1)
			   (123.0    -15.3    15.3)
			   (124.0    -15.5    15.5)
			   (125.0    -15.6    15.6)
			   (126.0    -15.8    15.8)
			   (127.0    -16.0    16.0)
			   (128.0    -16.3    16.3)
			   (129.0    -16.5    16.5)
			   (130.0    -16.7    16.7)
			   (131.0    -17.0    17.0)
			   (132.0    -17.3    17.3)
			   (133.0    -17.5    17.5)
			   (134.0    -17.8    17.8)
			   (135.0    -18.1    18.1)
			   (136.0    -18.5    18.5)
			   (137.0    -18.8    18.8)
			   (138.0    -19.2    19.2)
			   (139.0    -19.6    19.6)
			   (140.0    -20.0    20.0)
			   (141.0    -20.4    20.4)
			   (142.0    -20.9    20.9)
			   (143.0    -21.3    21.3)
			   (144.0    -21.9    21.9)
			   (145.0    -22.4    22.4)
			   (146.0    -23.0    23.0)
			   (147.0    -23.6    23.6)
			   (148.0    -24.3    24.3)
			   (149.0    -25.0    25.0)
			   (150.0    -25.8    25.8)
			   (151.0    -26.6    26.6)
			   (152.0    -27.5    27.5)
			   (153.0    -28.4    28.4)
			   (154.0    -29.5    29.5)
			   (155.0    -30.6    30.6)
			   (156.0    -31.8    31.8)
			   (157.0    -33.2    33.2)
			   (158.0    -34.6    34.6)
			   (159.0    -36.2    36.2)
			   (160.0    -38.0    38.0)
			   (161.0    -40.0    40.0)
			   (162.0    -42.3    42.3)
			   (163.0    -44.8    44.8)
			   (164.0    -47.7    47.7)
			   (165.0    -51.0    51.0)
			   (166.0    -54.9    54.9)
			   (167.0    -59.4    59.4)
			   (168.0    -64.8    64.8)
			   (169.0    -71.5    71.5)
                           (170.0    -79.9    79.9)
                           (171.0    -90.9    90.9)
                           (172.0   -106.4   106.4)
                           (173.0   -132.3   132.3)
                           (174.0   -180.0   180.0))
		         "11.150"
		          (( 50.0    -12.1    12.1)
			   ( 51.0    -12.0    12.0)
			   ( 52.0    -11.8    11.8)
			   ( 53.0    -11.7    11.7)
			   ( 54.0    -11.5    11.5)
			   ( 55.0    -11.4    11.4)
			   ( 56.0    -11.2    11.2)
			   ( 57.0    -11.1    11.1)
			   ( 58.0    -11.0    11.0)
			   ( 59.0    -10.9    10.9)
			   ( 60.0    -10.7    10.7)
			   ( 61.0    -10.6    10.6)
			   ( 62.0    -10.5    10.5)
			   ( 63.0    -10.4    10.4)
			   ( 64.0    -10.3    10.3)
			   ( 65.0    -10.3    10.3)
			   ( 66.0    -10.2    10.2)
			   ( 67.0    -10.1    10.1)
			   ( 68.0    -10.0    10.0)
			   ( 69.0    -10.0    10.0)
			   ( 70.0     -9.9     9.9)
			   ( 71.0     -9.8     9.8)
			   ( 72.0     -9.8     9.8)
			   ( 73.0     -9.7     9.7)
			   ( 74.0     -9.7     9.7)
			   ( 75.0     -9.6     9.6)
			   ( 76.0     -9.6     9.6)
			   ( 77.0     -9.5     9.5)
			   ( 78.0     -9.5     9.5)
			   ( 79.0     -9.5     9.5)
			   ( 80.0     -9.4     9.4)
			   ( 81.0     -9.4     9.4)
			   ( 82.0     -9.4     9.4)
			   ( 83.0     -9.4     9.4)
			   ( 84.0     -9.4     9.4)
			   ( 85.0     -9.3     9.3)
			   ( 86.0     -9.3     9.3)
			   ( 87.0     -9.3     9.3)
			   ( 88.0     -9.3     9.3)
			   ( 89.0     -9.3     9.3)
			   ( 90.0     -9.3     9.3)
			   ( 91.0     -9.3     9.3)
			   ( 92.0     -9.3     9.3)
			   ( 93.0     -9.3     9.3)
			   ( 94.0     -9.3     9.3)
			   ( 95.0     -9.3     9.3)
			   ( 96.0     -9.4     9.4)
			   ( 97.0     -9.4     9.4)
			   ( 98.0     -9.4     9.4)
			   ( 99.0     -9.4     9.4)
			   (100.0     -9.4     9.4)
			   (101.0     -9.5     9.5)
			   (102.0     -9.5     9.5)
			   (103.0     -9.5     9.5)
			   (104.0     -9.6     9.6)
			   (105.0     -9.6     9.6)
			   (106.0     -9.7     9.7)
			   (107.0     -9.7     9.7)
			   (108.0     -9.8     9.8)
			   (109.0     -9.8     9.8)
			   (110.0     -9.9     9.9)
			   (111.0    -10.0    10.0)
			   (112.0    -10.0    10.0)
			   (113.0    -10.1    10.1)
			   (114.0    -10.2    10.2)
			   (115.0    -10.3    10.3)
			   (116.0    -10.3    10.3)
			   (117.0    -10.4    10.4)
			   (118.0    -10.5    10.5)
			   (119.0    -10.6    10.6)
			   (120.0    -10.7    10.7)
			   (121.0    -10.9    10.9)
			   (122.0    -11.0    11.0)
			   (123.0    -11.1    11.1)
			   (124.0    -11.2    11.2)
			   (125.0    -11.4    11.4)
			   (126.0    -11.5    11.5)
			   (127.0    -11.7    11.7)
			   (128.0    -11.8    11.8)
			   (129.0    -12.0    12.0)
			   (130.0    -12.1    12.1)
			   (131.0    -12.3    12.3)
			   (132.0    -12.5    12.5)
			   (133.0    -12.7    12.7)
			   (134.0    -12.9    12.9)
			   (135.0    -13.2    13.2)
			   (136.0    -13.4    13.4)
			   (137.0    -13.7    13.7)
			   (138.0    -13.9    13.9)
			   (139.0    -14.2    14.2)
			   (140.0    -14.5    14.5)
			   (141.0    -14.8    14.8)
			   (142.0    -15.1    15.1)
			   (143.0    -15.5    15.5)
			   (144.0    -15.9    15.9)
			   (145.0    -16.3    16.3)
			   (146.0    -16.7    16.7)
			   (147.0    -17.1    17.1)
			   (148.0    -17.6    17.6)
			   (149.0    -18.1    18.1)
			   (150.0    -18.7    18.7)
			   (151.0    -19.3    19.3)
			   (152.0    -19.9    19.9)
			   (153.0    -20.6    20.6)
			   (154.0    -21.3    21.3)
			   (155.0    -22.1    22.1)
			   (156.0    -23.0    23.0)
			   (157.0    -23.9    23.9)
			   (158.0    -25.0    25.0)
			   (159.0    -26.1    26.1)
			   (160.0    -27.4    27.4)
			   (161.0    -28.8    28.8)
			   (162.0    -30.4    30.4)
			   (163.0    -32.2    32.2)
			   (164.0    -34.2    34.2)
			   (165.0    -36.5    36.5)
			   (166.0    -39.2    39.2)
			   (167.0    -42.2    42.2)
			   (168.0    -45.9    45.9)
			   (169.0    -50.3    50.3)
                           (170.0    -55.7    55.7)
                           (171.0    -62.4    62.4)
                           (172.0    -71.3    71.3)
                           (173.0    -83.4    83.4)
                           (174.0   -101.7   101.7)
                           (175.0   -136.9   136.9)
                           (176.0   -180.0   180.0))
		         "11.192"
		          (( 50.0    -17.5    17.5)
			   ( 51.0    -17.3    17.3)
			   ( 52.0    -17.0    17.0)
			   ( 53.0    -16.8    16.8)
			   ( 54.0    -16.6    16.6)
			   ( 55.0    -16.4    16.4)
			   ( 56.0    -16.2    16.2)
			   ( 57.0    -16.0    16.0)
			   ( 58.0    -15.8    15.8)
			   ( 59.0    -15.6    15.6)
			   ( 60.0    -15.5    15.5)
			   ( 61.0    -15.3    15.3)
			   ( 62.0    -15.2    15.2)
			   ( 63.0    -15.0    15.0)
			   ( 64.0    -14.9    14.9)
			   ( 65.0    -14.8    14.8)
			   ( 66.0    -14.7    14.7)
			   ( 67.0    -14.6    14.6)
			   ( 68.0    -14.5    14.5)
			   ( 69.0    -14.4    14.4)
			   ( 70.0    -14.3    14.3)
			   ( 71.0    -14.2    14.2)
			   ( 72.0    -14.1    14.1)
			   ( 73.0    -14.0    14.0)
			   ( 74.0    -13.9    13.9)
			   ( 75.0    -13.9    13.9)
			   ( 76.0    -13.8    13.8)
			   ( 77.0    -13.8    13.8)
			   ( 78.0    -13.7    13.7)
			   ( 79.0    -13.7    13.7)
			   ( 80.0    -13.6    13.6)
			   ( 81.0    -13.6    13.6)
			   ( 82.0    -13.5    13.5)
			   ( 83.0    -13.5    13.5)
			   ( 84.0    -13.5    13.5)
			   ( 85.0    -13.5    13.5)
			   ( 86.0    -13.4    13.4)
			   ( 87.0    -13.4    13.4)
			   ( 88.0    -13.4    13.4)
			   ( 89.0    -13.4    13.4)
			   ( 90.0    -13.4    13.4)
			   ( 91.0    -13.4    13.4)
			   ( 92.0    -13.4    13.4)
			   ( 93.0    -13.4    13.4)
			   ( 94.0    -13.4    13.4)
			   ( 95.0    -13.5    13.5)
			   ( 96.0    -13.5    13.5)
			   ( 97.0    -13.5    13.5)
			   ( 98.0    -13.5    13.5)
			   ( 99.0    -13.6    13.6)
			   (100.0    -13.6    13.6)
			   (101.0    -13.7    13.7)
			   (102.0    -13.7    13.7)
			   (103.0    -13.8    13.8)
			   (104.0    -13.8    13.8)
			   (105.0    -13.9    13.9)
			   (106.0    -13.9    13.9)
			   (107.0    -14.0    14.0)
			   (108.0    -14.1    14.1)
			   (109.0    -14.2    14.2)
			   (110.0    -14.3    14.3)
			   (111.0    -14.4    14.4)
			   (112.0    -14.5    14.5)
			   (113.0    -14.6    14.6)
			   (114.0    -14.7    14.7)
			   (115.0    -14.8    14.8)
			   (116.0    -14.9    14.9)
			   (117.0    -15.0    15.0)
			   (118.0    -15.2    15.2)
			   (119.0    -15.3    15.3)
			   (120.0    -15.5    15.5)
			   (121.0    -15.6    15.6)
			   (122.0    -15.8    15.8)
			   (123.0    -16.0    16.0)
			   (124.0    -16.2    16.2)
			   (125.0    -16.4    16.4)
			   (126.0    -16.6    16.6)
			   (127.0    -16.8    16.8)
			   (128.0    -17.0    17.0)
			   (129.0    -17.3    17.3)
			   (130.0    -17.5    17.5)
			   (131.0    -17.8    17.8)
			   (132.0    -18.1    18.1)
			   (133.0    -18.4    18.4)
			   (134.0    -18.7    18.7)
			   (135.0    -19.0    19.0)
			   (136.0    -19.3    19.3)
			   (137.0    -19.7    19.7)
			   (138.0    -20.1    20.1)
			   (139.0    -20.5    20.5)
			   (140.0    -20.9    20.9)
			   (141.0    -21.4    21.4)
			   (142.0    -21.8    21.8)
			   (143.0    -22.4    22.4)
			   (144.0    -22.9    22.9)
			   (145.0    -23.5    23.5)
			   (146.0    -24.1    24.1)
			   (147.0    -24.7    24.7)
			   (148.0    -25.4    25.4)
			   (149.0    -26.2    26.2)
			   (150.0    -27.0    27.0)
			   (151.0    -27.9    27.9)
			   (152.0    -28.8    28.8)
			   (153.0    -29.8    29.8)
			   (154.0    -30.9    30.9)
			   (155.0    -32.1    32.1)
			   (156.0    -33.3    33.3)
			   (157.0    -34.7    34.7)
			   (158.0    -36.3    36.3)
			   (159.0    -38.0    38.0)
			   (160.0    -39.9    39.9)
			   (161.0    -42.0    42.0)
			   (162.0    -44.4    44.4)
			   (163.0    -47.0    47.0)
			   (164.0    -50.1    50.1)
			   (165.0    -53.6    53.6)
			   (166.0    -57.7    57.7)
			   (167.0    -62.5    62.5)
			   (168.0    -68.3    68.3)
			   (169.0    -75.4    75.4)
                           (170.0    -84.4    84.4)
                           (171.0    -96.5    96.5)
                           (172.0   -113.9   113.9)
                           (173.0   -146.4   146.4)
                           (174.0   -180.0   180.0))
		         "11.269"
		          (( 50.0    -20.7    20.7)
			   ( 51.0    -20.4    20.4)
			   ( 52.0    -20.1    20.1)
			   ( 53.0    -19.8    19.8)
			   ( 54.0    -19.6    19.6)
			   ( 55.0    -19.3    19.3)
			   ( 56.0    -19.1    19.1)
			   ( 57.0    -18.9    18.9)
			   ( 58.0    -18.7    18.7)
			   ( 59.0    -18.5    18.5)
			   ( 60.0    -18.3    18.3)
			   ( 61.0    -18.1    18.1)
			   ( 62.0    -17.9    17.9)
			   ( 63.0    -17.7    17.7)
			   ( 64.0    -17.6    17.6)
			   ( 65.0    -17.4    17.4)
			   ( 66.0    -17.3    17.3)
			   ( 67.0    -17.2    17.2)
			   ( 68.0    -17.0    17.0)
			   ( 69.0    -16.9    16.9)
			   ( 70.0    -16.8    16.8)
			   ( 71.0    -16.7    16.7)
			   ( 72.0    -16.6    16.6)
			   ( 73.0    -16.5    16.5)
			   ( 74.0    -16.4    16.4)
			   ( 75.0    -16.4    16.4)
			   ( 76.0    -16.3    16.3)
			   ( 77.0    -16.2    16.2)
			   ( 78.0    -16.2    16.2)
			   ( 79.0    -16.1    16.1)
			   ( 80.0    -16.0    16.0)
			   ( 81.0    -16.0    16.0)
			   ( 82.0    -16.0    16.0)
			   ( 83.0    -15.9    15.9)
			   ( 84.0    -15.9    15.9)
			   ( 85.0    -15.9    15.9)
			   ( 86.0    -15.8    15.8)
			   ( 87.0    -15.8    15.8)
			   ( 88.0    -15.8    15.8)
			   ( 89.0    -15.8    15.8)
			   ( 90.0    -15.8    15.8)
			   ( 91.0    -15.8    15.8)
			   ( 92.0    -15.8    15.8)
			   ( 93.0    -15.8    15.8)
			   ( 94.0    -15.8    15.8)
			   ( 95.0    -15.9    15.9)
			   ( 96.0    -15.9    15.9)
			   ( 97.0    -15.9    15.9)
			   ( 98.0    -16.0    16.0)
			   ( 99.0    -16.0    16.0)
			   (100.0    -16.0    16.0)
			   (101.0    -16.1    16.1)
			   (102.0    -16.2    16.2)
			   (103.0    -16.2    16.2)
			   (104.0    -16.3    16.3)
			   (105.0    -16.4    16.4)
			   (106.0    -16.4    16.4)
			   (107.0    -16.5    16.5)
			   (108.0    -16.6    16.6)
			   (109.0    -16.7    16.7)
			   (110.0    -16.8    16.8)
			   (111.0    -16.9    16.9)
			   (112.0    -17.0    17.0)
			   (113.0    -17.2    17.2)
			   (114.0    -17.3    17.3)
			   (115.0    -17.4    17.4)
			   (116.0    -17.6    17.6)
			   (117.0    -17.7    17.7)
			   (118.0    -17.9    17.9)
			   (119.0    -18.1    18.1)
			   (120.0    -18.3    18.3)
			   (121.0    -18.5    18.5)
			   (122.0    -18.7    18.7)
			   (123.0    -18.9    18.9)
			   (124.0    -19.1    19.1)
			   (125.0    -19.3    19.3)
			   (126.0    -19.6    19.6)
			   (127.0    -19.8    19.8)
			   (128.0    -20.1    20.1)
			   (129.0    -20.4    20.4)
			   (130.0    -20.7    20.7)
			   (131.0    -21.0    21.0)
			   (132.0    -21.3    21.3)
			   (133.0    -21.7    21.7)
			   (134.0    -22.0    22.0)
			   (135.0    -22.4    22.4)
			   (136.0    -22.8    22.8)
			   (137.0    -23.3    23.3)
			   (138.0    -23.7    23.7)
			   (139.0    -24.2    24.2)
			   (140.0    -24.7    24.7)
			   (141.0    -25.2    25.2)
			   (142.0    -25.8    25.8)
			   (143.0    -26.4    26.4)
			   (144.0    -27.0    27.0)
			   (145.0    -27.7    27.7)
			   (146.0    -28.5    28.5)
			   (147.0    -29.2    29.2)
			   (148.0    -30.1    30.1)
			   (149.0    -31.0    31.0)
			   (150.0    -31.9    31.9)
			   (151.0    -32.9    32.9)
			   (152.0    -34.0    34.0)
			   (153.0    -35.2    35.2)
			   (154.0    -36.5    36.5)
			   (155.0    -38.0    38.0)
			   (156.0    -39.5    39.5)
			   (157.0    -41.2    41.2)
			   (158.0    -43.0    43.0)
			   (159.0    -45.1    45.1)
			   (160.0    -47.4    47.4)
			   (161.0    -49.9    49.9)
			   (162.0    -52.8    52.8)
			   (163.0    -56.1    56.1)
			   (164.0    -59.8    59.8)
			   (165.0    -64.2    64.2)
			   (166.0    -69.2    69.2)
			   (167.0    -75.3    75.3)
			   (168.0    -82.8    82.8)
			   (169.0    -92.2    92.2)
                           (170.0   -104.7   104.7)
                           (171.0   -122.9   122.9)
                           (172.0   -161.9   161.9)
                           (173.0   -180.0   180.0))
		         "11.311"
		          (( 50.0    -25.7    25.7)
			   ( 51.0    -25.3    25.3)
			   ( 52.0    -24.9    24.9)
			   ( 53.0    -24.6    24.6)
			   ( 54.0    -24.3    24.3)
			   ( 55.0    -24.0    24.0)
			   ( 56.0    -23.7    23.7)
			   ( 57.0    -23.4    23.4)
			   ( 58.0    -23.2    23.2)
			   ( 59.0    -22.9    22.9)
			   ( 60.0    -22.7    22.7)
			   ( 61.0    -22.4    22.4)
			   ( 62.0    -22.2    22.2)
			   ( 63.0    -22.0    22.0)
			   ( 64.0    -21.8    21.8)
			   ( 65.0    -21.6    21.6)
			   ( 66.0    -21.5    21.5)
			   ( 67.0    -21.3    21.3)
			   ( 68.0    -21.2    21.2)
			   ( 69.0    -21.0    21.0)
			   ( 70.0    -20.9    20.9)
			   ( 71.0    -20.7    20.7)
			   ( 72.0    -20.6    20.6)
			   ( 73.0    -20.5    20.5)
			   ( 74.0    -20.4    20.4)
			   ( 75.0    -20.3    20.3)
			   ( 76.0    -20.2    20.2)
			   ( 77.0    -20.1    20.1)
			   ( 78.0    -20.0    20.0)
			   ( 79.0    -20.0    20.0)
			   ( 80.0    -19.9    19.9)
			   ( 81.0    -19.8    19.8)
			   ( 82.0    -19.8    19.8)
			   ( 83.0    -19.7    19.7)
			   ( 84.0    -19.7    19.7)
			   ( 85.0    -19.7    19.7)
			   ( 86.0    -19.6    19.6)
			   ( 87.0    -19.6    19.6)
			   ( 88.0    -19.6    19.6)
			   ( 89.0    -19.6    19.6)
			   ( 90.0    -19.6    19.6)
			   ( 91.0    -19.6    19.6)
			   ( 92.0    -19.6    19.6)
			   ( 93.0    -19.6    19.6)
			   ( 94.0    -19.6    19.6)
			   ( 95.0    -19.7    19.7)
			   ( 96.0    -19.7    19.7)
			   ( 97.0    -19.7    19.7)
			   ( 98.0    -19.8    19.8)
			   ( 99.0    -19.8    19.8)
			   (100.0    -19.9    19.9)
			   (101.0    -20.0    20.0)
			   (102.0    -20.0    20.0)
			   (103.0    -20.1    20.1)
			   (104.0    -20.2    20.2)
			   (105.0    -20.3    20.3)
			   (106.0    -20.4    20.4)
			   (107.0    -20.5    20.5)
			   (108.0    -20.6    20.6)
			   (109.0    -20.7    20.7)
			   (110.0    -20.9    20.9)
			   (111.0    -21.0    21.0)
			   (112.0    -21.2    21.2)
			   (113.0    -21.3    21.3)
			   (114.0    -21.5    21.5)
			   (115.0    -21.6    21.6)
			   (116.0    -21.8    21.8)
			   (117.0    -22.0    22.0)
			   (118.0    -22.2    22.2)
			   (119.0    -22.4    22.4)
			   (120.0    -22.7    22.7)
			   (121.0    -22.9    22.9)
			   (122.0    -23.2    23.2)
			   (123.0    -23.4    23.4)
			   (124.0    -23.7    23.7)
			   (125.0    -24.0    24.0)
			   (126.0    -24.3    24.3)
			   (127.0    -24.6    24.6)
			   (128.0    -24.9    24.9)
			   (129.0    -25.3    25.3)
			   (130.0    -25.7    25.7)
			   (131.0    -26.1    26.1)
			   (132.0    -26.5    26.5)
			   (133.0    -26.9    26.9)
			   (134.0    -27.4    27.4)
			   (135.0    -27.9    27.9)
			   (136.0    -28.4    28.4)
			   (137.0    -28.9    28.9)
			   (138.0    -29.5    29.5)
			   (139.0    -30.1    30.1)
			   (140.0    -30.7    30.7)
			   (141.0    -31.4    31.4)
			   (142.0    -32.1    32.1)
			   (143.0    -32.9    32.9)
			   (144.0    -33.7    33.7)
			   (145.0    -34.5    34.5)
			   (146.0    -35.4    35.4)
			   (147.0    -36.4    36.4)
			   (148.0    -37.5    37.5)
			   (149.0    -38.6    38.6)
			   (150.0    -39.8    39.8)
			   (151.0    -41.1    41.1)
			   (152.0    -42.5    42.5)
			   (153.0    -44.0    44.0)
			   (154.0    -45.7    45.7)
			   (155.0    -47.5    47.5)
			   (156.0    -49.5    49.5)
			   (157.0    -51.6    51.6)
			   (158.0    -54.0    54.0)
			   (159.0    -56.7    56.7)
			   (160.0    -59.7    59.7)
			   (161.0    -63.0    63.0)
			   (162.0    -66.8    66.8)
			   (163.0    -71.2    71.2)
			   (164.0    -76.3    76.3)
			   (165.0    -82.2    82.2)
			   (166.0    -89.4    89.4)
			   (167.0    -98.3    98.3)
			   (168.0   -109.9   109.9)
			   (169.0   -126.3   126.3)
                           (170.0   -157.2   157.2)
                           (171.0   -180.0   180.0))
		         "11.353"
		          (( 50.0    -29.5    29.5)
			   ( 51.0    -29.1    29.1)
			   ( 52.0    -28.7    28.7)
			   ( 53.0    -28.3    28.3)
			   ( 54.0    -27.9    27.9)
			   ( 55.0    -27.6    27.6)
			   ( 56.0    -27.2    27.2)
			   ( 57.0    -26.9    26.9)
			   ( 58.0    -26.6    26.6)
			   ( 59.0    -26.3    26.3)
			   ( 60.0    -26.0    26.0)
			   ( 61.0    -25.8    25.8)
			   ( 62.0    -25.5    25.5)
			   ( 63.0    -25.3    25.3)
			   ( 64.0    -25.1    25.1)
			   ( 65.0    -24.9    24.9)
			   ( 66.0    -24.7    24.7)
			   ( 67.0    -24.5    24.5)
			   ( 68.0    -24.3    24.3)
			   ( 69.0    -24.1    24.1)
			   ( 70.0    -24.0    24.0)
			   ( 71.0    -23.8    23.8)
			   ( 72.0    -23.7    23.7)
			   ( 73.0    -23.5    23.5)
			   ( 74.0    -23.4    23.4)
			   ( 75.0    -23.3    23.3)
			   ( 76.0    -23.2    23.2)
			   ( 77.0    -23.1    23.1)
			   ( 78.0    -23.0    23.0)
			   ( 79.0    -22.9    22.9)
			   ( 80.0    -22.9    22.9)
			   ( 81.0    -22.8    22.8)
			   ( 82.0    -22.7    22.7)
			   ( 83.0    -22.7    22.7)
			   ( 84.0    -22.6    22.6)
			   ( 85.0    -22.6    22.6)
			   ( 86.0    -22.6    22.6)
			   ( 87.0    -22.5    22.5)
			   ( 88.0    -22.5    22.5)
			   ( 89.0    -22.5    22.5)
			   ( 90.0    -22.5    22.5)
			   ( 91.0    -22.5    22.5)
			   ( 92.0    -22.5    22.5)
			   ( 93.0    -22.5    22.5)
			   ( 94.0    -22.6    22.6)
			   ( 95.0    -22.6    22.6)
			   ( 96.0    -22.6    22.6)
			   ( 97.0    -22.7    22.7)
			   ( 98.0    -22.7    22.7)
			   ( 99.0    -22.8    22.8)
			   (100.0    -22.9    22.9)
			   (101.0    -22.9    22.9)
			   (102.0    -23.0    23.0)
			   (103.0    -23.1    23.1)
			   (104.0    -23.2    23.2)
			   (105.0    -23.3    23.3)
			   (106.0    -23.4    23.4)
			   (107.0    -23.5    23.5)
			   (108.0    -23.7    23.7)
			   (109.0    -23.8    23.8)
			   (110.0    -24.0    24.0)
			   (111.0    -24.1    24.1)
			   (112.0    -24.3    24.3)
			   (113.0    -24.5    24.5)
			   (114.0    -24.7    24.7)
			   (115.0    -24.9    24.9)
			   (116.0    -25.1    25.1)
			   (117.0    -25.3    25.3)
			   (118.0    -25.5    25.5)
			   (119.0    -25.8    25.8)
			   (120.0    -26.0    26.0)
			   (121.0    -26.3    26.3)
			   (122.0    -26.6    26.6)
			   (123.0    -26.9    26.9)
			   (124.0    -27.2    27.2)
			   (125.0    -27.6    27.6)
			   (126.0    -27.9    27.9)
			   (127.0    -28.3    28.3)
			   (128.0    -28.7    28.7)
			   (129.0    -29.1    29.1)
			   (130.0    -29.5    29.5)
			   (131.0    -30.0    30.0)
			   (132.0    -30.4    30.4)
			   (133.0    -30.9    30.9)
			   (134.0    -31.5    31.5)
			   (135.0    -32.0    32.0)
			   (136.0    -32.6    32.6)
			   (137.0    -33.2    33.2)
			   (138.0    -33.9    33.9)
			   (139.0    -34.6    34.6)
			   (140.0    -35.3    35.3)
			   (141.0    -36.1    36.1)
			   (142.0    -36.9    36.9)
			   (143.0    -37.8    37.8)
			   (144.0    -38.8    38.8)
			   (145.0    -39.8    39.8)
			   (146.0    -40.8    40.8)
			   (147.0    -42.0    42.0)
			   (148.0    -43.2    43.2)
			   (149.0    -44.5    44.5)
			   (150.0    -45.9    45.9)
			   (151.0    -47.5    47.5)
			   (152.0    -49.1    49.1)
			   (153.0    -50.9    50.9)
			   (154.0    -52.9    52.9)
			   (155.0    -55.0    55.0)
			   (156.0    -57.3    57.3)
			   (157.0    -59.9    59.9)
			   (158.0    -62.8    62.8)
			   (159.0    -66.0    66.0)
			   (160.0    -69.6    69.6)
			   (161.0    -73.6    73.6)
			   (162.0    -78.3    78.3)
			   (163.0    -83.7    83.7)
			   (164.0    -90.1    90.1)
			   (165.0    -97.8    97.8)
			   (166.0   -107.5   107.5)
			   (167.0   -120.3   120.3)
			   (168.0   -139.5   139.5)
			   (169.0   -180.0   180.0))
			 )))	 
			
  ;; guide-star-table maps the number of guide star pairs available at a time to the guide star suitability
  :guide-star-table '(:fine-lock-nominal       (*MINUS-INFINITY* 0.0 1 1.0)
		      :fine-lock-off-nominal   (*MINUS-INFINITY* 0.0 1 0.75)
		      :course-lock-nominal     (*MINUS-INFINITY* 0.0 1 1.0)
		      :course-lock-off-nominal (*MINUS-INFINITY* 0.0 1 0.75))
  :phase-period-cutoff 7.0	;; added ijej 01-05-01.  Restored to explicit default 01-05-03.
  )
